<?php
class AlmacenController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/almacen';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $almacen = new Default_Model_Almacen();
            $almacenes = $almacen->fetchAll();

            $paginador = Zend_Paginator::factory($almacenes);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->almacenes = $paginador;
            $this->view->title = 'Almacenes';
            $this->renderScript('almacen/index.phtml');
        }
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_Almacen(null, $this->path);

            if($this->_request->getParam('id')) {

                $almacen = new Default_Model_Almacen();
                $id = $almacen->getAdapter()->quote($this->_request->getParam('id'));
                $row = $almacen->fetchRow("id=$id")->toArray();
                $form->populate($row);
                $form->setAction('/almacen/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar almacén";

            } else {

                $this->view->title = "Crear almacén";

            }
            $this->view->form = $form;
            $this->renderScript('almacen/form.phtml');
        } else {
            $this->_forward('logout', 'index');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Default_Form_Almacen(null, $this->path);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $almacen = new Default_Model_Almacen();
                    $row = $almacen->createRow();
                    $row->nombre = $form->getValue('nombre');
                    if($form->getValue('descripcion')!=='') {
                        $row->descripcion = $form->getValue('descripcion');
                    } else {
                        $row->descripcion = NULL;
                    }
                    $row->save();

                    $mSession->mensajes[] = 'El registro fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                }

                $this->_forward('index', 'almacen');

            } else {
                $this->view->title = "Crear almacén";
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('almacen/form.phtml');
            }
        }
        $this->view->form = $form;
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $almacen = new Default_Model_Almacen();

        $request = $this->getRequest();
        $form = new Default_Form_Almacen();
        $form->setAction($this->path . '/edit');
        $form->submit->setLabel("Guardar cambios");

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    
                    $where = $almacen->getAdapter()->quoteInto("id=?", (int)$form->getValue('id'));
                    $row = $almacen->fetchRow($where);
                    $row->nombre = $form->getValue('nombre');
                    if($form->getValue('descripcion')!=='') {
                        $row->descripcion = $form->getValue('descripcion');
                    } else {
                        $row->descripcion = NULL;
                    }
                    $row->save();

                    $mSession->mensajes[] = 'El registro fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                }

                $this->_forward('index', 'almacen');

            } else {
                $this->view->title = "Editar almacén";
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('almacen/form.phtml');
            }
        } else {

            if ($this->_request->getParam('id')) {

                $where = $almacen->getAdapter()->quoteInto("id=?", (int)$this->_request->getParam('id'));
                $registro = $almacen->fetchRow($where);
                $form->populate($registro->toArray());
            }
        }
        $this->view->form = $form;
    }

    public function deleteAction()
    {
        if($this->_getParam('id')){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            
            try {

                $model = new Default_Model_Almacen();
                $where = $model->getAdapter()->quoteInto("id = ?" , (int)$this->_getParam('id'));
                $model->delete($where);

                $mSession->mensajes[] = 'El almacén fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';

                $this->_forward('index','almacen');

            } catch (Exception $e) {

                $mSession->tipo_error = 1;
                $mSession->errores[] = $e->getMessage();

                $this->_forward('error-delete-registro','error');

            }
        }
    }
}