<?php
class AnotacionVehiculoController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/anotacion-vehiculo';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function listByVehiculoAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('vehiculos', 'patente', strtoupper($this->_getParam('id')))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $patente = strtoupper($this->_getParam('id'));
            $currentPage = $this->_getParam('page', 1);

            $model = new Default_Model_VistaAnotacionesVehiculos();
            $where = $model->getAdapter()->quoteInto('vehiculo=?', $patente);
            $anotaciones = $model->fetchAll($where);

            $paginador = Zend_Paginator::factory($anotaciones);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control_extra.phtml');

            $this->view->anotaciones = $paginador;
            $this->renderScript('anotacion-vehiculo/list-by-vehiculo.phtml');
        }
    }

    public function getFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            if($this->_getParam('id')) {

                $request = $this->getRequest();
                $form = new Default_Form_AnotacionVehiculo(null, $this->path);

                $id = (int)$this->_request->getParam('id');
                $anotacion = new Default_Model_AnotacionVehiculo();
                $where = $anotacion->getAdapter()->quoteInto("id=?", $id);
                $row = $anotacion->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/anotacion-vehiculo/edit');
                $form->submit->setLabel('Guardar cambios');

                if($this->_getParam('type_user')==1){
                    $form->type_user->setValue(1);
                }

                echo $form;

            } elseif($this->_getParam('from_id') && 
                     $this->_helper->validateRecordExists('vehiculos', 'patente', strtoupper($this->_getParam('from_id')))) {

                $patente = strtoupper($this->_getParam('from_id'));
                $request = $this->getRequest();
                $form = new Default_Form_AnotacionVehiculo(null, $this->path);
                $form->vehiculo->setValue($patente);

                if($this->_getParam('type_user')==1){
                    $form->type_user->setValue(1);
                }

                echo $form;

               
            }
        }
    }    
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_AnotacionVehiculo(null, $this->path);
        $this->view->title = 'Agregar anotación';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $anotacion = new Default_Model_AnotacionVehiculo();
                    $row = $anotacion->createRow();
                    $row->creador = $this->usuario->rut;
                    $row->vehiculo = strtoupper($form->getValue('vehiculo'));
                    $row->detalles = $form->getValue('detalles');
                    $row->save();
                    
                    $aviso = '<div id="aviso-form" class="confirmacion"><ul>';
                    $aviso .= '<li>La anotación fue guardada de forma exitosa.</li>';
                    $aviso .= '</ul></div>';

                    echo $aviso;

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la solicitud de servicio.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','vehiculo');
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('anotacion-vehiculo/form.phtml');
            }
        }
    }

}