<?php
class ArticuloController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/articulo';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {

        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $this->view->t = $this->_getParam('t');

            $currentPage = $this->_getParam('page', 1);

            $articulo = new Default_Model_VistaArticulos();
            $order = "codigo";
            $articulos = $articulo->fetchAll(null,$order);

            $paginador = Zend_Paginator::factory($articulos);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->articulos = $paginador;
            $this->view->title = 'Artículos';
            $this->renderScript('articulo/index.phtml');
        }
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_Articulo(null, $this->path);

            if($this->_request->getParam('codigo')) {

                $articulo = new Default_Model_Articulo();
                $codigo = $articulo->getAdapter()->quote($this->_request->getParam('codigo'));
                $row = $articulo->fetchRow('codigo='.$codigo)->toArray();
                $form->populate($row);
                $form->setAction('/articulo/edit');
                $form->codigo->setAttrib('disabled','disabled');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar artículo código : $codigo";

            } else {

                $this->view->title = "Crear artículo";

            }
            $this->view->form = $form;
            $this->renderScript('articulo/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Articulo(null, $this->path);
        $this->view->title = 'Crear artículo';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $articulo = new Default_Model_Articulo();
                    $row = $articulo->createRow();
                    $row->creador = $this->usuario->rut;
                    if($form->getValue('codigo_proveedor')!=='') {
                        $row->codigo_proveedor = $form->getValue('codigo_proveedor');
                    }
                    $row->categoria_id = $form->getValue('categoria_id');
                    $row->fabricante_id = $form->getValue('fabricante_id');
                    $row->envase_id = $form->getValue('envase_id');
                    $row->almacen_id = $form->getValue('almacen_id');
                    $row->nombre = $form->getValue('nombre');

                    if($form->getValue('descripcion')!='') {
                        $row->descripcion = $form->getValue('descripcion');
                    }

                    if($form->getValue('sector_almacenaje')!='') {
                        $row->sector_almacenaje = $form->getValue('sector_almacenaje');
                    }
                    
                    $row->save();
                    
                    $mSession->mensajes[] = 'El artículo fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view','articulo', null, array('codigo' => $row->codigo, 't' => 'a'));

                } catch (Exception $e) {

                    $mSession->tipo_error = 1;
                    $mSession->errores[] = $e->getMessage();

                    $this->_forward('error-new-registro','error');
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('articulo/form.phtml');
            }
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Articulo();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                try {

                    $articulo = new Default_Model_Articulo();
                    $codigo = $form->getValue('codigo');
                    $where = $articulo->getAdapter()->quoteInto("codigo=?", $codigo);
                    $row = $articulo->fetchRow($where);
                    $row->creador = $this->usuario->rut;
                    $row->categoria_id = $form->getValue('categoria_id');
                    $row->fabricante_id = $form->getValue('fabricante_id');
                    $row->envase_id = $form->getValue('envase_id');
                    $row->almacen_id = $form->getValue('almacen_id');
                    $row->nombre = $form->getValue('nombre'); 

                    if($form->getValue('descripcion')!='') {
                        $row->descripcion = $form->getValue('descripcion');
                    } else {
                        $row->descripcion = null;
                    }

                    if($form->getValue('sector_almacenaje')!='') {
                        $row->sector_almacenaje = $form->getValue('sector_almacenaje');
                    } else {
                        $row->sector_almacenaje = null;
                    }

                    $row->save();

                    $mSession->mensajes[] = 'El artículo fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view', 'articulo', null, array('codigo'=> $codigo, 't' => 'a'));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el artículo.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','articulo');
                }
            } else {

                $form->populate($request->getPost());
                $form->codigo->setAttrib('disabled','disabled');
                $this->view->form = $form;
                $form->setAction('/articulo/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar artículo";
                $this->renderScript('articulo/form.phtml');
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            if($this->_getParam('codigo')) {
                $codigo = $this->_getParam('codigo');
                $articulo = new Default_Model_Articulo();
                $where = $articulo->getAdapter()->quoteInto('codigo = ?' , $codigo);
                $articulo->delete($where);
                $mSession->mensajes[] = 'El artículo fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';

            }
            $this->_forward('index','articulo');
        } 
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $codigo = $this->_getParam('codigo');


            $articulo = new Default_Model_VistaArticulos();
            $where = $articulo->getAdapter()->quoteInto("codigo=?", $codigo);
            $row = $articulo->fetchRow($where);

            $costoArticulo = new Default_Model_CostoArticulo();
            $where_costo = $costoArticulo->getAdapter()->quoteInto("articulo=?", $codigo);
            $order_costo = 'id DESC';
            $row_costo = $costoArticulo->fetchRow($where_costo, $oder_costo);

            $precioArticulo = new Default_Model_PrecioArticulo();
            $where_precio = $precioArticulo->getAdapter()->quoteInto("articulo=?", $codigo);
            $order_precio = 'id DESC';
            $row_precio = $precioArticulo->fetchRow($where_precio, $order_precio);

            if($row_costo AND $row_precio){
                $this->view->margen = round((($row_precio->precio_unitario_neto * 100) / $row_costo->costo_neto_corregido) - 100, 2);
            }

            $this->view->title = "Artículo";
            
            if(false==$row) {
                $this->_forward('index','articulo');
            } else {
                $this->view->precio = $row_precio;
                $this->view->costo = $row_costo;
                $this->view->articulo = $row;
                $this->view->t = $this->_getParam('t');

                if($row->estado=='BORRADOR') {
                     $this->renderScript('articulo/view-borrador.phtml');
                } else {

                    if($this->_getParam('t')=='a') {
                        $this->renderScript('articulo/view-admin.phtml');
                    } else {
                        $this->renderScript('articulo/view.phtml');
                    }
                }
            }
        }
    }

    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $formularios = array(
                new Default_Form_BuscarNumero(null, $this->path),
                new Default_Form_ConsultaArticuloInventario(null, $this->path),
            );

            $request = $this->getRequest();
            $this->view->formularios = $formularios;
            $this->view->title = 'Artículos : Buscar';
            $this->renderScript('articulo-inventario/find.phtml');

        }
    }

    public function searchTooltipAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $articulo = new Default_Model_VistaArticulos();

            $filter_tags    = new Zend_Filter_StripTags();
            $criterio       = $filter_tags->filter(trim($this->_getParam('criterio')));
            $valor          = $filter_tags->filter(trim($this->_getParam('valor')));
            $this->view->t  = $filter_tags->filter(trim($this->_getParam('t')));

            if($criterio!='' AND $valor!='') {

                if($criterio=='codigo') {

                    $valor = strtoupper($valor);
                    $where = "$criterio='$valor'";

                } else {

                    $where = "$criterio LIKE '%$valor%'";
                }

                $this->view->articulos = $articulo->fetchAll($where)->toArray();
            }

            $this->renderScript('articulo/search.phtml');
        }
    }

    public function viewSmallAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $this->view->t  = $this->_getParam('t');
            $codigo = $this->_getParam('codigo');
            $articulo = new Default_Model_VistaArticulos();
            $where = $articulo->getAdapter()->quoteInto("codigo=?", $codigo);
            $this->view->articulo = $articulo->fetchRow($where)->toArray();
            $this->renderScript('articulo/view-tooltip.phtml');
        }
    }

    public function ajustarStockMinimoAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('codigo') AND
           $this->_helper->validateRecordExists('articulos', 'codigo', $this->_getParam('codigo'))){

            $codigo = $this->_getParam('codigo');
            $valor = (int)$this->_getParam('valor');

            try {

                $articulo = new Default_Model_Articulo();
                $where = $articulo->getAdapter()->quoteInto("codigo=?", $codigo);
                $row = $articulo->fetchRow($where);
                $row->stock_minimo = $valor;
                $row->save();

                $data = array();
                $data['mensaje'] = array("valor" => "Valor guardado", "style" => "color:green;");
                $data['valores'] = 0;

                echo Zend_Json_Encoder::encode($data);

            } catch (Exception $e) {

                echo '<span style="color:red;">No se pudo guardar el nuevo valor</span>';
            }
        }
    }

    public function ajustarPrecioVentaAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('codigo') AND
           $this->_helper->validateRecordExists('articulos', 'codigo', $this->_getParam('codigo'))){

            $codigo = $this->_getParam('codigo');
            $valor = (int)$this->_getParam('valor');

            try {

                $precio = new Default_Model_PrecioArticulo();
                $row = $precio->createRow();
                $row->creador = $this->usuario->rut;
                $row->articulo = $codigo;
                $row->precio_unitario_neto = $valor;
                $row->tipo_valor = 'MANUAL';
                $row->save();

                $costo = new Default_Model_CostoArticulo();
                $where_costo = $costo->getAdapter()->quoteInto("articulo=?", $codigo);
                $order_costo = 'id DESC';
                $row_costo = $costo->fetchRow($where_costo, $order_costo)->toArray();

                $margen = round((($valor * 100) / $row_costo['costo_neto_corregido']) - 100, 2);

                $data = array();
                $data['mensaje'] = array("valor" => "Valor guardado", "style" => "color:green;");
                $data['valores'] = array(
                    array('id' => '#porcentaje_margen', 'html' => $margen)
                );

                /*
                $data['cambios'] = array(
                    array('id' => '#porcentaje_margen', 'attrs' => array('key' => 'value', 'value' => $margen))
                );
                */

                echo Zend_Json_Encoder::encode($data);

            } catch (Exception $e) {

                echo '<span style="color:red;">No se pudo guardar el nuevo valor</span>';
            }
        }
    }

    public function habilitarAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND 
           $this->_getParam('codigo') AND 
           $this->_helper->validateRecordExists('articulos', 'codigo', $this->_getParam('codigo'))){

            $codigo = $this->_getParam('codigo');
            $t = $this->_getParam('t');
            
            try {
                
                $articulo = new Default_Model_Articulo();
                $where = $articulo->getAdapter()->quoteInto("codigo=?", $codigo);
                $row = $articulo->fetchRow($where);
                $row->estado = 'DISPONIBLE';
                $row->save();
                
                $mSession->mensajes[] = 'El artículo ya se encuentra disponible para la venta.';
                $mSession->claseMensaje = 'confirmacion';

                $this->_forward('view', 'articulo', null, array('codigo' => $codigo, 't' => $t));
                
            } catch (Exception $e) {

                $mSession->mensajes[] = 'Ocurrió un error al intentar habilitar el artículo para la venta.';
                $mSession->mensajes[] = $e->getMessage();
                $mSession->claseMensaje = 'error';
                $this->_forward('index','articulo');
            }
        }
    }

    public function deshabilitarAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('codigo') AND
           $this->_helper->validateRecordExists('articulos', 'codigo', $this->_getParam('codigo'))){

            $codigo = $this->_getParam('codigo');
            $t = $this->_getParam('t');

            try {

                $articulo = new Default_Model_Articulo();
                $where = $articulo->getAdapter()->quoteInto("codigo=?", $codigo);
                $row = $articulo->fetchRow($where);
                $row->estado = 'NO DISPONIBLE';
                $row->save();

                $mSession->mensajes[] = 'El artículo ya se encuentra disponible para la venta.';
                $mSession->claseMensaje = 'confirmacion';

                $this->_forward('view', 'articulo', null, array('codigo' => $codigo, 't' => $t));

            } catch (Exception $e) {

                $mSession->mensajes[] = 'Ocurrió un error al intentar habilitar el artículo para la venta.';
                $mSession->mensajes[] = $e->getMessage();
                $mSession->claseMensaje = 'error';
                $this->_forward('index','articulo');
            }
        }
    }
}