<?php
class ArticuloProductoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();

        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
    }
    
    public function init()
    {
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/articulo-producto';
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function getFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_ArticuloProducto();

            if($this->_request->getParam('id') AND 
               $this->_helper->validateRecordExists('articulos_productos', 'id', $this->_request->getParam('id'))) {

                $art_producto = new Default_Model_ArticuloProducto();
                $where = $art_producto->getAdapter()->quoteInto("id=?", (int)$this->_request->getParam('id'));
                $row = $art_producto->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction($this->path .'/edit');
                $form->submit->setLabel('Guardar cambios');
                echo $form;

            } elseif($this->_request->getParam('codigo') AND
                     $this->_helper->validateRecordExists('productos', 'codigo', $this->_request->getParam('codigo'))) {
                $form->producto->setValue($this->_request->getParam('codigo'));
                echo $form;
            }
        }
    }

    public function newAction()
    {
        $request = $this->getRequest();
        $form = new Default_Form_ArticuloProducto();

        if ($this->getRequest()->isPost()) {
            
            if ($form->isValid($request->getPost())) {

                try {

                    $art_producto = new Default_Model_ArticuloProducto();
                    $row = $art_producto->createRow();
                    $row->creador = $this->usuario->rut;
                    $row->producto = $form->getValue('producto');
                    $row->articulo = $form->getValue('articulo');
                    $row->unidades = (int)$form->getValue('unidades');
                    $row->descripcion = $form->getValue('descripcion');
                    $row->save();

                    $form->reset();
                    $form->producto->setValue($row->producto);

                    $aviso = '<div id="aviso-form" class="confirmacion"><ul>';
                    $aviso .= '<li>El artículo fue agregado de forma satisfactoria. </li>';
                    $aviso .= '</ul></div>';

                    echo $aviso.$form;

                } catch (Exception $e) {

                    $aviso = '<div id="aviso-form" class="error"><ul><li>Ocurrió un error el intentar agregar el artículo</li></ul></div>';

                }
            } else {
                $form->populate($request->getPost());
                echo $form;
            }
        }
    }

    public function editAction()
    {
        $request = $this->getRequest();
        $form = new Default_Form_ArticuloProducto();
        $form->id->setRequired(true);

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {

                    $art_producto = new Default_Model_ArticuloProducto();
                    $where = $art_producto->getAdapter()->quoteInto("id=?",$form->getValue('id'));
                    $row = $art_producto->fetchRow($where);
                    $row->creador = $this->usuario->rut;
                    $row->articulo = $form->getValue('articulo');
                    $row->unidades = (int)$form->getValue('unidades');
                    $row->descripcion = $form->getValue('descripcion');
                    $row->save();

                    $aviso = '<div id="aviso-form" class="confirmacion"><ul>';
                    $aviso .= '<li>El artículo fue editado de forma satisfactoria. </li>';
                    $aviso .= '</ul></div>';

                    echo $aviso;

                } catch (Exception $e) {

                    $aviso = '<div id="aviso-form" class="error"><ul><li>Ocurrió un error el intentar editar el artículo</li></ul></div>';

                }
            } else {
                $form->populate($request->getPost());
                echo $form;
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $producto = $this->_getParam('producto');

            if($this->_helper->validateRecordExists('productos', 'codigo', $producto)){

                $data = $this->_getParam('data');
                $items = explode(",", $data);

                $articuloProducto = new Default_Model_ArticuloProducto();

                foreach($items as $id){

                    if($this->_helper->validateRecordExists('articulos_productos', 'id', $id)){
                        $where = $articuloProducto->getAdapter()->quoteInto("id=?", $id);
                        $articuloProducto->delete($where);
                    }
                }
                return true;
            }
        }
    }
}