<?php
class BancoController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/banco';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $banco = new Default_Model_Banco();
            $bancos = $banco->fetchAll();

            $paginador = Zend_Paginator::factory($bancos);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->bancos = $paginador;
            $this->view->title = 'Bancos';

            $this->renderScript('banco/index.phtml');
        }

    }
    
    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_Banco(null, $this->path);

            if($this->_request->getParam('id')) {

                $banco = new Default_Model_Banco();
                $where = $banco->getAdapter()->quoteInto("id=?", (int)$this->_request->getParam('id'));
                $row = $banco->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/banco/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar banco";

            } else {

                $this->view->title = "Agregar banco";

            }
            $this->view->form = $form;
            $this->renderScript('banco/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Banco(null, $this->path);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $banco = new Default_Model_Banco();
                    $row = $banco->createRow();
                    $row->nombre = $form->getValue('nombre');
                    $row->save();

                    $mSession->mensajes[] = 'El banco fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el banco.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                }
                $this->_forward('index', 'banco');

            } else {
                $this->view->title = 'Agregar banco';
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('banco/form.phtml');
            }
        }
        $this->view->form = $form;
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $banco = new Default_Model_Banco();

        $request = $this->getRequest();
        $form = new Default_Form_Banco(null, $this->path);
        $form->setAction($this->path . '/edit');
        $form->submit->setLabel("guardar cambios");

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $where = $banco->getAdapter()->quoteInto("id=?", (int)$form->getValue('id'));
                    $row = $banco->fetchRow($where);
                    $row->nombre = $form->getValue('nombre');
                    $row->save();

                    $mSession->mensajes[] = 'El registro fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                }

                $this->_forward('index', 'banco');

            } else {
                $this->view->title = 'Editar banco';
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('banco/form.phtml');
            }
        } else {

            if ($this->_request->getParam('id')) {
                $where = $banco->getAdapter()->quoteInto("id=?", $this->_request->getParam('id'));
                $registro = $banco->fetchRow($where);
                $form->populate($registro->toArray());
            }
        }
        $this->view->form = $form;
    }


    public function deleteAction()
    {
        if($this->_getParam('id')){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            try {

                $model = new Default_Model_Banco();
                $where = $model->getAdapter()->quoteInto("id = ?" , (int)$this->_getParam('id'));
                $model->delete($where);

                $mSession->mensajes[] = 'El banco fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                
                $this->_forward('index','banco');

            } catch (Exception $e) {

                $mSession->tipo_error = 1;
                $mSession->errores[] = $e->getMessage();

                $this->_forward('error-delete-registro','error');

            }
        }
    }
}