<?php
class CajaChicaController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->path = '/caja-chica';
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $propietario = new Default_Model_Propietario();
        $this->view->propietario = $propietario->fetchRow();
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {

                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $caja = new Default_Model_VistaCajasChicasCiclosActivos();
            $cajas = $caja->fetchAll();

            $paginador = Zend_Paginator::factory($cajas);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->cajas = $paginador;
            $this->view->title = "Caja chica";
            $this->renderScript('caja-chica/index.phtml');
        }
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_CajaChica(null, $this->path);

            if($this->_request->getParam('id')) {

                $id = App_Rut::cleanToDb($this->_getParam('id'));
                $caja = new Default_Model_CajaChica();
                $where = $caja->getAdapter()->quoteInto("id=?", $id);
                $row = $caja->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/caja-chica/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar caja chica";

            } else {

                $this->view->title = "Crear caja chica";

            }
            $this->view->form = $form;
            $this->renderScript('caja-chica/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_CajaChica(null, $this->path);
        $this->view->title = "Agregar caja chica";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                $caja = new Default_Model_CajaChica();
                $db = $caja->getAdapter();
                $db->beginTransaction();

                try {

                    // creo la caja chica
                    $row = $caja->createRow();
                    $row->id = $form->getValue('responsable');
                    $row->monto_minimo = $form->getValue('monto_minimo');
                    $row->descripcion = $form->getValue('descripcion');
                    $row->save();

                    // Inicializo el primer ciclo
                    $ciclo = new Default_Model_CajaChicaCiclo();
                    $rowCiclo = $ciclo->createRow();
                    $rowCiclo->caja_id = $row->id;
                    $rowCiclo->fecha_inicio = date("Y-m-d H:i:s");
                    $rowCiclo->save();

                    $db->commit();

                    $mSession->mensajes[] = 'La caja chica fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view','caja-chica', null, array('id' => $row->id));

                } catch (Exception $e) {

                    $db->rollBack();
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la caja chica.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','caja-chica');
                }
            } else {

                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('caja-chica/form.phtml');
            }
        }
    }
    
    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = App_Rut::cleanToDb($this->_getParam('id'));

            $caja = new Default_Model_VistaCajasChicas();
            $whereCaja = $caja->getAdapter()->quoteInto("id=?", $id);
            $rowCaja = $caja->fetchRow($whereCaja);
            
            $ciclo = new Default_Model_VistaCajasChicasCiclos();
            $whereCiclo = $ciclo->getAdapter()->quoteInto("id=?", $rowCaja->ciclo_activo);
            $rowCiclo = $ciclo->fetchRow($whereCiclo);

            $this->view->title = 'Caja chica: ' . $rowCaja->id;
            $this->view->caja = $rowCaja;
            $this->view->ciclo = $rowCiclo;
            $this->renderScript('caja-chica/view.phtml');
        }
    }
   
    public function userAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $caja = new Default_Model_VistaCajasChicas();
            $whereCaja = $caja->getAdapter()->quoteInto("id=?", $this->usuario->rut);
            $rowCaja = $caja->fetchRow($whereCaja);

            $ciclo = new Default_Model_VistaCajasChicasCiclos();
            $whereCiclo = $ciclo->getAdapter()->quoteInto("id=?", $rowCaja->ciclo_activo);
            $rowCiclo = $ciclo->fetchRow($whereCiclo);

            $this->view->title = 'Caja chica: ' . $rowCaja->id;
            $this->view->caja = $rowCaja;
            $this->view->ciclo = $rowCiclo;
            $this->renderScript('caja-chica/user.phtml');
        }
    }

    public function lockAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $caja = new Default_Model_CajaChica();
            $id = (int)$this->_getParam('id');
            $where = $caja->getAdapter()->quoteInto("id=?",$id);
            $row = $caja->fetchRow($where);
            $row->estado = 'BLOQUEADA';
            $mSession->mensajes[] = 'La caja chica fue bloqueada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('index','caja-chica');
        }
    }

    public function unlockAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $caja = new Default_Model_CajaChica();
            $id = (int)$this->_getParam('id');
            $where = $caja->getAdapter()->quoteInto("id=?",$id);
            $row = $caja->fetchRow($where);
            $row->estado = 'HABILITADA';
            $mSession->mensajes[] = 'La caja chica fue habilitada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('index','caja-chica');
        }
    }

    public function deleteAction()
    {
        if($this->_getParam('id') AND
           $this->_helper->validateRecordExists('cc_cajas', 'id', $this->_getParam('id'))){
            
            $mSession = new Zend_Session_Namespace('expressauto');
            
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            try {

                $model = new Default_Model_CajaChica();
                $where = $model->getAdapter()->quoteInto("id = ?" , (int)$this->_getParam('id'));
                $model->delete($where);
                
                $mSession->mensajes[] = 'La caja chica fue eliminada de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_forward('index','caja-chica');

            } catch (Exception $e) {

                $mSession->tipo_error = 1;
                $mSession->errores[] = $e->getMessage();
                $this->_forward('error-delete-registro','error');
            }
        }
    }

    public function terminarCicloAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_helper->validateRecordExists('cc_cajas', 'id', $this->usuario->rut)){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $modelCaja = new Default_Model_VistaCajasChicas();
            $db = $modelCaja->getAdapter();
            $db->beginTransaction();

            try {

                // obtengo la caja
                $whereCaja = $modelCaja->getAdapter()->quoteInto("id=?", $this->usuario->rut);
                $rowCaja = $modelCaja->fetchRow($whereCaja);

                $cicloActivoId = $rowCaja->ciclo_activo;

                // obtengo y cierro el ciclo
                $modelCiclo = new Default_Model_CajaChicaCiclo();
                $whereCiclo = $modelCiclo->getAdapter()->quoteInto("id=?", $cicloActivoId);
                $rowCiclo = $modelCiclo->fetchRow($whereCiclo);
                $rowCiclo->fecha_termino = date("Y-m-d H:i:s");
                $rowCiclo->estado = "RENDIDO";
                $rowCiclo->save();

                // obtengo la vista del ciclo para ver los totales
                $modelVistaCiclo = new Default_Model_VistaCajasChicasCiclos();
                $rowVistaCiclo = $modelVistaCiclo->fetchRow($whereCiclo);

                $saldoEnCaja = $rowVistaCiclo->total_ingresos
                             - $rowVistaCiclo->total_egresos
                             + $rowVistaCiclo->total_retornos;
                $saldoEnCirculacion = $rowVistaCiclo->total_egresos
                                    - $rowVistaCiclo->total_rendiciones
                                    - $rowVistaCiclo->total_retornos;

                $saldoCicloAnterior = $saldoEnCaja + $saldoEnCirculacion;

                // abro el nuevo ciclo
                $rowNuevoCiclo = $modelCiclo->createRow();
                $rowNuevoCiclo->caja_id = $this->usuario->rut;
                $rowNuevoCiclo->fecha_inicio = date("Y-m-d H:i:s");
                $rowNuevoCiclo->save();

                // obtengo los egresos activos
                $modelEgresoActivo = new Default_Model_VistaCajasChicasEgresosActivos();
                $rowsEgresoActivo = $modelEgresoActivo->fetchAll();

                foreach($rowsEgresoActivo as $egresoActivo){

                    // genero nuevo egresos en el nuevo ciclo con los saldos pendientes
                    $modelEgreso                    = new Default_Model_CajaChicaEgreso();
                    $rowNuevoEgreso                 = $modelEgreso->createRow();
                    $rowNuevoEgreso->ciclo_id       = $rowNuevoCiclo->id;
                    $rowNuevoEgreso->entregado_a    = $egresoActivo->entregado_a;

                    if(!is_numeric($egresoActivo->rendido)){
                        $rowNuevoEgreso->cantidad   = $egresoActivo->egreso;
                    } else {
                        $rowNuevoEgreso->cantidad   = $egresoActivo->egreso - $egresoActivo->rendido;
                    }

                    $rowNuevoEgreso->fecha          = date("Y-m-d H:i:s");
                    $rowNuevoEgreso->detalles       = $egresoActivo->detalles;
                    $rowNuevoEgreso->save();
                }

                // cierro los egresos del ciclo anterior
                $whereEgresosActivosAnteriores = "estado='0' AND ciclo_id='" . $cicloActivoId . "'";
                $data = array('estado' => '1');
                $db->update('cc_egresos', $data, $whereEgresosActivosAnteriores);

                // hago el primer ingreso de dinero del nuevo ciclo
                $modelNuevoIngreso = new Default_Model_CajaChicaIngreso();
                $rowNuevoIngreso = $modelNuevoIngreso->createRow();
                $rowNuevoIngreso->ciclo_id = $rowNuevoCiclo->id;
                $rowNuevoIngreso->tipo_id = 1;
                $rowNuevoIngreso->cantidad = $saldoCicloAnterior;
                $rowNuevoIngreso->estado = "RECIBIDO";
                $rowNuevoIngreso->save();

                $db->commit();

                $mSession->mensajes[] = 'La rendición fue terminada de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_forward('user', 'caja-chica');

            } catch (Exception $e) {

                $db->rollBack();

               var_dump($e->getMessage());
            }
        }
    }

    public function formConsultaAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            if($this->_getParam('type_user')=='a') {

                if($this->_getParam('id')!='0' &&
                   $this->_helper->validateRecordExists('cc_cajas', 'id', App_Rut::cleanToDb($this->_getParam('id')))) {
                    $this->view->caja_id = App_Rut::cleanToDb($this->_getParam('id'));
                }
                
                $this->view->cajas = Default_Model_VistaCajasChicas::getPairsToSelect();
                $this->view->back = '/caja-chica/view/' . App_Rut::cleanToDb($this->_getParam('id'));
                $this->view->user = 'a';

            } elseif($this->_getParam('type_user')=='u') {
                
                $this->view->back = '/caja-chica/user';
                $this->view->user = 'u';

            }
            $this->view->title = "Consultar rendiciones de caja";
            $this->renderScript('caja-chica/form-consulta.phtml');
        }
    }

    public function consultaAction()
    {
        if($_POST) {

            $model = new Default_Model_VistaCajasChicasCiclos();

            if($this->_getParam('type_user')=='u'){

                $where = "caja_id='" . $this->usuario->rut . "'";
                $consulta = "/egreso-caja-chica/form-consulta/0/u";
                
            } elseif($this->_getParam('type_user')=='a') {

                $consulta = "/egreso-caja-chica/form-consulta/0/a";
                if($this->_getParam('caja_id')!='0'){
                    $where = "caja_id='" . $this->_getParam('caja_id') . "'";
                } else {
                    $where = "caja_id IS NOT NULL";
                }
                
            } else {
                return false;
            }

            // filtro por fechas
            $fecha_i = $this->_getParam('fecha_i');
            $fecha_t = $this->_getParam('fecha_t');

            if(Zend_Date::isDate($fecha_i . ' 00:00:00', Zend_Date::ISO_8601)) {
                $fecha_i = $fecha_i . ' 00:00:00';
                $where .= " AND fecha > '" . $fecha_i . "'";
            }

            if(Zend_Date::isDate($fecha_t . ' 23:59:59', Zend_Date::ISO_8601)) {
                $fecha_t = $fecha_t . ' 23:59:59';
                $where .= " AND fecha < '" . $fecha_t . "'";
            }

            $where .= " AND estado='RENDIDO'";

            $rows = $model->fetchAll($where);
            $this->view->rendiciones = $rows;
            $this->view->back = $this->_getParam('back');
            $this->view->user = $this->_getParam('type_user');
            $this->view->title = "Consultar rendiciones de caja";
            $this->renderScript('caja-chica/resultados-busqueda.phtml');
            
        } else {
            $this->_forward("form-consulta", "caja-chica");
        }
    }

    public function informePreliminarAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND 
           $this->_helper->validateRecordExists('cc_cajas', 'id', $this->usuario->rut)){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $modelCaja = new Default_Model_VistaCajasChicas();
            $whereCaja = $modelCaja->getAdapter()->quoteInto("id=?", $this->usuario->rut);
            $rowCaja = $modelCaja->fetchRow($whereCaja);

            $modelCiclo = new Default_Model_VistaCajasChicasCiclos();
            $whereCiclo = $modelCiclo->getAdapter()->quoteInto("id=?", $rowCaja->ciclo_activo);
            $rowCiclo = $modelCiclo->fetchRow($whereCiclo);

            $modelIngreso = new Default_Model_VistaCajasChicasIngresos();
            $whereIngreso = $modelIngreso->getAdapter()->quoteInto("ciclo_id=?", $rowCiclo->id);
            $rowsIngresos = $modelIngreso->fetchAll($whereIngreso);

            $modelEgresoActivo = new Default_Model_VistaCajasChicasEgresos();
            $whereEgresoActivo = "estado='0' AND caja_id='". $this->usuario->rut ."'";
            $rowsEgresosActivos = $modelEgresoActivo->fetchAll($whereEgresoActivo);

            $modelRendicion = new Default_Model_VistaCajasChicasRendiciones();
            $whereRendicion = $modelRendicion->getAdapter()->quoteInto("ciclo_id=?", $rowCiclo->id);
            $rowsRendiciones = $modelRendicion->fetchAll($whereRendicion);

            $this->view->title = "Informe preliminar rendición caja chica";
            $this->view->caja = $rowCaja;
            $this->view->ciclo = $rowCiclo;
            $this->view->ingresos = $rowsIngresos;
            $this->view->pendientes = $rowsEgresosActivos;
            $this->view->rendiciones = $rowsRendiciones;
            $this->renderScript('caja-chica/informe-preliminar.phtml');

        }
    }

    public function rendicionAction()
    {
        if($this->_getParam('id') &&
           $this->_helper->validateRecordExists('cc_ciclos_cajas', 'id', $this->_getParam('id'))){

            $id = (int)$this->_getParam('id');

            $rendicion = $this->_getRendicion($id);

            $this->view->caja = $rendicion['caja'];
            $this->view->ciclo = $rendicion['ciclo'];
            $this->view->ingresos = $rendicion['ingresos'];
            $this->view->rendiciones = $rendicion['rendiciones'];

            if($this->_getParam('type_user')=='a') {
                $back = '/caja-chica/view/' . $rendicion['caja']->id;
            } else {
                $id = $this->usuario->rut;
                $back = '/caja-chica/user';
            }

            $this->view->back = $back;

            $this->view->title = "Informe de rendición de caja chica";
            $this->renderScript('caja-chica/informe-rendicion.phtml');


        } else {
            // envio al error controller acceso inválido
        }
    }

    public function ultimaRendicionAction()
    {
        if($this->_getParam('id')) {
            $id     = $this->_getParam('id');
            $user   = 'a';
        } else {
            $id     = $this->usuario->rut;
            $user   = 'u';
        }
        
        if($this->_helper->validateRecordExists('cc_cajas', 'id', $id)){
            $ultimaRendicionId = $this->_getUltimaRendicionId($id);

            $this->_forward('rendicion', 'caja-chica', null, array(
                'id' => $ultimaRendicionId,
                'user' => $user
            ));

        } else {
            // envio al error controller acceso inválido
        }
    }

    public function printInformePreliminarAction()
    {
        if($this->_helper->validateRecordExists('cc_cajas', 'id', $this->usuario->rut)){
           
            $this->_helper->layout->disableLayout(false);
            $this->_helper->viewRenderer->setNoRender(false);
            $this->_helper->layout->setLayout('print');
            
            $modelCaja = new Default_Model_VistaCajasChicas();
            $whereCaja = $modelCaja->getAdapter()->quoteInto("id=?", $this->usuario->rut);
            $rowCaja = $modelCaja->fetchRow($whereCaja);

            $modelCiclo = new Default_Model_VistaCajasChicasCiclos();
            $whereCiclo = $modelCiclo->getAdapter()->quoteInto("id=?", $rowCaja->ciclo_activo);
            $rowCiclo = $modelCiclo->fetchRow($whereCiclo);

            $modelIngreso = new Default_Model_VistaCajasChicasIngresos();
            $whereIngreso = $modelIngreso->getAdapter()->quoteInto("ciclo_id=?", $rowCaja->ciclo_activo);
            $rowsIngresos = $modelIngreso->fetchAll($whereIngreso);

            $modelEgresoActivo = new Default_Model_VistaCajasChicasEgresos();
            $whereEgresoActivo = "estado='0' AND caja_id='". $rowCiclo->caja_id ."'";
            $rowsEgresosActivos = $modelEgresoActivo->fetchAll($whereEgresoActivo);

            $modelRendicion = new Default_Model_VistaCajasChicasRendiciones();
            $whereRendicion = $modelRendicion->getAdapter()->quoteInto("ciclo_id=?", $rowCaja->ciclo_activo);
            $rowsRendiciones = $modelRendicion->fetchAll($whereRendicion);

            $this->view->title = "Informe de rendición de caja chica";
            $this->view->caja = $rowCaja;
            $this->view->ciclo = $rowCiclo;
            $this->view->ingresos = $rowsIngresos;
            $this->view->pendientes = $rowsEgresosActivos;
            $this->view->rendiciones = $rowsRendiciones;
        }
    }

    public function printRendicionAction()
    {
        if($this->_getParam('id') &&
           $this->_helper->validateRecordExists('cc_ciclos_cajas', 'id', $this->_getParam('id'))){

            $this->_helper->layout->disableLayout(false);
            $this->_helper->viewRenderer->setNoRender(false);
            $this->_helper->layout->setLayout('print');
            
            $rendicion = $this->_getRendicion((int)$this->_getParam('id'));
            
            $this->view->caja = $rendicion['caja'];
            $this->view->ciclo = $rendicion['ciclo'];
            $this->view->ingresos = $rendicion['ingresos'];
            $this->view->rendiciones = $rendicion['rendiciones'];

            $this->view->title = "Informe de rendición de caja chica";
        }
    }

    private function _getUltimaRendicionId($caja_id)
    {
        $model = new Default_Model_CajaChicaCiclo();
        $where = $model->getAdapter()->quoteInto("estado='RENDIDO' AND caja_id=?", $caja_id);
        $row = $model->fetchRow($where);
        return $row->id;
    }

    private function _getRendicion($ciclo_id)
    {
        $rendicion = array();

        $modelCiclo = new Default_Model_VistaCajasChicasCiclos();
        $whereCiclo = $modelCiclo->getAdapter()->quoteInto("id=?", $ciclo_id);
        $rendicion['ciclo'] = $modelCiclo->fetchRow($whereCiclo);

        if($rendicion['ciclo']->estado=='ACTIVO'){
            return false;
        }

        $modelCaja = new Default_Model_VistaCajasChicas();
        $whereCaja = $modelCaja->getAdapter()->quoteInto("id=?", $rendicion['ciclo']->caja_id);
        $rendicion['caja'] = $modelCaja->fetchRow($whereCaja);

        $modelIngreso = new Default_Model_VistaCajasChicasIngresos();
        $whereIngreso = $modelIngreso->getAdapter()->quoteInto("ciclo_id=?", $ciclo_id);
        $rendicion['ingresos'] = $modelIngreso->fetchAll($whereIngreso);

        $modelRendicion = new Default_Model_VistaCajasChicasRendiciones();
        $whereRendicion = $modelRendicion->getAdapter()->quoteInto("ciclo_id=?", $ciclo_id);
        $rendicion['rendiciones'] = $modelRendicion->fetchAll($whereRendicion);

        return $rendicion;
    }
}