<?php
class CategoriaArticuloController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/categoria-articulo';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
       if($this->getRequest()->isXmlHttpRequest()){

           $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            
            $currentPage = $this->_getParam('page', 1);

            $categoria = new Default_Model_VistaCategoriasArticulos();
            $categorias = $categoria->fetchAll();

            $paginador = Zend_Paginator::factory($categorias);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->categorias = $paginador;
            $this->view->title = 'Categorías de artículos';

            $this->renderScript('categoria-articulo/index.phtml');
       }
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_CategoriaArticulo(null, $this->path);

            if($this->_request->getParam('id')) {

                $categoria = new Default_Model_CategoriaArticulo();
                $where = $categoria->getAdapter()->quoteInto("id=?", $this->_request->getParam('id'));
                $row = $categoria->fetchRow($where)->toArray();
                $form->populate($row);
                $form->id->setAttrib('disabled','disabled');
                $form->setAction('/categoria-articulo/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar categoría de artículos";

            } else {

                $this->view->title = "Crear categoría de artículos";

            }
            $this->view->form = $form;
            $this->renderScript('categoria-articulo/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Default_Form_CategoriaArticulo(null, $this->path);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    $categoria = new Default_Model_CategoriaArticulo();
                    $row = $categoria->createRow();
                    $row->id = $form->getValue('id');
                    if($form->getValue('padre_id')!='0') {
                        $row->padre_id = $form->getValue('padre_id');
                    } else {
                        $row->padre_id = NULL;
                    }

                    $row->nombre = $form->getValue('nombre');

                    if($form->getValue('descripcion')!=''){
                        $row->descripcion = $form->getValue('descripcion');
                    } else {
                        $row->descripcion = NULL;
                    }
                    
                    $row->save();

                    $mSession->mensajes[] = 'El registro fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                }
                $this->_forward('index', 'categoria-articulo');

            } else {
                $this->view->title = 'Crear categoría de artículos';
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('categoria-articulo/form.phtml');
            }
        }
        $this->view->form = $form;
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $categoria = new Default_Model_CategoriaArticulo();

        $request = $this->getRequest();
        $form = new Default_Form_CategoriaArticulo();
        $form->setAction($this->path . '/edit');
        $form->submit->setLabel("guardar cambios");

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $where = $categoria->getAdapter()->quoteInto("id=?", (int)$form->getValue('id'));
                    $row = $categoria->fetchRow($where);
                    if($form->getValue('padre_id')!='0') {
                        $row->padre_id = $form->getValue('padre_id');
                    } else {
                        $row->padre_id = NULL;
                    }
                    
                    $row->nombre = $form->getValue('nombre');

                    if($form->getValue('descripcion')!=''){
                        $row->descripcion = $form->getValue('descripcion');
                    } else {
                        $row->descripcion = NULL;
                    }

                    $row->save();

                    $mSession->mensajes[] = 'El registro fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                }

                $this->_forward('index', 'categoria-articulo');

            } else {
                $this->view->title = 'Editar categoría de artículos';
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('categoria-articulo/form.phtml');
            }
        } else {

            if($this->_request->getParam('id')) {

                $where = $categoria->getAdapter()->quoteInto("id=?", (int)$this->_request->getParam('id'));
                $registro = $categoria->fetchRow($where);
                $form->populate($registro->toArray());

            }
        }
        $this->view->form = $form;
    }

    public function deleteAction()
    {
        if($this->_getParam('id')){
            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            try {

                $model = new Default_Model_CategoriaArticulo();
                $where = $model->getAdapter()->quoteInto("id = ?" , (int)$this->_getParam('id'));
                $model->delete($where);
                
                $mSession->mensajes[] = 'La categoría fue eliminada de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_forward('index','categoria-articulo');

            } catch (Exception $e) {

                $mSession->tipo_error = 1;
                $mSession->errores[] = $e->getMessage();

                $this->_forward('error-delete-registro','error');

            }
            
        }
    }

}