<?php
class ClienteController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->path = '/cliente';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {

                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);
            $cliente = new Default_Model_VistaClientes();
            $clientes = $cliente->fetchAll();

            $paginador = Zend_Paginator::factory($clientes);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->clientes = $paginador;
            $this->view->title = "Clientes";
            $this->renderScript('cliente/index.phtml');
        }
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_Cliente(null, $this->path);

            if($this->_getParam('id') &&
               $this->_helper->validateRecordExists('clientes', 'rut', $this->_getParam('id'))) {

                $rut = App_Rut::cleanToDb($this->_getParam('id'));
                $cliente = new Default_Model_Cliente();
                $where = $cliente->getAdapter()->quoteInto("rut=?", $rut);
                $row = $cliente->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/cliente/edit');
                $form->id->setValue($rut);
                $form->submit->setLabel('Guardar cambios');

                if($this->_checkUsuarioWeb($rut)){
                    $form->copiar->setAttrib('disabled', 'disabled');
                    $form->nombre_web->setAttrib('disabled', 'disabled');
                    $form->telefono_web->setAttrib('disabled', 'disabled');
                    $form->mail_web->setAttrib('disabled', 'disabled');
                }

                $this->view->title = "Editar cliente";

            } else {

                $this->view->title = "Agregar cliente";

            }
            $this->view->form = $form;
            $this->renderScript('cliente/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Cliente(null, $this->path);
        $this->view->title = "Crear cliente";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $cliente = new Default_Model_Cliente();
                    $db = $cliente->getAdapter();

                    $db->beginTransaction();

                    $row = $cliente->createRow();
                    $row->rut = App_Rut::cleanToDb($form->getValue('rut'));
                    $row->nombre = ucwords($form->getValue('nombre'));
                    $row->direccion = $form->getValue('direccion');
                    $row->comuna = $form->getValue('comuna');
                    $row->ciudad = $form->getValue('ciudad');
                    $row->telefono = $form->getValue('telefono');
                    $row->mail = $form->getValue('mail');
                    $row->web = $form->getValue('web');
                    $row->estado_registro = 1;
                    $row->save();

                    if($form->getValue('nombre_web')!='' &&
                       $form->getValue('telefono_web') &&
                       $form->getValue('mail_web')){

                        $semilla = $row->rut . 'suma';
                        $suma = md5($semilla);
                        $usuario = new Default_Model_UsuarioWeb();
                        $rowUsuario = $usuario->createRow();

                        $rowUsuario->cliente = $row->rut;
                        $rowUsuario->nombre = $form->getValue('nombre_web');
                        $rowUsuario->mail = $form->getValue('mail_web');
                        $rowUsuario->telefono = $form->getValue('telefono_web');
                        $rowUsuario->tipo = 'ADMINISTRADOR';
                        $rowUsuario->clave = '000000';
                        $rowUsuario->super_admin = 1;
                        $rowUsuario->save();

                        $enlace = 'http://www.expressauto.cl/registro/d/' . $rowUsuario->id  . '/' . $rowUsuario->cliente . '/' . $suma ;
                        $mail = new App_HtmlMailer('UTF-8');
                        $mail->setSubject('Confirmación de registro')
                             ->addTo($row->mail)
                             ->setViewParam('enlace', $enlace)
                             ->setViewParam('nombre', $rowUsuario->nombre)
                             ->sendHtmlTemplate('confirmacion-registro.phtml');
                    }

                    $db->commit();



                    $mSession->mensajes[] = 'El cliente fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view','cliente', null, array('id' => $row->rut));

                } catch (Exception $e) {

                    $db->rollBack();

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el cliente.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','cliente');
                }
            } else {

                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('archivos-comunes/form.phtml');
            }
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $cliente = new Default_Model_Cliente();

        $request = $this->getRequest();
        $form = new Default_Form_Cliente();
        $form->id->setRequired(true);

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {

                    $rut = App_Rut::cleanToDb($form->getValue('id'));
                    $where = $cliente->getAdapter()->quoteInto("rut=?", $rut);
                    $row = $cliente->fetchRow($where);
                    $row->rut = App_Rut::cleanToDb($form->getValue('rut'));
                    $row->nombre = $form->getValue('nombre');
                    $row->direccion = $form->getValue('direccion');
                    $row->comuna = $form->getValue('comuna');
                    $row->ciudad = $form->getValue('ciudad');
                    $row->telefono = $form->getValue('telefono');
                    $row->mail = $form->getValue('mail');
                    $row->web = $form->getValue('web');
                    $row->save();

                    if($form->getValue('nombre_web')!='' &&
                       $form->getValue('telefono_web') &&
                       $form->getValue('mail_web')){

                        $semilla = $row->rut . 'suma';
                        $suma = md5($semilla);
                        $usuario = new Default_Model_UsuarioWeb();
                        $rowUsuario = $usuario->createRow();

                        $rowUsuario->cliente = $row->rut;
                        $rowUsuario->nombre = $form->getValue('nombre_web');
                        $rowUsuario->mail = $form->getValue('mail_web');
                        $rowUsuario->telefono = $form->getValue('telefono_web');
                        $rowUsuario->tipo = 'ADMINISTRADOR';
                        $rowUsuario->clave = '000000';
                        $rowUsuario->super_admin = 1;
                        $rowUsuario->save();

                        $enlace = 'http://www.expressauto.cl/registro/d/' . $rowUsuario->id  . '/' . $rowUsuario->cliente . '/' . $suma ;
                        $mail = new App_HtmlMailer('UTF-8');
                        $mail->setSubject('Confirmación de registro')
                             ->addTo($row->mail)
                             ->setViewParam('enlace', $enlace)
                             ->setViewParam('nombre', $rowUsuario->nombre)
                             ->sendHtmlTemplate('confirmacion-registro.phtml');
                    }

                    $mSession->mensajes[] = 'El cliente fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view', 'cliente', null, array('id'=> $row->rut));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','cliente');
                }

            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/cliente/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar cliente";
                $this->renderScript('archivos-comunes/form.phtml');
            }
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $rut = App_Rut::cleanToDb($this->_getParam('id'));
            $cliente = new Default_Model_VistaClientes();
            $where = $cliente->getAdapter()->quoteInto("rut=?", $rut);

            $usuario = new Default_Model_VistaUsuariosWeb();
            $whereUsuario = $usuario->getAdapter()->quoteInto("cliente=?", $rut);
            $usuarios = $usuario->fetchAll($whereUsuario);

            $infoFacturacion = new Default_Model_ClienteInfoFacturacion();
            $whereInfoFacturacion = $infoFacturacion->getAdapter()->quoteInto("cliente=?", $rut);
            $rowInfoFacturacion = $infoFacturacion->fetchRow($whereInfoFacturacion);

            $this->view->cliente = $cliente->fetchRow($where);
            $this->view->usuarios = $usuarios;
            $this->view->infoFacturacion = $rowInfoFacturacion;
            $this->view->title = 'Cliente : ' . $this->view->cliente->nombre;
            $this->renderScript('cliente/view.phtml');
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest() &&
           $this->_getParam('id') &&
           $this->_helper->validateRecordExists('vista_clientes', 'rut', App_Rut::cleanToDb($this->_getParam('id')))){

            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            try {

                $rut = App_Rut::cleanToDb($this->_getParam('id'));
                $cliente = new Default_Model_Cliente();
                $where = $cliente->getAdapter()->quoteInto('rut = ?' , $rut);
                $cliente->delete($where);
                $mSession->mensajes[] = 'El cliente fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_forward('index','cliente');

            } catch (Exception $e) {

                $mSession->error['mensajes'][]      = $e->getMessage();
                $mSession->error['tipo']            = 1;
                $mSession->error['registro_id']     = $rut;
                $mSession->error['registro_tabla']  = 'clientes';
                $this->_forward('error-delete-registro','error');

            }

            
        }
    }

    public function ajustarLineaCreditoAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('rut') AND
           $this->_helper->validateRecordExists('clientes', 'rut', App_Rut::cleanToDb($this->_getParam('rut')))){

            $rut = App_Rut::cleanToDb($this->_getParam('rut'));
            $valor = (int)$this->_getParam('valor');

            try {

                $cliente = new Default_Model_Cliente();
                $where = $cliente->getAdapter()->quoteInto("rut=?", $rut);
                $row = $cliente->fetchRow($where);
                $row->monto_linea_credito = $valor;
                $row->save();

                $data = array();
                $data['mensaje'] = array("valor" => "Valor guardado", "style" => "color:green;");
                $data['valores'] = 0;

                echo Zend_Json_Encoder::encode($data);

            } catch (Exception $e) {

                echo '<span style="color:red;">No se pudo guardar el nuevo valor</span>';
            }
        }
    }

    public function ajustarPlazoPagoMaxAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('rut') AND
           $this->_helper->validateRecordExists('clientes', 'rut', App_Rut::cleanToDb($this->_getParam('rut')))){

            $rut = App_Rut::cleanToDb($this->_getParam('rut'));
            $valor = (int)$this->_getParam('valor');

            try {

                $cliente = new Default_Model_Cliente();
                $where = $cliente->getAdapter()->quoteInto("rut=?", $rut);
                $row = $cliente->fetchRow($where);
                $row->plazo_pago_max = $valor;
                $row->save();

                $data = array();
                $data['mensaje'] = array("valor" => "Valor guardado", "style" => "color:green;");
                $data['valores'] = 0;

                echo Zend_Json_Encoder::encode($data);

            } catch (Exception $e) {

                echo '<span style="color:red;">No se pudo guardar el nuevo valor</span>';
            }
        }
    }

    public function setTipoAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('clientes', 'rut', App_Rut::cleanToDb($this->_getParam('id')))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $rut = App_Rut::cleanToDb($this->_getParam('id'));
            $tipo = $this->_getParam('tipo');

            $tipos = array('MONOUSUARIO','MULTIUSUARIO');

            if(in_array($tipo, $tipos)) {

                $model = new Default_Model_Cliente();
                $where = $model->getAdapter()->quoteInto("rut=?", $rut);
                $cliente = $model->fetchRow($where);
                $cliente->tipo_acceso_web = $tipo;
                $cliente->save();
                
            }
            $this->_forward('view', 'cliente', null, array('id' => $rut));
        }
    }

    public function estadoCuentaAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('clientes', 'rut', App_Rut::cleanToDb($this->_getParam('id')))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $this->view->title = "Estado de cuenta";
            $this->renderScript('cliente/estado-cuenta.phtml');

        }
    }

    public function getFormInfoFacturacionAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_ClienteInfoFacturacion(null, $this->path);

            if($this->_getParam('id')) {

                $rut = App_Rut::cleanToDb($this->_request->getParam('id'));
                $infoFacturacion = new Default_Model_ClienteInfoFacturacion();
                $where = $infoFacturacion->getAdapter()->quoteInto("cliente=?", $rut);
                $row = $infoFacturacion->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/info-facturacion/edit');
                $form->rut->setValue($rut);
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar cliente";

            } else {

                $this->view->title = "Agregar cliente";

            }
            $this->view->form = $form;
            $this->renderScript('cliente/form.phtml');
        }
    }

    public function searchTooltipAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $cliente = new Default_Model_VistaClientes();

            $filter_tags    = new Zend_Filter_StripTags();
            $criterio       = $filter_tags->filter(trim($this->_getParam('criterio')));
            $valor          = $filter_tags->filter(trim($this->_getParam('valor')));
            $this->view->t  = $filter_tags->filter(trim($this->_getParam('t')));

            if($criterio!='' AND $valor!='') {

                if($criterio=='rut') {

                    $valor = App_Rut::cleanToDb($valor);
                    $where = "$criterio='$valor'";

                } else {

                    $where = "$criterio LIKE '%$valor%'";
                }

                $this->view->clientes = $cliente->fetchAll($where)->toArray();
            }

            $this->renderScript('cliente/search.phtml');
        }
    }

    public function viewSmallAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            if($this->_getParam('id')) {

                $this->view->t  = $this->_getParam('type_user');
                $rut = App_Rut::cleanToDb($this->_getParam('id'));
                $cliente = new Default_Model_VistaClientes();
                $where = $cliente->getAdapter()->quoteInto("rut=?", $rut);
                $this->view->cliente = $cliente->fetchRow($where)->toArray();
                $this->renderScript('cliente/view-tooltip.phtml');

            }
        }
    }

    private function _checkUsuarioWeb($cliente)
    {
        $usuario = new Default_Model_UsuarioWeb();
        $where = $usuario->getAdapter()->quoteInto("cliente=?", $cliente);
        $usuarios = $usuario->fetchAll($where);
        
        if(NULL!==$usuarios && count($usuarios) > 0 ){
            return true;
        }
        return false;
    }
}