<?php
class ContactoController extends Zend_Controller_Action
{
    public function init()
    {
         $auth = Zend_Auth::getInstance();

        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->path  = '/contacto';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();

            $contacto = new Default_Model_VistaContactos();
            $this->view->contactos = $contacto->fetchAll();
        } else {
            $this->_redirect('/index/error');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $this->_helper->layout->disableLayout();

        $request = $this->getRequest();
        $form = new Default_Form_Contacto(null, $this->path);

        if($this->getRequest()->isXmlHttpRequest()){

            $id = $this->_request->getParam('id');
            $tr = $this->_request->getParam('tr');

            if(isset($id) AND isset($tr)) {
                $form->referencia_id->setValue($id);
                $form->tabla->setValue($tr);
            }

            $this->view->form = $form;
            //$this->view->formCatContacto = $formCatContacto;

            $this->renderScript('contacto/new.phtml');

        } elseif ($this->getRequest->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    
                    $contacto = new Default_Model_Contacto();
                    $row = $contacto->createRow();
                    $row->categoria_id = $form->getValue('categoria_id');
                    $row->nombre = $form->getValue('nombre');
                    $row->mail = $form->getValue('mail');
                    $row->telefono = $form->getValue('telefono');
                    $row->movil = $form->getValue('movil');
                    $row->fax = $form->getValue('fax');
                    $row->direccion = $form->getValue('direccion');
                    $row->ciudad = $form->getValue('ciudad');
                    $row->observaciones= $form->getValue('observaciones');
                    $row->etiquetas = $form->getValue('etiquetas');
                    $row->save();

                    $contacto_id = $row->id;

                    if(($form->getValue('tabla')!='') AND ($form->getValue('referencia_id')!='')){

                        $referencia = new Default_Model_ReferenciaContacto();
                        $row_ref = $referencia->createRow();
                        $row_ref->contacto_id = $contacto_id;
                        $row_ref->tabla = $form->getValue('tabla');
                        $row_ref->referencia_id = $form->getValue('referencia_id');
                        $row_ref->save();

                    }

                    $mSession->mensajes[] = 'El contacto fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el contacto.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                }

            } else {

                $form->populate($formData);

            }
        }            
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $id = (int)$this->_request->getParam('id');
            $contacto = new Default_Model_VistaContactos();
            $this->view->contacto = $contacto->fetchRow('id='.$id);

            if(false==$this->view->contacto) {
                $this->_redirect($this->path . '/list');
            }
            $this->renderScript('contacto/view-tooltip.phtml');
        } else {
            $this->_forward('logout', 'index');
        }

    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $this->view->titulo_pagina = "Contactos";

        $form = new ContactoForm(null, $this->path);
        $form->setAction($this->view->baseUrl(). $this->path . '/edit');
        $form->submit->setLabel("guardar cambios");

        if ($this->_request->isPost()) {
            $formData = $this->_request->getPost();
            if ($form->isValid($formData)) {
                
                try {
                    $id = $form->getValue('id');
                    $contacto = new Contacto();
                    $row = $contacto->fetchRow('id='.$id);
                    $row->categoria_id = $form->getValue('categoria_id');
                    $row->nombre = $form->getValue('nombre');
                    $row->mail = $form->getValue('mail');
                    $row->telefono = $form->getValue('telefono');
                    $row->movil = $form->getValue('movil');
                    $row->fax = $form->getValue('fax');
                    $row->direccion = $form->getValue('direccion');
                    $row->ciudad = $form->getValue('ciudad');
                    $row->observaciones= $form->getValue('observaciones');
                    $row->etiquetas = $form->getValue('etiquetas');
                    $row->save();
                    $mSession->mensajes[] = 'El registro fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    
                } catch (Exception $e) {                   
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';                 
                }
                $this->_redirect($this->path . '/view/id/'.$id);
            }
        } else {
            $id = (int)$this->_request->getParam('id', 0);
            if ($id > 0) {
                $contacto = new Contacto();
                $registro = $contacto->fetchRow('id='.$id);
                $this->view->contacto = $registro;
                $form->populate($registro->toArray());
            }
        }
        $this->view->form = $form;
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $form = new DeleteForm();
        $form->setAction($this->view->baseUrl() . $this->path . '/delete');

        $this->view->titulo_pagina = "Contactos";


        if ($this->_request->isPost()) {
            $formData = $this->_request->getPost();
            if ($form->isValid($formData)) {
                $contacto = new Contacto();
                $where = 'id = '. $form->getValue('id');
                $contacto->delete($where);
                $mSession->mensajes[] = 'El registro fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_redirect($this->path . '/list');
            }
        } else {
            $id = (int)$this->_request->getParam('id', 0);
            if ($id > 0) {
                $contacto = new Contacto();
                $this->view->contacto = $contacto->fetchRow('id='.$id);
                $form->id->setValue($id);
            }
        }
        $this->view->form = $form;
    }
    /*
    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $form = new BuscarContactoForm(null, $this->path);
  
        $url = $_SERVER['HTTP_REFERER'];
        $clave = $this->_request->getPost('clave');  
        $buscar_por = $this->_request->getPost('buscar_por');    
        $contactos = new VistaContactos(); 

        if(($clave!='') AND ($clave!='Palabra(s) clave')) {     
            switch($buscar_por) {
                case "nombre" :
                    $where = "nombre LIKE '%$clave%' ";
                    break;
                case "mail" :
                    $where = "mail LIKE '%$clave%' ";
                    break;    
                case "direccion" :
                    $where = "direccion LIKE '%$clave%' ";  
                    break;
                case "ciudad" :
                    $where = "ciudad LIKE '%$clave%' ";
                    break;
                case "etiquetas" :
                    $where = "etiquetas LIKE '%$clave%' "; 
                    break;
                default :
                    $this->_redirect($this->path .'/list');
                    break;         
            } 
        } else {
            $this->_redirect($url);
        }
        
        $this->view->contactos = $contactos->fetchAll($where);
        $this->view->clave = $clave;
        $this->view->num_found = count($this->view->contactos);
        $this->view->form = $form;
    }*/
    /*
    public function findAction()
    {
            $db = Zend_Db_Table::getDefaultAdapter();
            $name = $this->_getParam('name');
            $contactos = $db->fetchAll("SELECT * FROM contactos WHERE nombre LIKE '%$name%'");
            echo Zend_Json_Encoder::encode($contactos);
    }
    */
    public function searchTooltipAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $contacto = new Default_Model_VistaContactos();
            $name = $this->_getParam('name');
            $where = "nombre LIKE '%$name%' OR ref_nombre LIKE '%$name%'";
            $this->view->contactos = $contacto->fetchAll($where);
            $this->renderScript('contacto/search.phtml');
        }
    }
}