<?php
class CotizacionController extends Zend_Controller_Action
{
    public function init()
    {
        $action = $this->getRequest()->getActionName();
        if($action != 'export-pdf' AND $action != 'create-pdf'){
            $auth = Zend_Auth::getInstance();
            if (!$auth->hasIdentity()) {
                $this->_redirect('/index/exit');
            }
        }
        $this->path = '/cotizacion';
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->preferencias = Default_Model_Cotizacion::_getPrefs();
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->porcentaje_recargo = Default_Model_FormaPago::getPorcentajeRecargo();
        $propietario = new Default_Model_Propietario();
        $this->view->propietario = $propietario->fetchRow();
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $cotizacion = new Default_Model_VistaCotizaciones();
            $cotizaciones = $cotizacion->fetchAll();

            $paginador = Zend_Paginator::factory($cotizaciones);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->cotizaciones = $paginador;
            $this->view->title = 'Cotizaciones';
            $this->renderScript('cotizacion/index.phtml');
        }
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_Cotizacion(null, $this->path);

            if($this->_getParam('id')) {

                $cotizacion = new Default_Model_Cotizacion();
                $id = (int)$this->_request->getParam('id');
                $where= $cotizacion->getAdapter()->quoteInto("id=?", $id);
                $row = $cotizacion->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/cotizacion/edit');
                $rut = App_Rut::format($form->cliente->getValue());
                $form->cliente->setValue($rut);
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar cotización Nº $id";

            } else {

                $this->view->title = "Crear cotización";

                $form->fecha->setValue(date("Y-m-d"));
                $form->validez->setValue($this->preferencias['CT_VALIDEZ']);
                $form->emitida_por->setValue($this->usuario->empleado);

                if($this->_request->getParam('from_id')) {
                    $rut = App_Rut::format($this->_request->getParam('from_id'));
                    $form->cliente->setValue($rut);
                }

                if($this->_request->getParam('ref_id')) {
                    $form->recepcion_id->setValue($this->_request->getParam('ref_id'));
                }
            }
            $this->view->form = $form;
            $this->renderScript('cotizacion/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Cotizacion(null, $this->path);
        $this->view->title = 'Crear cotización';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    
                    $cotizacion = new Default_Model_Cotizacion();
                    $row = $cotizacion->createRow();
                    $row->creador = $this->usuario->rut;
                    $row->cliente = App_Rut::cleanToDb($form->getValue('cliente'));
                    $row->fecha = $form->getValue('fecha');
                    $row->validez = $form->getValue('validez');
                    $row->atencion_a = $form->getValue('atencion_a');
                    $row->emitida_por = $form->getValue('emitida_por');
                    if($form->getValue('recepcion_id')!='') {
                        $row->recepcion_id = $form->getValue('recepcion_id');
                    } else {
                        $row->recepcion_id = NULL;
                    }
                    $row->autoriza_ext_presupuesto = $form->getValue('autoriza_ext_presupuesto');
                    $row->tope_ext_presupuesto = $form->getValue('tope_ext_presupuesto');
                    $row->aviso_ext_presupuesto = $form->getValue('aviso_ext_presupuesto');
                    $row->iva = $this->view->getPref('IVA');
                    if($form->getValue('observaciones')!='') {
                        $row->observaciones = $form->getValue('observaciones');
                    } else {
                        $row->observaciones = NULL;
                    }
                    $row->estado = 'BORRADOR';
                    $row->save();
                    $id = $row->id;
                    $mSession->mensajes[] = 'La cotizacion fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view','cotizacion', null, array('id'=>$id));
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la cotizacion.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','cotizacion');
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('cotizacion/form.phtml');
            }
        }
    }

    public function newFromAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('cotizaciones', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = $this->_getParam('id');
            $cotizacion = new Default_Model_Cotizacion();
            $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
            $origen = $cotizacion->fetchRow($where);
            
            $nueva  = $cotizacion->createRow();
            $nueva->creador = $this->usuario->rut;
            $nueva->cliente = $origen->cliente;
            $nueva->fecha = date("Y-m-d");
            $nueva->validez = $origen->validez;
            $nueva->atencion_a = $origen->atencion_a;
            $nueva->emitida_por = $origen->emitida_por;
            
            if($origen->recepcion_id!==null) {
                $nueva->recepcion_id = $origen->recepcion_id;
            } else {
                $nueva->recepcion_id = NULL;
            }
            
            $nueva->iva = $this->view->getPref('IVA');
            $nueva->observaciones = $origen->observaciones;
            $nueva->autoriza_ext_presupuesto = $origen->autoriza_ext_presupuesto;
            $nueva->tope_ext_presupuesto = $origen->tope_ext_presupuesto;
            $nueva->aviso_ext_presupuesto = $origen->aviso_ext_presupuesto;
            $nueva->estado = 'BORRADOR';
            $nueva->save();

            $nueva_id = $nueva->id;
            
            $item = new Default_Model_ItemCotizacion();

            $items_origen = $item->fetchAll('cotizacion_id='.$id);

            foreach($items_origen as $item_o){

                $item_n = $item->createRow();
                $item_n->cotizacion_id  = $nueva_id;
                $item_n->vehiculo       = $item_o->vehiculo;
                $item_n->codigo         = $item_o->codigo;
                $item_n->unidad_medida  = $item_o->unidad_medida;
                $item_n->nombre         = $item_o->nombre;
                $item_n->descripcion    = $item_o->descripcion;
                $item_n->cantidad       = $item_o->cantidad;
                $item_n->valor_neto     = $item_o->valor_neto;
                $item_n->descuento      = $item_o->descuento;
                $item_n->codigo         = $item_o->codigo;
                $item_n->table          = $item_o->table;
                $item_n->save();
                $item_n = false;
            }
            $this->_forward('view','cotizacion', null, array('id' => $nueva_id));
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $cotizacion = new Default_Model_Cotizacion();

        $request = $this->getRequest();
        $form = new Default_Form_Cotizacion();

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {
                    
                    $id = (int)$form->getValue('id');
                    $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
                    $row = $cotizacion->fetchRow($where);
                    $row->creador = $this->usuario->rut;
                    $row->cliente = App_Rut::cleanToDb($form->getValue('cliente'));
                    $row->fecha = $form->getValue('fecha');
                    $row->validez = $form->getValue('validez');
                    $row->atencion_a = $form->getValue('atencion_a');
                    $row->emitida_por = $form->getValue('emitida_por');
                    if($form->getValue('recepcion_id')!='') {
                        $row->recepcion_id = $form->getValue('recepcion_id');
                    } else {
                        $row->recepcion_id = NULL;
                    }
                    $row->autoriza_ext_presupuesto = $form->getValue('autoriza_ext_presupuesto');
                    $row->tope_ext_presupuesto = $form->getValue('tope_ext_presupuesto');
                    $row->aviso_ext_presupuesto = $form->getValue('aviso_ext_presupuesto');
                    $row->iva = $this->view->getPref('IVA');
                    if($form->getValue('observaciones')!='') {
                        $row->observaciones = $form->getValue('observaciones');
                    } else {
                        $row->observaciones = NULL;
                    }
                    $row->save();

                    $mSession->mensajes[] = 'La cotizacion fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view', 'cotizacion', null, array('id'=> $id));
                    
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la cotizacion.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                    $this->_forward('index','cotizacion');
                }

            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/cotizacion/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar cotización";
                $this->renderScript('cotizacion/form.phtml');
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('cotizaciones', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $cotizacion = new Default_Model_Cotizacion();
            $id = (int)$this->_getParam('id');
            $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
            $cotizacion->delete($where);
            $mSession->mensajes[] = 'La cotización fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('index','cotizacion');
        }
    }

    public function finishAction()
    {
        if($this->getRequest()->isXmlHttpRequest() &&
           $this->_getParam('id') && 
           $this->_helper->validateRecordExists('vista_cotizaciones', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $modelVista = new Default_Model_VistaCotizaciones();
            $id = (int)$this->_getParam('id');
            $where = $modelVista->getAdapter()->quoteInto("id=?", $id);
            $rowVista = $modelVista->fetchRow($where);

            if($rowVista->estado=='BORRADOR') {

                if($rowVista->total_neto!==NULL && $rowVista->total_neto!==0) {

                    $cotizacion = new Default_Model_Cotizacion();
                    $row = $cotizacion->fetchRow($where);

                    if($rowVista->total_neto >= $this->preferencias['CT_MONTO_APROB']) {
                        $row->estado = 'PENDIENTE';
                        $row->iva = $this->view->getPref('IVA');

                        $modelAutorizacion = new Default_Model_AutorizacionDocumento();
                        $rowAutorizacion = $modelAutorizacion->createRow();
                        $rowAutorizacion->documento_controller = 'cotizacion';
                        $rowAutorizacion->documento_id = $id;
                        $rowAutorizacion->documento_nombre = 'Cotización';
                        $rowAutorizacion->save();

                        $mSession->claseMensaje = 'advertencia';
                        $mSession->mensajes[] = 'La cotización fue emitida de forma exitosa pero quedó a la espera de aprobación';

                    } else {
                        $row->estado = 'EMITIDA';
                        $row->iva = $this->view->getPref('IVA');

                        $mSession->claseMensaje = 'confirmacion';
                        $mSession->mensajes[] = 'La cotización fue emitida de forma exitosa';
                    }

                    $row->save();

                } else {

                    $mSession->mensajes[] = 'Debe agregar ítems a la cotización';
                    $mSession->claseMensaje = 'error';
                    
                }
            }
            $this->_forward('view','cotizacion', null, array('id' => $id));
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('cotizaciones', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');
            $cotizacion = new Default_Model_VistaCotizaciones();
            $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
            $row = $cotizacion->fetchRow($where);

            $envio = new Default_Model_EnvioDocumento();
            $where_envio = "documento_id='$id' AND tipo='cotizacion'";
            $order_envio = "id DESC";
            $count_envio = '1';
            $rows_envios = $envio->fetchAll($where_envio, $order_envio, $count_envio)->toArray();

            $items = new Default_Model_ItemCotizacion();
            $where_items = $items->getAdapter()->quoteInto("cotizacion_id=?", $id);

            $this->view->title = "Cotización Nº $id";
            $this->view->cotizacion = $row;
            $this->view->items = $items->fetchAll($where_items);
            $this->view->envios = $rows_envios;

            if($row->estado=='BORRADOR') {

                $this->renderScript('cotizacion/view-borrador.phtml');

            } elseif($row->estado=='PENDIENTE') {
                
                $this->view->title .= " : Pendiente aprobación";
                
                if($this->_getParam('check')=='a') {
                    $this->renderScript('cotizacion/review.phtml');
                } else {
                    $this->renderScript('cotizacion/view-pendiente.phtml');
                }

            } elseif($row->estado=='EMITIDA') {

                $this->view->title .= " : Emitida";
                $this->renderScript('cotizacion/view-emitida.phtml');

            } elseif($row->estado=='APROBADA') {

                $this->view->title .= " : Aprobada por el cliente";
                $this->renderScript('cotizacion/view-aprobada.phtml');

            } elseif($row->estado=='RECHAZADA') {

                $this->view->title .= " : Rechazada";
                //$rechazo = new Default_Model_RechazoCotizacion();
                //$this->view->rechazo = $rechazo->fetchRow('cotizacion_id=' . $row->id);
                $this->renderScript('cotizacion/view-rechazada.phtml');

            } else {
                $this->renderScript('cotizacion/view-simple.phtml');
            }
        }
    }

    public function aprobarAction()
    {
        if($this->getRequest()->isXmlHttpRequest() && 
           $this->_getParam('id') &&
           $this->_helper->validateRecordExists('vista_cotizaciones', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $cotizacion = new Default_Model_Cotizacion();
            $id = (int)$this->_getParam('id');
            $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
            $row = $cotizacion->fetchRow($where);

            if($row->estado=='PENDIENTE') {

                $row->estado = 'EMITIDA';
                $row->save();

                $autorizacion = new Default_Model_AutorizacionDocumento();
                $whereAutorizacion = "documento_controller='cotizacion' AND documento_id='$id'";
                $rowAutorizacion = $autorizacion->fetchRow($whereAutorizacion);
                $rowAutorizacion->estado = 1;
                $rowAutorizacion->autorizado_por = $this->usuario->rut;
                $rowAutorizacion->autorizacion = date("Y-m-d H:i:s");
                $rowAutorizacion->save();

            }
            
            $mSession->mensajes[] = 'La cotización fue </strong>aprobada</strong> de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('autorizaciones','admin');
        }
    }

    public function rechazarAction()
    {
        if($this->getRequest()->isXmlHttpRequest() &&
           $this->_getParam('id') &&
           $this->_helper->validateRecordExists('vista_cotizaciones', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $cotizacion = new Default_Model_Cotizacion();
            $id = (int)$this->_getParam('id');
            $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
            $row = $cotizacion->fetchRow($where);

            if($row->estado=='PENDIENTE') {

                $row->estado = 'RECHAZADA';
                $row->save();

                $autorizacion = new Default_Model_AutorizacionDocumento();
                $whereAutorizacion = "documento_controller='cotizacion' AND documento_id='$id'";
                $rowAutorizacion = $autorizacion->fetchRow($whereAutorizacion);
                $rowAutorizacion->estado = 1;
                $rowAutorizacion->autorizado_por = $this->usuario->rut;
                $rowAutorizacion->autorizacion = date("Y-m-d H:i:s");
                $rowAutorizacion->save();

            }

            $mSession->mensajes[] = 'La cotización fue </strong>rechazada</strong> de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('autorizaciones','admin');
        }
    }

    public function detalleAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            if($this->_getParam('id') AND
                $this->_helper->validateRecordExists('cotizaciones','id', $this->_getParam('id'))){

                $id = $this->_getParam('id');

                $cotizacion = new Default_Model_VistaCotizaciones();
                $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
                $row = $cotizacion->fetchRow($where);

                $items = new Default_Model_ItemCotizacion();
                $where_items = $items->getAdapter()->quoteInto("cotizacion_id=?", $id);

                $this->view->items = $items->fetchAll($where_items);
                $this->view->cotizacion = $row;

               $this->renderScript('cotizacion/detalle.phtml');
            }
        }
    }

    public function listByClienteAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('clientes', 'rut', App_Rut::cleanToDb($this->_getParam('id')))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $rut = App_Rut::cleanToDb($this->_getParam('id'));
            $currentPage = $this->_getParam('page', 1);

            $model = new Default_Model_VistaCotizaciones();
            $where = $model->getAdapter()->quoteInto('cliente_id=?', $rut);
            $cotizaciones = $model->fetchAll($where);

            $paginador = Zend_Paginator::factory($cotizaciones);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control_extra.phtml');

            $this->view->cotizaciones = $paginador;
            $this->renderScript('cotizacion/list-by-cliente.phtml');
        }
    }

    public function printAction()
    {
        if($this->_getParam('id') AND
           $this->_helper->validateRecordExists('vista_cotizaciones','id', $this->_getParam('id'))){

            $this->_helper->layout->disableLayout(false);
            $this->_helper->viewRenderer->setNoRender(false);
            $this->_helper->layout->setLayout('print');

            $cotizacion = new Default_Model_VistaCotizaciones();
            $id = (int)$this->_getParam('id');
            $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
            $row = $cotizacion->fetchRow($where);

            if(false!==$row AND $row->estado=='EMITIDA') {
                $item = new Default_Model_ItemCotizacion();
                $where_items = $item->getAdapter()->quoteInto("cotizacion_id=?",$id);
                $items = $item->fetchAll($where_items);
                $this->view->title = "Cotización Nº $id";
                $this->view->cotizacion = $row;
                $this->view->items = $items;
                $this->view->modeView = $this->_getParam('mode_view');
                $this->view->condiciones_generales = Default_Model_CondicionGeneral::getTexto('COTIZACION');
            }
        }
    }

    public function mailAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_SendAttach(null, $this->path);

        if($this->getRequest()->isXmlHttpRequest() AND 
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('vista_cotizaciones', 'id', $this->_getParam('id'))){

            $documento = 'cotizacion';
            $id = (int)$this->_getParam('id');
            $name = $documento . '-' . $id .'.pdf';
            $back = '/' . $documento . '/view/' . $id;

            $formValues = array(
                'archivo'       => $name,
                'id'            => $id,
                'documento'     => $documento,
                'asunto'        => 'ExpressAuto S.p.A. - Cotización Nº ' . $id,
                'texto_mensaje' => 'Adjunto cotización según lo solicitado',
                'back'          => $back
            );

            if($this->_getParam('mode_view')) {
                $form->setAction('/cotizacion/send/f');
            }

            
            $form->copia->setLabel('Enviar una copia a mi casilla ('.  $this->usuario->mail .')');
            $form->populate($formValues);

            $this->view->form = $form;
            $this->view->title = "Enviar documento adjunto por mail";
            $this->renderScript('archivos-comunes/form.phtml');
        }
    }

    public function sendAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->_getParam('mode_view')=='f') {
            $modeView = 'f';
        }

        $request = $this->getRequest();
        $form = new Default_Form_SendAttach(null, $this->path);
        $form->copia->setLabel('Enviar una copia a mi casilla ('.  $this->usuario->mail .')');

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {

                    $mail = new App_HtmlMailerDocument('UTF-8');
                    $mail->setFrom($this->usuario->mail, $this->usuario->empleado);
                    $mail->setType(Zend_Mime::MULTIPART_RELATED);
                    $mail->setSubject($form->getValue('asunto'))
                         ->setViewParam('nombre', $form->getValue('nombre'))
                         ->setViewParam('usuario', $this->usuario->empleado)
                         ->setViewParam('mensaje', $form->getValue('texto_mensaje'));

                    $mail->addTo($form->getValue('mail'), $form->getValue('nombre'));

                    if($form->copia->getValue()==1){
                        $mail->addBcc($this->usuario->mail);
                    }

                    $path =  '/cotizacion/create-pdf/' . $form->getValue('id');

                    if($modeView=='f'){
                        $path .= '/f';
                    }

                    $pdf = new App_Pdf($path);
                    
                    $attach = $mail->createAttachment($pdf->getContent());
                    $attach->filename = $form->getValue('archivo');
                    
                    $mail->sendHtmlTemplate('send-attach.phtml');

                    $envio = new Default_Model_EnvioDocumento();
                    $row = $envio->createRow();
                    $row->creador = $this->usuario->rut;
                    $row->tipo = 'cotizacion';
                    $row->documento_id = $form->getValue('id');
                    $row->nombre = $form->getValue('nombre');
                    $row->mail = $form->getValue('mail');
                    $row->save();

                    $mSession->mensajes[] = 'El mensaje fue enviado de forma satisfactoria.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view', 'cotizacion', null, array('id' => $form->getValue('id')));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar enviar el mensaje, por favor inténtelo más tarde.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect($form->getValue('back'));
                }

            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('archivos-comunes/form.phtml');
            }
        }
    }

    public function pdfAction()
    {
        if($this->_getParam('id') AND
           $this->_helper->validateRecordExists('vista_cotizaciones','id', $this->_getParam('id'))){
            $documento = 'cotizacion';
            $id = (int)$this->_getParam('id');
            $path = '/cotizacion/create-pdf/'. $id;
            if($this->_getParam('mode_view')=='f') {
                $path .= '/f';
            }
            $name = $documento . '-' . $id .'.pdf';
            $pdf = new App_Pdf($path);
            $pdf->setName($name);
            $pdf->download();
        }
    }

    public function createPdfAction()
    {
        $this->_helper->layout->disableLayout(false);
        $this->_helper->viewRenderer->setNoRender(false);
        $this->_helper->layout->setLayout('pdf');
        $id = (int)$this->_getParam('id');
        $cotizacion = new Default_Model_VistaCotizaciones();
        $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
        $row = $cotizacion->fetchRow($where);

        if(false!==$row AND $row['estado']=='EMITIDA') {
            $item = new Default_Model_ItemCotizacion();
            $where_items = $item->getAdapter()->quoteInto("cotizacion_id=?",$id);
            $items = $item->fetchAll($where_items);
            $this->view->title = "Cotización Nº $id";
            $this->view->cotizacion = $row;
            $this->view->items = $items;
            $this->view->modeView = $this->_getParam('view');
            $this->view->condiciones_generales = Default_Model_CondicionGeneral::getTexto('COTIZACION');
        }
    }
}