<?php

class DocumentoBancarioEmitidoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
    }
    
    public function init()
    {   
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/documento-bancario-emitido';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function getFormAction()
    {
        
        $mSession = new Zend_Session_Namespace('session');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        if($this->getRequest()->isXmlHttpRequest()){
            
            $request = $this->getRequest();
            
            $form = new Default_Form_DocumentoBancarioEmitido(null, $this->path);
            
            if($this->_getParam('id')) {
               
                $documento = new Default_Model_DocumentoBancarioEmitido();
                $id = (int)$this->_getParam('id');
                $where= $documento->getAdapter()->quoteInto("id=?", $id);
                $row = $documento->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/documento-bancario-emitido/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar el documento bancario emitido";
                
            } elseif($this->_getParam('pago_id') AND
                     $this->_helper->validateRecordExists('pagos_emitidos', 'id', $this->_getParam('pago_id'))) {
                
                $this->view->title = "Ingresar documento bancario emitido";
                $pago_id = (int)$this->_getParam('pago_id');
                $form->pago_id->setValue($pago_id);
            }
            
            $this->view->form = $form;
            $this->renderScript('documento-bancario-emitido/form.phtml');
        }
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('session');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_DocumentoBancarioEmitido(null, $this->path);
        $this->view->title = 'Ingresar documento bancario emitido';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $documento = new Default_Model_DocumentoBancarioEmitido();
                    $row = $documento->createRow();
                    $row->pago_id = $form->getValue('pago_id');
                    $row->creador = $this->usuario->rut;
                    $row->tipo_id = $form->getValue('tipo_id');
                    $row->cuenta_id = $form->getValue('cuenta_id');
                    $row->serie = $form->getValue('serie');
                    $row->fecha_cobro = $form->getValue('fecha_cobro');
                    $row->save();
                    $mSession->mensajes[] = 'El documento fue ingresado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view','pago-emitido', null, array('id' => $row->pago_id));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar ingresar el documento.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','pago-emitido');
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('pago-emitido/form.phtml');
            }
        }
    }
    /*
    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('session');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $documento = new Default_Model_DocumentoTributarioEmitido();

        $request = $this->getRequest();
        $form = new Default_Form_DocumentoTributarioEmitido(null, $this->path);
        $form->id->setRequired(true);

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {

                    $id = (int)$form->getValue('id');
                    $where = $documento->getAdapter()->quoteInto("id=?", $id);
                    $row = $documento->fetchRow($where);
                    $row->creador = $this->usuario->rut;
                    $row->cliente = App_Rut::cleanToDb($form->getValue('cliente'));
                    $row->tipo_id = $form->getValue('tipo_id');
                    $row->numero = $form->getValue('numero');
                    $row->neto = $form->getValue('neto');
                    $row->iva = $form->getValue('iva');
                    $row->emision = $form->getValue('emision');
                    $row->vencimiento = $form->getValue('vencimiento');
                    if($form->getValue('referencia')!='') {
                        $row->referencia = $form->getValue('referencia');
                    } else {
                        $row->referencia = NULL;
                    }
                    if($form->getValue('observaciones')!='') {
                        $row->observaciones = $form->getValue('observaciones');
                    } else {
                        $row->observaciones = NULL;
                    }
                    $row->save();
                    
                    $mSession->mensajes[] = 'El documento fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view', 'documento-tributario-emitido', null, array('id'=> $id));


                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el documento.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                    $this->_forward('index','documento-tributario-emitido');
                }

            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/documento-tributario-emitido/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar documento tributario emitido";
                $this->renderScript('documento-tributario-emitido/form.phtml');
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('session');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $documento = new Default_Model_DocumentoTributarioEmitido();
            $id = (int)$this->_getParam('id');
            $where = $documento->getAdapter()->quoteInto("id=?", $id);
            $documento->delete($where);
            $mSession->mensajes[] = 'El documento tributario emitido fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('index','documento-tributario-emitido');
        }
    }

    */
}