<?php

class DocumentoBancarioRecibidoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
    }
    
    public function init()
    {   
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/documento-bancario-recibido';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function indexAction()
    {

        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $documento = new Default_Model_VistaDocumentosBancariosRecibidos();
            $documentos = $documento->fetchAll();

            $paginador = Zend_Paginator::factory($documentos);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->documentos = $paginador;
            $this->view->title = 'Documentos bancarios recibidos';
            $this->renderScript('documento-bancario-recibido/index.phtml');
        }
    }

    public function listaDepositoAction()
    {

        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $documento = new Default_Model_VistaDocumentosBancariosRecibidos();
            $documentos = $documento->fetchAll();

            $paginador = Zend_Paginator::factory($documentos);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->documentos = $paginador;
            $this->view->title = 'Documentos bancarios para depositar';
            $this->renderScript('documento-bancario-recibido/index.phtml');
        }
    }

    public function getFormAction()
    {
        
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        if($this->getRequest()->isXmlHttpRequest()){
            
            $request = $this->getRequest();
            
            $form = new Default_Form_DocumentoBancarioRecibido(null, $this->path);
            
            if($this->_getParam('id')) {
               
                $documento = new Default_Model_DocumentoBancarioRecibido();
                $id = (int)$this->_getParam('id');
                $where= $documento->getAdapter()->quoteInto("id=?", $id);
                $row = $documento->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/documento-bancario-recibido/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar el documento bancario recibido";
                
            } elseif($this->_getParam('pago_id') AND
                     $this->_helper->validateRecordExists('pagos_recibidos', 'id', $this->_getParam('pago_id'))) {
                
                $this->view->title = "Ingresar documento bancario recibido";
                $pago_id = (int)$this->_getParam('pago_id');
                $form->pago_id->setValue($pago_id);
            }
            
            $this->view->form = $form;
            $this->renderScript('documento-bancario-recibido/form.phtml');
        }
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_DocumentoBancarioRecibido(null, $this->path);
        $this->view->title = 'Ingresar documento bancario recibido';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $documento = new Default_Model_DocumentoBancarioRecibido();
                    $row = $documento->createRow();
                    $row->pago_id = $form->getValue('pago_id');
                    $row->creador = $this->usuario->rut;
                    $row->tipo_id = $form->getValue('tipo_id');
                    $row->fecha_cobro = $form->getValue('fecha_cobro');
                    $row->banco = $form->getValue('banco');
                    $row->cuenta = $form->getValue('cuenta');
                    $row->titular = $form->getValue('titular');
                    $row->serie = $form->getValue('serie');
                    $row->save();
                    $mSession->mensajes[] = 'El documento fue ingresado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view','pago-recibido', null, array('id' => $row->pago_id));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar ingresar el documento.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','pago-recibido');
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('documento-bancario-recibido/form.phtml');
            }
        }
    }
}