<?php
class DteBoletaController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->path = '/dte-boleta';
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');

        $this->porcentaje_recargo = Default_Model_FormaPago::getPorcentajeRecargo();

        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $boleta = new Default_Model_DteBoleta();
            $boletas = $boleta->fetchAll();

            $paginador = Zend_Paginator::factory($boletas);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->boletas = $paginador;
            $this->view->title = 'Boletas';
            $this->renderScript('dte-boleta/index.phtml');
        }
    }
    
    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_DteBoleta(null, $this->path);

            $this->view->title = "Crear boleta";
            $this->view->form = $form;

            $this->renderScript('dte-boleta/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();

        $form = new Default_Form_DteBoleta(null, $this->path);
        $boleta = new Default_Model_DteBoleta();

        $this->view->title = 'Crear boleta';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                
                $db = $boleta->getAdapter();
                $db->beginTransaction();

                try {
                    
                    $row = $boleta->createRow();
                    $row->creador = $this->usuario->rut;
                    $row->numero = $form->getValue('numero');
                    $row->fecha_emision = $form->getValue('fecha');
                    $row->sub_total = 0;
                    $row->desc_global = 0;
                    $row->neto = 0;
                    $row->iva = 0;
                    $row->total = 0;
                    $row->estado = 'BORRADOR';
                    $row->save();
                    $id = $row->id;
                    
                    $itemNotaVenta = new Default_Model_ItemNotaVenta();
                    $where = $itemNotaVenta->getAdapter()->quoteInto("nota_id=?", $form->getValue('nota_id'));
                    $itemsNotaVenta = $itemNotaVenta->fetchAll($where);

                    $itemDteBoleta = new Default_Model_DteItemBoleta();

                    foreach($itemsNotaVenta as $item){
                        
                        $rowItem = $itemDteBoleta->createRow();
                        $rowItem->boleta_id = $id;
                        $rowItem->codigo = $item->codigo;
                        $rowItem->nombre = $item->nombre;
                        $rowItem->descripcion = $item->descripcion;
                        $rowItem->cantidad = $item->cantidad;
                        $rowItem->unidad_medida = $item->unidad_medida;
                        $rowItem->valor_neto = $item->valor_neto;
                        $rowItem->descuento = $item->descuento;
                        $rowItem->table = $item->table;
                        $rowItem->save();
                    }
                    
                    $db->commit();

                    $mSession->mensajes[] = 'La boleta fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view','dte-boleta', null, array('id' => $id ));
                    
                } catch (Exception $e) {

                    $db->rollBack();

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la cotizacion.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','dte-boleta');
                }
                
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('dte-boleta/form.phtml');
            }
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $cotizacion = new Default_Model_Cotizacion();

        $request = $this->getRequest();
        $form = new Default_Form_Cotizacion();

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {
                    
                    $id = (int)$form->getValue('id');
                    $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
                    $row = $cotizacion->fetchRow($where);
                    $row->cliente = App_Rut::cleanToDb($form->getValue('cliente'));
                    $row->fecha = $form->getValue('fecha');
                    $row->validez = $form->getValue('validez');
                    $row->atencion_a = $form->getValue('atencion_a');
                    $row->emitida_por = $form->getValue('emitida_por');
                    $row->referencia = $form->getValue('referencia');
                    $row->autoriza_ext_presupuesto = $form->getValue('autoriza_ext_presupuesto');
                    $row->tope_ext_presupuesto = $form->getValue('tope_ext_presupuesto');
                    $row->aviso_ext_presupuesto = $form->getValue('aviso_ext_presupuesto');
                    $row->iva = $this->view->getPref('IVA');
                    if($form->getValue('observaciones')!='') {
                        $row->observaciones = $form->getValue('observaciones');
                    } else {
                        $row->observaciones = NULL;
                    }
                    $row->save();

                    $mSession->mensajes[] = 'La cotizacion fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view', 'cotizacion', null, array('id'=> $id));
                    
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la cotizacion.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                    $this->_forward('index','cotizacion');
                }

            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/cotizacion/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar cotización";
                $this->renderScript('cotizacion/form.phtml');
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('cotizaciones', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $cotizacion = new Default_Model_Cotizacion();
            $id = (int)$this->_getParam('id');
            $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
            $cotizacion->delete($where);
            $mSession->mensajes[] = 'La cotización fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('index','cotizacion');
        }
    }

    public function emitirAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND 
           $this->_getParam('id') AND $this->_helper->validateRecordExists('dte_boletas', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $boleta = new Default_Model_DteBoleta();
            $where = $boleta->getAdapter()->quoteInto("id=?", (int)$this->_getParam('id'));
            $row = $boleta->fetchRow($where);

            if($row->estado=='BORRADOR') {

                $row->estado = 'EMITIDA';
                $row->save();
                $mSession->mensajes[] = 'La boleta fue emitida de forma exitosa, ahora puede imprimirla.';
                $mSession->claseMensaje = 'confirmacion';

            }
            $this->_forward('view','dte-boleta', null, array('id' => $row->id));
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('dte_boletas', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');
            $boleta = new Default_Model_VistaDteBoletas();
            $where = $boleta->getAdapter()->quoteInto("id=?", $id);
            $row = $boleta->fetchRow($where);

            $items = new Default_Model_DteItemBoleta();
            $where_items = $items->getAdapter()->quoteInto("boleta_id=?", $id);

            $this->view->title = "Boleta Nº $id";
            $this->view->dteboleta = $row;
            $this->view->items = $items->fetchAll($where_items);

            if($row->estado=='BORRADOR') {

                $this->renderScript('dte-boleta/view-borrador.phtml');

            } elseif($row->estado=='EMITIDA') {

                $this->view->title .= " : Emitida";
                $this->renderScript('dte-boleta/view-emitida.phtml');

            } elseif($row->estado=='ANULADA') {

                $this->view->title .= " : Anulada";
                $this->renderScript('dte-boleta/view-anulada.phtml');

            } else {
                $this->renderScript('dte-boleta/view-simple.phtml');
            }
        }
    }
}