<?php
class DteGuiaDespachoController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->path = '/dte-guia-despacho';
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');

        $this->porcentaje_recargo = Default_Model_FormaPago::getPorcentajeRecargo();

        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $guia = new Default_Model_DteGuiaDespacho();
            $guias = $guia->fetchAll();

            $paginador = Zend_Paginator::factory($guias);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->guias = $paginador;
            $this->view->title = 'Guías de despacho';
            $this->renderScript('dte-guia-despacho/index.phtml');
        }
    }
    
    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_DteGuiaDespacho(null, $this->path);

            $this->view->title = "Crear guía despacho";
            $this->view->form = $form;

            $this->renderScript('dte-guia-despacho/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();

        $form = new Default_Form_DteBoleta(null, $this->path);
        $boleta = new Default_Model_DteBoleta();

        $this->view->title = 'Crear boleta';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                
                $db = $boleta->getAdapter();
                $db->beginTransaction();


                try {
                    
                    $row = $boleta->createRow();
                    $row->creador = $this->usuario->rut;
                    $row->numero = $form->getValue('numero');
                    $row->fecha_emision = $form->getValue('fecha');
                    $row->estado = 'BORRADOR';
                    $row->save();
                    $id = $row->id;

                    $itemNotaVenta = new Default_Model_ItemNotaVenta();
                    $where = $itemNotaVenta->getAdapter()->quoteInto("nota_id=?", $form->getValue('nota_id'));
                    $itemsNotaVenta->fetchAll($where);

                    $itemDteBoleta = new Default_Model_DteItemBoleta();

                    foreach($itemsNotaVenta as $item){

                        $rowItem = $itemDteBoleta->createRow();
                        $rowItem->boleta_id = $id;
                        $rowItem->codigo = $item->codigo;
                        $rowItem->nombre = '';
                        $rowItem->descripcion = $item->descripcion;
                        $rowItem->cantidad = $item->cantidad;
                        $rowItem->unidad_medida = 'U';
                        $rowItem->neto = $item->valor_neto;
                        $rowItem->descuento = 0;
                        $rowItem->save();
                    }

                    $db->commit();

                    $mSession->mensajes[] = 'La boleta fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view','boleta', null, array('id' => $id ));
                    
                } catch (Exception $e) {

                    $db->rollBack();

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la cotizacion.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','cotizacion');
                }
                
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('dte-boleta/form.phtml');
            }
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $cotizacion = new Default_Model_Cotizacion();

        $request = $this->getRequest();
        $form = new Default_Form_Cotizacion();

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {
                    
                    $id = (int)$form->getValue('id');
                    $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
                    $row = $cotizacion->fetchRow($where);
                    $row->cliente = App_Rut::cleanToDb($form->getValue('cliente'));
                    $row->fecha = $form->getValue('fecha');
                    $row->validez = $form->getValue('validez');
                    $row->atencion_a = $form->getValue('atencion_a');
                    $row->emitida_por = $form->getValue('emitida_por');
                    $row->referencia = $form->getValue('referencia');
                    $row->autoriza_ext_presupuesto = $form->getValue('autoriza_ext_presupuesto');
                    $row->tope_ext_presupuesto = $form->getValue('tope_ext_presupuesto');
                    $row->aviso_ext_presupuesto = $form->getValue('aviso_ext_presupuesto');
                    $row->iva = $this->view->getPref('IVA');
                    if($form->getValue('observaciones')!='') {
                        $row->observaciones = $form->getValue('observaciones');
                    } else {
                        $row->observaciones = NULL;
                    }
                    $row->save();

                    $mSession->mensajes[] = 'La cotizacion fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view', 'cotizacion', null, array('id'=> $id));
                    
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la cotizacion.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                    $this->_forward('index','cotizacion');
                }

            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/cotizacion/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar cotización";
                $this->renderScript('cotizacion/form.phtml');
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('cotizaciones', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $cotizacion = new Default_Model_Cotizacion();
            $id = (int)$this->_getParam('id');
            $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
            $cotizacion->delete($where);
            $mSession->mensajes[] = 'La cotización fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('index','cotizacion');
        }
    }

    public function finishAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND $this->_getParam('id')){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $v_cotizacion = new Default_Model_VistaCotizaciones();
            $id = $v_cotizacion->getAdapter()->quote($this->_getParam('id'));
            $v_row = $v_cotizacion->fetchRow('id='.$id);

            $cotizacion = new Default_Model_Cotizacion();
            $row = $cotizacion->fetchRow('id='.$id);

            if($v_row->estado=='BORRADOR') {

                if((NULL!=$v_row->total_neto) AND ($v_row->total_neto >= $this->preferencias['CT_MONTO_APROB'])) {
                    $row->estado = 'PENDIENTE';
                    $row->iva = $this->view->getPref('IVA');
                } else {
                    $row->estado = 'EMITIDA';
                    $row->iva = $this->view->getPref('IVA');
                }
                $row->save();
                $mSession->mensajes[] = 'La cotización fue emitida de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';

            }
            $this->_forward('view','cotizacion', null, array('id' => $row->id));
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('cotizaciones', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');
            $cotizacion = new Default_Model_VistaCotizaciones();
            $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
            $row = $cotizacion->fetchRow($where);

            $envio = new Default_Model_EnvioDocumento();
            $where_envio = "documento_id='$id' AND tipo='cotizacion'";
            $order_envio = "id DESC";
            $count_envio = '1';
            $rows_envios = $envio->fetchAll($where_envio, $order_envio, $count_envio)->toArray();

            $items = new Default_Model_ItemCotizacion();
            $where_items = $items->getAdapter()->quoteInto("cotizacion_id=?", $id);

            

            if(false==$row) {
                $this->_forward('index','cotizacion');
            } else {

                $this->view->title = "Cotización Nº $id";
                $this->view->cotizacion = $row;
                $this->view->items = $items->fetchAll($where_items);
                $this->view->envios = $rows_envios;

                if($row->estado=='BORRADOR') {

                    $this->renderScript('cotizacion/view-borrador.phtml');

                } elseif($row->estado=='PENDIENTE') {

                    $this->view->title .= " : Pendiente aprobación";
                    $this->renderScript('cotizacion/view-pendiente.phtml');

                } elseif($row->estado=='EMITIDA') {

                    $this->view->title .= " : Emitida";
                    $this->renderScript('cotizacion/view-emitida.phtml');

                } elseif($row->estado=='APROBADA') {

                    $this->view->title .= " : Aprobada por el cliente";
                    $this->renderScript('cotizacion/view-aprobada.phtml');

                } elseif($row->estado=='RECHAZADA') {

                    $this->view->title .= " : Rechazada";
                    //$rechazo = new Default_Model_RechazoCotizacion();
                    //$this->view->rechazo = $rechazo->fetchRow('cotizacion_id=' . $row->id);
                    $this->renderScript('cotizacion/view-rechazada.phtml');
                    
                } else {
                    $this->renderScript('cotizacion/view-simple.phtml');
                }
            }
        }
    }
}