<?php
class EgresoArticuloController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/egreso-articulo';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);
            
            $egreso = new Default_Model_VistaEgresosArticulos();
            $egresos = $egreso->fetchAll();

            $paginador = Zend_Paginator::factory($egresos);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->title = "Egresos de artículos desde los almacenes";
            $this->view->egresos = $paginador;
            $this->renderScript('egreso-articulo/index.phtml');
        }

    }

    public function getFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $request = $this->getRequest();
            $form = new Default_Form_EgresoArticulo(null, $this->path);
            $this->view->title = "Crear egreso";
            $this->view->form = $form;
            $this->renderScript('egreso-articulo/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_EgresoArticulo(null, $this->path);
        $this->view->title = 'Retirar artículos del almacén';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $egreso = new Default_Model_EgresoArticulo();
                    $row = $egreso->createRow();
                    $row->creador = $this->usuario->rut;
                    $row->tipo_egreso_id = $form->getValue('tipo_egreso_id');
                    $row->articulo = $form->getValue('articulo');
                    $row->cantidad = $form->getValue('cantidad');
                    if($form->getValue('observaciones')!='') {
                        $row->observaciones = $form->getValue('observaciones');
                    } else {
                        $row->observaciones = NULL;
                    }
                    $row->save();

                    $mSession->mensajes[] = 'El retiro fue realizado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('index','egreso-articulo');

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar realizar el egreso.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','egreso-articulo');
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('egreso-articulo/form.phtml');
            }
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $egreso = new Default_Model_VistaEgresosArticulos();

            $id = (int)$this->_getParam('id');
            $where = $egreso->getAdapter()->quoteInto("id=?", $id);
            $row = $egreso->fetchRow($where);
            $this->view->title = "Egreso de artículos Nº $id";

            if(false==$row) {
                $this->_forward('index','egreso-articulo');
            } else {
                $this->view->egreso = $row;
                $this->renderScript('egreso-articulo/view-simple.phtml');
            }
        }
    }
}