<?php
class EgresoCajaChicaController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $propietario = new Default_Model_Propietario();
        $this->view->propietario = $propietario->fetchRow()->toArray();
        $this->path = '/egreso-caja-chica';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function listByCicloAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('cc_ciclos_cajas', 'id', (int)$this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');
            $currentPage = $this->_getParam('page', 1);
            $model = new Default_Model_VistaCajasChicasEgresos();
            $where = $model->getAdapter()->quoteInto('ciclo_id=?', $id);
            $egresos = $model->fetchAll($where);
            /*
            $paginador = Zend_Paginator::factory($egresos);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control_extra.phtml');
             */
            $this->view->egresos = $egresos; //$paginador;
            $this->view->u = $this->_getParam('type_user');
            $this->renderScript('egreso-caja-chica/list-by-ciclo.phtml');
        }
    }

    public function getFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $ciclo_id = Default_Model_VistaCajasChicasCiclos::_getActivo($this->usuario->rut);

            if($ciclo_id){

                $saldoDisponible = $this->_getSaldoDisponible($ciclo_id);

                $request = $this->getRequest();
                $form = new Default_Form_EgresoCajaChica(null, $this->path);
                $form->ciclo_id->setValue($ciclo_id);
                $form->maximo->setValue($saldoDisponible);
                $form->maximo->setAttrib('disabled', 'disabled');
                $this->view->title = "Registrar egreso de caja chica";
                $this->view->form = $form;
                $this->renderScript('caja-chica/form.phtml');

            } else {

                $mSession->mensajes[] = 'No se registra dinero disponible en la caja chica';
                $mSession->claseMensaje = 'error';
                $this->_forward('user', 'caja-chica');

            }
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_EgresoCajaChica(null, $this->path);
        $this->view->title = 'Retirar artículos del almacén';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                $ciclo_id = (int)$form->getValue('ciclo_id');
                $saldoDisponible = $this->_getSaldoDisponible($ciclo_id);
                $optionsMinMax = array('min' => '1', 'max' => $saldoDisponible);
                $validadorMinMax = new Zend_Validate_Between($optionsMinMax);

                if($validadorMinMax->isValid($form->getValue('cantidad'))) {

                    $egreso = new Default_Model_CajaChicaEgreso();
                    $db = $egreso->getAdapter();
                    $db->beginTransaction();

                    try {

                        $rowEgreso = $egreso->createRow();
                        $rowEgreso->ciclo_id = $form->getValue('ciclo_id');
                        $rowEgreso->entregado_a = $form->getValue('entregado_a');
                        $rowEgreso->fecha = date("Y-m-d H:i:s");
                        $rowEgreso->cantidad = $form->getValue('cantidad');
                        $rowEgreso->detalles = $form->getValue('detalles');
                        $rowEgreso->save();

                        if($form->getValue('ordenes_servicios')!=''){

                            $ordenesServicios = $form->getValue('ordenes_servicios');
                            $arrayOrdenesServicios = explode(",", $ordenesServicios);

                            foreach ($arrayOrdenesServicios as $id) {

                                $id = trim((int)$id);
                                $modelOrden = new Default_Model_VistaOrdenesServicios();
                                $whereOrden = $modelOrden->getAdapter()->quoteInto("id=?", $id);
                                $rowOrden = $modelOrden->fetchRow($whereOrden);

                                if($rowOrden){
                                    if($rowOrden->estado=='PENDIENTE' || $rowOrden->estado=='EN PROCESO') {

                                        $modelEnlace = new Default_Model_EnlaceOrdenServicioCcEgreso();
                                        $rowEnlace = $modelEnlace->createRow();
                                        $rowEnlace->orden_id = $id;
                                        $rowEnlace->egreso_id = $rowEgreso->id;
                                        $rowEnlace->save();
                                    }
                                }
                            }
                        }

                        $mSession->mensajes[] = 'El egreso fue registrado de forma exitosa.';
                        $mSession->claseMensaje = 'confirmacion';

                        $db->commit();

                        $this->_forward('user','caja-chica');

                    } catch (Exception $e) {
                        $db->rollBack();
                        $mSession->mensajes[] = 'Ocurrió un error al intentar registrar el egreso.';
                        $mSession->mensajes[] = $e->getMessage();
                        $mSession->claseMensaje = 'error';
                        $this->_forward('user','caja-chica');
                    }
                } else {
                    $form->populate($request->getPost());
                    $form->cantidad->setErrorMessages(array('El monto a ingresar debe estar entre 1 y ' . $saldoDisponible));
                    $form->cantidad->markAsError();
                    $form->maximo->setAttrib('disabled', 'disabled');
                    $this->view->form = $form;
                    $this->renderScript('caja-chica/form.phtml');
                }
            } else {
                $form->maximo->setAttrib('disabled', 'disabled');
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('egreso-articulo/form.phtml');
            }
        }
    }

    public function deleteAction()
    {
        if($this->_getParam('id') AND
           $this->_helper->validateRecordExists('cc_egresos', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            
            try {
                $model = new Default_Model_CajaChicaEgreso();
                $modelVista = new Default_Model_VistaCajasChicasEgresos();
                $where = $model->getAdapter()->quoteInto("id = ?" , (int)$this->_getParam('id'));

                $rowVista = $modelVista->fetchRow($where);

                if($rowVista->rendido==0){
                    $model->delete($where);
                }

                $mSession->mensajes[] = 'El egreso caja chica fue eliminada de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_forward('user','caja-chica');

            } catch (Exception $e) {

                $mSession->tipo_error = 1;
                $mSession->errores[] = $e->getMessage();
                $this->_forward('error-delete-registro','error');
            }
        }
    }

    public function cerrarAction()
    {
        if($this->_getParam('id') AND
           $this->_helper->validateRecordExists('cc_egresos', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }



            try {
                $model = new Default_Model_CajaChicaEgreso();
                $where = $model->getAdapter()->quoteInto("id = ?" , (int)$this->_getParam('id'));
                $row = $model->fetchRow($where);

                if($row->estado == 0){
                    $row->estado = 1;
                    $row->save();
                }

                $mSession->mensajes[] = 'El egreso de caja chica fue cerrado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_forward('user','caja-chica');

            } catch (Exception $e) {

                $mSession->tipo_error = 1;
                $mSession->errores[] = $e->getMessage();
                $this->_forward('error-update-registro','error');
            }
        }
    }

    public function formConsultaAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            if($this->_getParam('type_user')=='a') {
                if($this->_getParam('id')!='0' &&
                   $this->_helper->validateRecordExists('cc_cajas', 'id', App_Rut::cleanToDb($this->_getParam('id')))) {
                    $this->view->caja_id = App_Rut::cleanToDb($this->_getParam('id'));
                }
                $this->view->cajas = Default_Model_VistaCajasChicas::getPairsToSelect();
                $this->view->back = '/caja-chica/view/' . App_Rut::cleanToDb($this->_getParam('id'));
                $this->view->user = 'a';
            } elseif($this->_getParam('type_user')=='u') {
                $this->view->back = '/caja-chica/user';
                $this->view->user = 'u';
            }
            $this->view->empleados = Default_Model_Empleado::getPairsToSelect();
            $this->view->title = "Consultar egresos de dinero";
            $this->renderScript('egreso-caja-chica/form-consulta.phtml');
        }
    }

    public function consultaAction()
    {
        if($_POST) {

            $model = new Default_Model_VistaCajasChicasEgresos();

            if($this->_getParam('type_user')=='u'){

                $where = "caja_id='" . $this->usuario->rut . "'";
                $consulta = "/egreso-caja-chica/form-consulta/0/u";

            } elseif($this->_getParam('type_user')=='a') {

                $consulta = "/egreso-caja-chica/form-consulta/0/a";

                if($this->_getParam('caja_id')!='0'){
                    $where = "caja_id='" . $this->_getParam('caja_id') . "'";
                } else {
                    $where = "caja_id IS NOT NULL";
                }
                
            } else {
                return false;
            }

            // filtro por fechas
            $fecha_i = $this->_getParam('fecha_i');
            $fecha_t = $this->_getParam('fecha_t');

            if(Zend_Date::isDate($fecha_i . ' 00:00:00', Zend_Date::ISO_8601)) {
                $fecha_i = $fecha_i . ' 00:00:00';
                $where .= " AND fecha > '" . $fecha_i . "'";
            }

            if(Zend_Date::isDate($fecha_t . ' 23:59:59', Zend_Date::ISO_8601)) {
                $fecha_t = $fecha_t . ' 23:59:59';
                $where .= " AND fecha < '" . $fecha_t . "'";
            }

            // filtro por estados
            $estado = (int)$this->_getParam('estado');
            if($estado==1){
                $where .= " AND estado='1'";
            } elseif($estado==2){
                $where .= " AND estado='0'";
            }

            // filtro por tipo de ingreso
            $tipo = (int)$this->_getParam('tipo');
            if($tipo==1){
                $where .= " AND tipo_id='1'";
            } elseif($tipo==2){
                $where .= " AND tipo_id='2'";
            }
            
            // filtro por empleado
            $entregado_a = App_Rut::cleanToDb($this->_getParam('entregado_a'));
            if($entregado_a!='' && $this->_helper->validateRecordExists('empleados', 'rut', $entregado_a)){
                $where .= " AND entregado_a='" . $entregado_a . "'";
            }
            
            // filtro por montos
            $signo = (int)$this->_getParam('signo');
            $cantidad = (int)$this->_getParam('monto');
            if($signo==1) {
                $where .= " AND cantidad >= '" . $cantidad . "'";
            } elseif($signo==2) {
                $where .= " AND cantidad <= '" . $cantidad . "'";
            }

            $rows = $model->fetchAll($where);


            $this->view->egresos = $rows;
            $this->view->back = $this->_getParam('back');
            $this->view->user = $this->_getParam('type_user');
            $this->view->consulta = $consulta;
            $this->view->title = "Consultar egresos de dinero";
            $this->renderScript('egreso-caja-chica/resultados-busqueda.phtml');

        } else {
            $this->_forward("form-consulta", "egreso-caja-chica");
        }
    }
    
    public function printAction()
    {
        if($this->_getParam('id') AND
           $this->_helper->validateRecordExists('vista_cc_egresos','id', $this->_getParam('id'))){

            $this->_helper->layout->disableLayout(false);
            $this->_helper->viewRenderer->setNoRender(false);
            $this->_helper->layout->setLayout('print');

            $id = (int)$this->_getParam('id');
            $egreso = new Default_Model_VistaCajasChicasEgresos();
            $where = $egreso->getAdapter()->quoteInto("id=?", $id);
            $row = $egreso->fetchRow($where);

            $this->view->title = "Egreso de caja chica Nº $id";
            $this->view->egreso = $row;
            $this->view->condiciones_generales = Default_Model_CondicionGeneral::getTexto('EGRESO_CAJA_CHICA');
        }
    }

    private function _getSaldoDisponible($ciclo_id)
    {
        $ciclo = new Default_Model_VistaCajasChicasCiclos();
        $where = $ciclo->getAdapter()->quoteInto("id=?", $ciclo_id);
        $row = $ciclo->fetchRow($where);
        $saldoDisponible = $row->total_ingresos
                         - $row->total_egresos
                         + ($row->total_egresos_cerrados - $row->total_rendiciones_egresos_cerrados);
        return $saldoDisponible;
    }
}