<?php
class EmpleadoController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/empleado';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {

                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $empleado = new Default_Model_Empleado();
            $empleados = $empleado->fetchAll();

            $paginador = Zend_Paginator::factory($empleados);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->empleados = $paginador;
            $this->view->title = "Empleados";
            $this->renderScript('empleado/index.phtml');

        } else {
            $this->_forward('logout', 'index');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Empleado(null, $this->path);
        $this->view->title = "Agregar empleado";

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {
                    $empleado = new Default_Model_Empleado();
                    $row = $empleado->createRow();
                    $row->rut = App_Rut::cleanToDb($form->getValue('rut'));
                    $row->nombres = $form->getValue('nombres');
                    $row->apellidos = $form->getValue('apellidos');
                    $row->telefono = $form->getValue('telefono');
                    $row->movil = $form->getValue('movil');
                    $row->direccion = $form->getValue('direccion');
                    $row->ciudad = $form->getValue('ciudad');
                    $row->mail = $form->getValue('mail');
                    $row->save();
                    $mSession->mensajes[] = 'El empleado fue agregado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';           

                    switch ($form->getValue('accion')){

                        case "1" :
                            $this->_forward('get-form','contrato-empleado', null, array('rut' => $row->rut));
                            break;
                        case "2" :
                            $this->_forward('get-form','empleado');
                            break;
                        case "3" :
                            $this->_forward('index','empleado');
                            break;
                    }
                    

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar agregar el empleado.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('new','empleado');
                }
            } else {

                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('empleado/form.phtml');
            }
        } else {
            $this->_forward('logout','index');
        }
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_Empleado(null, $this->path);

            if($this->_request->getParam('rut')) {

                $empleado = new Default_Model_Empleado();
                $rut = $empleado->getAdapter()->quote($this->_request->getParam('rut'));
                $row = $empleado->fetchRow('rut='.$rut)->toArray();
                $form->populate($row);
                $form->setAction('empleado/edit');
                $rut = App_Rut::format($form->rut->getValue());
                $form->rut->setValue($rut);
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar empleado";

            } else {

                $this->view->title = "Agregar empleado";

            }
            $this->view->form = $form;
            $this->renderScript('empleado/form.phtml');
        } else {
            $this->_forward('logout', 'index');
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $rut = $this->_getParam('rut');
            $empleado = new Default_Model_Empleado();
            $this->view->empleado = $empleado->fetchRow('rut=' . $rut);
            $this->view->title = 'Empleado';

            if(false==$this->view->empleado) {

                $this->_forward('index','empleado');

            } else {

                $contrato = new Default_Model_ContratoEmpleado();
                $where = 'empleado=' . $rut;
                $order = 'id DESC';
                $this->view->contrato = $contrato->fetchRow($where);
                //var_dump($this->view->contrato);
                $this->renderScript('empleado/view.phtml');
            }
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Empleado();

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {

                    $rut = App_Rut::cleanToDb($form->getValue('rut'));
                    $empleado = new Default_Model_Empleado();
                    $row = $empleado->fetchRow('rut='.$rut);
                    $row->nombres = $form->getValue('nombres');
                    $row->apellidos = $form->getValue('apellidos');
                    $row->telefono = $form->getValue('telefono');
                    $row->movil = $form->getValue('movil');
                    $row->direccion = $form->getValue('direccion');
                    $row->ciudad = $form->getValue('ciudad');
                    $row->mail = $form->getValue('mail');
                    $row->save();

                    $mSession->mensajes[] = 'El empleado fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view', 'empleado', null, array('rut'=> $rut));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('edit','empleado');
                }

            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/empleado/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar empleado";
                $this->renderScript('empleado/form.phtml');
            }
        }
    }


    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $rut = $this->_getParam('rut');
            $empleado = new Default_Model_Empleado();
            $where = $empleado->getAdapter()->quoteInto('rut = ?' , $rut);
            $empleado->delete($where);
            $mSession->mensajes[] = 'El empleado fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('index','empleado');

        } else {
            $this->_forward('logout', 'index');
        }
    }

}