<?php
class FabricanteController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/fabricante';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $fabricante = new Default_Model_Fabricante();
            $order_by = "nombre";
            $fabricantes = $fabricante->fetchAll(null, $order_by);

            $paginador = Zend_Paginator::factory($fabricantes);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->fabricantes = $paginador;
            $this->view->title = 'Fabricantes';
            $this->renderScript('fabricante/index.phtml');
        }
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_Fabricante(null, $this->path);

            if($this->_request->getParam('id')) {

                $fabricante = new Default_Model_Fabricante();
                $where = $fabricante->getAdapter()->quoteInto("id=?", (int)$this->_request->getParam('id'));
                $row = $fabricante->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/fabricante/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar fabricante";

            } else {

                $this->view->title = "Crear fabricante";

            }
            $this->view->form = $form;
            $this->renderScript('fabricante/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Default_Form_Fabricante(null, $this->path);

        if ($this->_request->isPost()) {
            $formData = $this->_request->getPost();
            if ($form->isValid($formData)) {

                try {

                    $fabricante = new Default_Model_Fabricante();
                    $row = $fabricante->createRow();
                    $row->nombre = $form->getValue('nombre');
                    $row->save();

                    $mSession->mensajes[] = 'El registro fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                }

                $this->_forward('index', 'fabricante');

            } else {
                $this->view->title = 'Crear fabricante';
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('fabricante/form.phtml');
            }
        }

        $this->view->form = $form;
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $fabricante = new Default_Model_Fabricante();

        $request = $this->getRequest();
        $form = new Default_Form_Fabricante();
        $form->setAction($this->path . '/edit');
        $form->submit->setLabel("guardar cambios");

        if ($this->_request->isPost()) {
            $formData = $this->_request->getPost();
            if ($form->isValid($formData)) {

                try {

                    $where = $fabricante->getAdapter()->quoteInto("id=?", (int)$form->getValue('id'));
                    $row = $fabricante->fetchRow($where);
                    $row->nombre = $form->getValue('nombre');
                    $row->save();

                    $mSession->mensajes[] = 'El registro fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                }

                $this->_forward('index', 'fabricante');

            } else {
                $this->view->title = 'Editar fabricante';
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('fabricante/form.phtml');
            }
        } else {

            if ($this->_request->getParam('id')) {
                $where = $fabricante->getAdapter()->quoteInto("id=?", (int)$this->_request->getParam('id'));
                $registro = $fabricante->fetchRow($where);
                $form->populate($registro->toArray());
            }
        }
        $this->view->form = $form;
    }

    public function deleteAction()
    {
        if($this->_getParam('id')){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            try {

                $model = new Default_Model_Fabricante();
                $where = $model->getAdapter()->quoteInto("id = ?" , (int)$this->_getParam('id'));
                $model->delete($where);

                $mSession->mensajes[] = 'El fabricante fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';

                $this->_forward('index','fabricante');

            } catch (Exception $e) {

                $mSession->tipo_error = 1;
                $mSession->errores[] = $e->getMessage();

                $this->_forward('error-delete-registro','error');

            }
        }
    }
}