<?php
class FacturaProveedorController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();

        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/factura-proveedor';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $factura = new Default_Model_VistaFacturasProveedores();
            $order = "id DESC";
            $facturas = $factura->fetchAll(null,$order);

            $paginador = Zend_Paginator::factory($facturas);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->facturas = $paginador;
            $this->view->title = 'Facturas de proveedores';
            $this->renderScript('factura-proveedor/index.phtml');

        } else {
            $this->_forward('logout', 'index');
        }
    }

    public function getFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $request = $this->getRequest();
            $form = new Default_Form_FacturaProveedor(null, $this->path);

            if($this->_request->getParam('id')) {

                $nota = new Default_Model_FacturaProveedor();
                $where = $nota->getAdapter()->quoteInto("id=?", (int)$this->_request->getParam('id'));
                $row = $nota->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/factura-proveedor/edit');
                $rut = App_Rut::format($form->proveedor->getValue());
                $form->proveedor->setValue($rut);
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar factura de proveedor";

            } else {

                $this->view->title = "Ingresar factura de proveedor";

            }
            $this->view->form = $form;
            $this->renderScript('factura-proveedor/form.phtml');
        }
    }

    public function listByProveedorAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_request->getParam('id', 0);
        $facturas = new Default_Model_VistaFacturasProveedores();
        $this->view->facturas = $facturas->fetchAll('proveedor_id=' . $id, 'fecha_v DESC');

    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_FacturaProveedor(null, $this->path);
        $this->view->title = 'Ingresar factura de proveedor';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                try {
                    
                    $factura = new Default_Model_FacturaProveedor();
                    $row = $factura->createRow();
                    $row->usuario_id = $this->usuario->id;
                    $row->proveedor = App_Rut::cleanToDb($form->getValue('proveedor'));
                    $row->numero = $form->getValue('numero');
                    $row->fecha_e = $form->getValue('fecha_e');
                    $row->vence_en = $form->getValue('vence_en');
                    $row->neto = $form->getValue('neto');
                    $row->iva = $form->getValue('iva');
                    $row->save();
                    $id = $row->id;
                    $mSession->mensajes[] = 'La factura de proveedor fue ingresada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';     
                    $this->_forward('view','factura-proveedor', null, array('id'=>$id));     
                    //$this->_forward('test','error');

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar ingresar la factura de proveedor.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('new','factura-proveedor');
                }

                

            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('factura-proveedor/form.phtml');
            }
        } else {
            $this->_forward('logout','index');
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Default_Form_FacturaProveedor(null, $this->path);
        $form->setAction($this->path . '/edit');
        $form->submit->setLabel("guardar cambios");

        if ($this->_request->isPost()) {
            $formData = $this->_request->getPost();
            if ($form->isValid($formData)) {

                try {
                    
                    $id = $form->getValue('id');
                    $factura = new Default_Model_FacturaProveedor();
                    $row = $factura->fetchRow('id='.$id);
                    $row->proveedor_id = $form->getValue('proveedor_id');
                    $row->numero = $form->getValue('numero');
                    $row->fecha_e = $form->getValue('fecha_e');
                    $row->vence_en = $form->getValue('vence_en');
                    $row->neto = $form->getValue('neto');
                    $row->iva = $form->getValue('iva');
                    $row->save();

                    $mSession->mensajes[] = 'La factura del proveedor fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    
                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    
                }

                $this->_redirect('/factura-proveedor/view/id/' . $id);

            } else {
                $form->populate($request->getPost());
            }
        } else {
            $id = (int)$this->_request->getParam('id', 0);
            if ($id > 0) {
                $factura = new Default_Model_FacturaProveedor();
                $registro = $factura->fetchRow('id='.$id);
                $form->populate($registro->toArray());
            }
        }
        $this->view->form = $form;
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Default_Form_Delete();
        $form->setAction($this->path . '/delete');

        if ($this->_request->isPost()) {
            $formData = $this->_request->getPost();
            if ($form->isValid($formData)) {

                $factura = new Default_Model_FacturaProveedor();
                $where = 'id = '. $form->getValue('id');
                $factura->delete($where);
                $mSession->mensajes[] = 'El registro fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_redirect($this->path . '/list');
            }
        } else {
            $id = (int)$this->_request->getParam('id', 0);
            if ($id > 0) {
                $factura = new Default_Model_VistaFacturasProveedores();
                $this->view->factura = $factura->fetchRow('id='.$id);
                $form->id->setValue($id);
            }
        }
        $this->view->form = $form;
    } 

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_request->getParam('id', 0);
            $factura = new Default_Model_VistaFacturasProveedores();
            $this->view->factura = $factura->fetchRow('id=' . $id);

            if(false==$this->view->factura) {
                $this->_redirect($this->path . '/list');
            }
            //$ingresos = new Default_Model_VistaIngresosInventario();
            //$this->view->ingresos = $ingresos->fetchAll('proveedor=' . $this->view->factura->proveedor_rut);
            $this->view->title = 'Factura de proveedor';
            $this->renderScript('factura-proveedor/view.phtml');
            
        } else {
            $this->_forward('logout', 'index');
        }
    }

    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();

            $formularios = array(
                new Default_Form_ConsultaFacturaProveedor(null, $this->path),
            );

            $request = $this->getRequest();
            $this->view->formularios = $formularios;
            $this->view->title = "Facturas de proveedor : Buscar";
            $this->renderScript('factura-proveedor/find.phtml');
            
        } else {
            $this->_forward('logout', 'index');
        }
    }
}