<?php
class InfoModeloVehiculoController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/info-modelo-vehiculo';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function listByModeloAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('modelos_vehiculos', 'id', strtoupper($this->_getParam('id')))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = strtoupper($this->_getParam('id'));
            $currentPage = $this->_getParam('page', 1);

            $model = new Default_Model_VistaInfoModelosVehiculos();
            $where = $model->getAdapter()->quoteInto('modelo_id=?', $id);
            $informaciones = $model->fetchAll($where);

            $paginador = Zend_Paginator::factory($informaciones);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control_extra.phtml');

            $this->view->informaciones = $paginador;
            $this->renderScript('info-modelo-vehiculo/list-by-modelo.phtml');
        }
    }
    
    public function getFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $request = $this->getRequest();
            $form = new Default_Form_AnotacionVehiculo(null, $this->path);

            if($this->_request->getParam('id')) {

                $id = (int)$this->_request->getParam('id');
                $anotacion = new Default_Model_AnotacionVehiculo();
                $where = $anotacion->getAdapter()->quoteInto("id=?", $id);
                $row = $anotacion->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/anotacion-vehiculo/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Guardar cambios";

            } else {

                $this->view->title = "Agregar anotación";

            }
            echo $form;
        }
    }    
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_OrdenServicio(null, $this->path);
        $this->view->title = 'Crear orden de servicio';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $orden = new Default_Model_OrdenServicio();
                    $row = $orden->createRow();
                    $row->creador = $this->usuario->rut;
                    $row->vehiculo = strtoupper($form->getValue('vehiculo'));
                    //$row->descripcion
                    $row->save();
                    $id = $row->id;
                    $mSession->mensajes[] = 'La orden de servicio fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view','orden-servicio', null, array('id' => $id));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la solicitud de servicio.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','orden-servicio');
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('orden-servicio/form.phtml');
            }
        }
    }

    
}