<?php
class IngresoArticuloController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/ingreso-articulo';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);
            
            $ingreso = new Default_Model_VistaIngresosArticulos();
            $ingresos = $ingreso->fetchAll();

            $paginador = Zend_Paginator::factory($ingresos);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->title = "Ingreso de artículos";
            $this->view->ingresos = $paginador;
            if($this->_getParam('mode')=='check') {
                $this->renderScript('ingreso-articulo/index-review.phtml');
            } else {
                $this->renderScript('ingreso-articulo/index.phtml');
            }
        }

    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_IngresoArticulo(null, $this->path);
            $this->view->title = "Crear ingreso";

            if($this->_getParam('codigo')){

                $codigo = $this->_getParam('codigo');

                $options = array('table' => 'articulos', 'field' => 'codigo');
                $validadorArticulo = new Zend_Validate_Db_RecordExists($options);

                if($validadorArticulo->isValid($codigo)) {
                    $form->articulo->setValue($codigo);
                }
            }

            $this->view->form = $form;
            $this->renderScript('ingreso-articulo/form.phtml');
        }
    }

    public function getFormCostoAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_CostoArticulo(null, $this->path);
            $this->view->title = "Crear ingreso";

            if(isset($mSession->documentoIngreso)) {
                $form->populate($mSession->documentoIngreso);
            }

            $this->view->form = $form;
            $this->renderScript('ingreso-articulo/form-costo.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_IngresoArticulo(null, $this->path);
        $this->view->title = 'Agregar artículos al stock';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    if(Default_Model_TipoIngresoArticulo::detallarCosto($form->getValue('tipo_ingreso_id'))==true) {
                        
                        $mSession->ingresoArticulo = array();
                        $mSession->ingresoArticulo['creador'] = $this->usuario->rut;
                        $mSession->ingresoArticulo['tipo_ingreso_id'] = $form->getValue('tipo_ingreso_id');
                        $mSession->ingresoArticulo['articulo'] = $form->getValue('articulo');
                        $mSession->ingresoArticulo['cantidad'] = $form->getValue('cantidad');
                        if($form->getValue('observaciones')!='') {
                            $mSession->ingresoArticulo['observaciones'] = $form->getValue('observaciones');
                        } else {
                            $mSession->ingresoArticulo['observaciones'] = NULL;
                        }
                        
                        $this->_forward('get-form-costo','ingreso-articulo');
                        
                    } else {
                        
                        $ingreso = new Default_Model_IngresoArticulo();
                        $row = $ingreso->createRow();
                        $row->creador = $this->usuario->rut;
                        $row->tipo_ingreso_id = $form->getValue('tipo_ingreso_id');
                        $row->articulo = $form->getValue('articulo');
                        $row->cantidad = $form->getValue('cantidad');
                        if($form->getValue('observaciones')!='') {
                            $row->observaciones = $form->getValue('observaciones');
                        } else {
                            $row->observaciones = NULL;
                        }
                        $row->save();

                        $mSession->mensajes[] = 'El ingreso fue realizado de forma exitosa.';
                        $mSession->claseMensaje = 'confirmacion';

                        $this->_forward('index','ingreso-articulo');
                    }
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar realizar el ingreso.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','ingreso-articulo');
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('ingreso-articulo/form.phtml');
            }
        }
    }


    public function costoAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_CostoArticulo(null, $this->path);
        $this->view->title = 'Costo del artículo';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost()) AND isset($mSession->ingresoArticulo)) {

                try {

                    $ingreso = new Default_Model_IngresoArticulo();
                    $row = $ingreso->createRow();
                    $row->creador = $mSession->ingresoArticulo['creador'];
                    $row->tipo_ingreso_id = $mSession->ingresoArticulo['tipo_ingreso_id'];
                    $row->articulo = $mSession->ingresoArticulo['articulo'];
                    $row->cantidad = $mSession->ingresoArticulo['cantidad'];
                    $row->observaciones = $mSession->ingresoArticulo['observaciones'];
                    $row->save();

                    $documento = new Default_Model_DocumentoIngresoArticulo();
                    $row_doc = $documento->createRow();
                    $row_doc->ingreso_id = $row->id;
                    $row_doc->proveedor = $form->getValue('proveedor');
                    $row_doc->tipo_id = $form->getValue('tipo_id');
                    $row_doc->numero_documento = $form->getValue('numero_documento');
                    $row_doc->save();


                    $costo = new Default_Model_CostoArticulo();
                    $row_costo = $costo->createRow();
                    $row_costo->documento_id = $row_doc->id;
                    $row_costo->costo_neto_real = $form->getValue('costo_neto_real');
                    $row_costo->costo_neto_corregido =  $row_costo->costo_neto_real;
                    $row_costo->save();

                    $mSession->mensajes[] = 'El ingreso fue realizado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    if($form->getValue('accion')=='1'){

                        unset($mSession->ingresoArticulo);

                        $mSession->documentoIngreso = array();
                        $mSession->documentoIngreso['proveedor'] = $form->getValue('proveedor');
                        $mSession->documentoIngreso['tipo_id'] = $form->getValue('tipo_id');
                        $mSession->documentoIngreso['numero_documento'] = $form->getValue('numero_documento');
                        
                        $this->_forward('get-form','ingreso-articulo');

                    } elseif($form->getValue('accion')=='2') {

                        if(isset($mSession->documentoIngreso)) {
                            unset($mSession->documentoIngreso);
                        }

                        $this->_forward('get-form','ingreso-articulo');

                    } else {

                        if(isset($mSession->documentoIngreso)) {
                            unset($mSession->documentoIngreso);
                        }

                        $this->_forward('index','ingreso-articulo');

                    }
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar realizar el ingreso.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','ingreso-articulo');
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('ingreso-articulo/form.phtml');
            }
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $ingreso = new Default_Model_VistaIngresosArticulos();

            $id = (int)$this->_getParam('id');
            $where = $ingreso->getAdapter()->quoteInto("id=?", $id);
            $row = $ingreso->fetchRow($where);
            $this->view->title = "Ingreso de artículos Nº $id";

            if(false==$row) {
                $this->_forward('index','ingreso-articulo');
            } else {

                $this->view->ingreso = $row;

                if($row->estado=='PENDIENTE') {
                    $this->renderScript('ingreso-articulo/view-simple.phtml');
                } else {
                    $this->renderScript('ingreso-articulo/view.phtml');
                }
            }
        }
    }
}