<?php
class IngresoCajaChicaController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/ingreso-caja-chica';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function listByCicloAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('cc_ciclos_cajas', 'id', (int)$this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');
            $currentPage = $this->_getParam('page', 1);
            $model = new Default_Model_VistaCajasChicasIngresos();
            $where = $model->getAdapter()->quoteInto('ciclo_id=?', $id);
            $ingresos = $model->fetchAll($where);

            $paginador = Zend_Paginator::factory($ingresos);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control_extra.phtml');

            $this->view->ingresos = $paginador;
            $this->view->u = $this->_getParam('type_user');
            $this->renderScript('ingreso-caja-chica/list-by-ciclo.phtml');
        }
    }

    public function getFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $request = $this->getRequest();
            $form = new Default_Form_IngresoCajaChica(null, $this->path);
            $this->view->title = "Registrar ingreso a caja chica";
            $this->view->form = $form;
            $this->renderScript('caja-chica/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_IngresoCajaChica(null, $this->path);
        $this->view->title = 'Registrar ingreso a caja chica';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $caja_id = $form->getValue('caja_id');

                    $ingreso = new Default_Model_CajaChicaIngreso();
                    $row = $ingreso->createRow();
                    $row->ciclo_id = Default_Model_VistaCajasChicasCiclos::_getActivo($caja_id);
                    $row->tipo_id = '2';
                    $row->fecha = date("Y-m-d");
                    $row->cantidad = $form->getValue('cantidad');
                    $row->save();

                    $mSession->mensajes[] = 'El ingreso se ha registrado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view','caja-chica', null, array('id' => $caja_id));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar registrar el ingreso.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','caja-chica');
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('caja-chica/form.phtml');
            }
        }
    }

    public function confirmarAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('cc_ingresos', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');

            $ingreso = new Default_Model_CajaChicaIngreso();
            $where = $ingreso->getAdapter()->quoteInto("id=?", $id);
            $row = $ingreso->fetchRow($where);

            if($row->estado == 'PENDIENTE'){
                $row->estado = 'RECIBIDO';
                $row->save();
            }

            $this->_forward('user', 'caja-chica');
        }
    }

    public function deleteAction()
    {
        if($this->_getParam('id') AND
           $this->_helper->validateRecordExists('cc_ingresos', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            
            try {
                
                $model = new Default_Model_CajaChicaIngreso();
                $modelVista = new Default_Model_VistaCajasChicasIngresos();

                $where = $model->getAdapter()->quoteInto("id = ?" , (int)$this->_getParam('id'));

                $rowVista = $modelVista->fetchRow($where);
                $caja_id = $rowVista->caja_id;

                if($rowVista->estado=='PENDIENTE'){
                    $model->delete($where);
                }

                $mSession->mensajes[] = 'El ingreso caja chica fue eliminada de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_forward('view','caja-chica', null, array('id' => $caja_id));

            } catch (Exception $e) {

                $mSession->tipo_error = 1;
                $mSession->errores[] = $e->getMessage();
                $this->_forward('error-delete-registro','error');
                
            }
        }
    }

    public function formConsultaAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            if($this->_getParam('type_user')=='a') {

                if($this->_getParam('id')!='0' &&
                   $this->_helper->validateRecordExists('cc_cajas', 'id', App_Rut::cleanToDb($this->_getParam('id')))) {
                    $this->view->caja_id = App_Rut::cleanToDb($this->_getParam('id'));
                }
                $this->view->cajas = Default_Model_VistaCajasChicas::getPairsToSelect();
                $this->view->back = '/caja-chica/view/' . App_Rut::cleanToDb($this->_getParam('id'));
                $this->view->user = 'a';
                
            } elseif($this->_getParam('type_user')=='u') {
                $this->view->back = '/caja-chica/user';
                $this->view->user = 'u';
            }
            $this->view->title = "Consultar ingresos de dinero";
            $this->renderScript('ingreso-caja-chica/form-consulta.phtml');
        }
    }

    public function consultaAction()
    {
        if($_POST) {

            $model = new Default_Model_VistaCajasChicasIngresos();

            if($this->_getParam('type_user')=='u'){
                $where = "caja_id='" . $this->usuario->rut . "'";
                $consulta = "/ingreso-caja-chica/form-consulta/0/u";

            } elseif($this->_getParam('type_user')=='a') {

                $consulta = "/ingreso-caja-chica/form-consulta/0/a";
                if($this->_getParam('caja_id')!='0'){

                    $where = "caja_id='" . $this->_getParam('caja_id') . "'";

                } else {

                    $where = "caja_id IS NOT NULL";
                }

            } else {
                return false;
            }

            // filtro por fechas
            $fecha_i = $this->_getParam('fecha_i');
            $fecha_t = $this->_getParam('fecha_t');

            if(Zend_Date::isDate($fecha_i . ' 00:00:00', Zend_Date::ISO_8601)) {
                $fecha_i = $fecha_i . ' 00:00:00';
                $where .= " AND fecha > '" . $fecha_i . "'";
            }

            if(Zend_Date::isDate($fecha_t . ' 23:59:59', Zend_Date::ISO_8601)) {
                $fecha_t = $fecha_t . ' 23:59:59';
                $where .= " AND fecha < '" . $fecha_t . "'";
            }

            // filtro por estados
            $estado = (int)$this->_getParam('estado');
            if($estado==1){
                $where .= " AND estado='RECIBIDO'";
            } elseif($estado==1){
                $where .= " AND estado='PENDIENTE'";
            }

            // filtro por tipo de ingreso
            $tipo = (int)$this->_getParam('tipo');
            if($tipo==1){
                $where .= " AND tipo_id='1'";
            } elseif($tipo==2){
                $where .= " AND tipo_id='2'";
            }

            // filtro por montos
            $signo = (int)$this->_getParam('signo');
            $cantidad = (int)$this->_getParam('monto');
            if($signo==1) {
                $where .= " AND cantidad >= '" . $cantidad . "'";
            } elseif($signo==2) {
                $where .= " AND cantidad <= '" . $cantidad . "'";
            }

            $rows = $model->fetchAll($where);

            $this->view->ingresos = $rows;
            $this->view->back = $this->_getParam('back');
            $this->view->user = $this->_getParam('type_user');
            $this->view->consulta = $consulta;
            $this->view->title = "Consultar ingresos de dinero";
            $this->renderScript('ingreso-caja-chica/resultados-busqueda.phtml');

        } else {
            $this->_forward("form-consulta", "ingreso-caja-chica");
        }
    }
}