<?php
class ItemSolicitudCompraController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();

        if (!$auth->hasIdentity()) {
            $this->_redirect('/');
        }
    }
    
    public function init()
    {
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/item-solicitud-compra';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function getFormAction()
    {

        if($this->getRequest()->isXmlHttpRequest()){
            
            if($this->_getParam('id') AND
               $this->_helper->validateRecordExists('items_solicitudes_compras','id', $this->_getParam('id'))) {

                $request = $this->getRequest();
                $form = new Default_Form_ItemSolicitudCompra();

                $item = new Default_Model_ItemSolicitudCompra();
                $where = $item->getAdapter()->quoteInto("id=?", (int)$this->_request->getParam('id'));
                $row = $item->fetchRow($where)->toArray();
                $form->populate($row);
                $form->tipo_valor->setValue('NETO');
                $form->tipo_descuento->setValue('MONTO');
                $form->setAction('/item-solicitud-compra/edit');
                $form->submit->setLabel('Guardar cambios');
                
                echo $form;
                
            } elseif($this->_getParam('from_id') AND
                     $this->_helper->validateRecordExists('solicitudes_compras','id', $this->_getParam('from_id'))) {

                $request = $this->getRequest();
                $form = new Default_Form_ItemSolicitudCompra();

                $form->buscador->setLabel('Buscar artículo');
                $form->buscador->setAttrib('onkeypress', 'ajaxSearchArticulo($(this), "#codigo", "#valor_neto", "#nombre", "#descripcion")');
                $form->solicitud_id->setValue($this->_request->getParam('from_id'));
                echo $form;
            }
        }
    }

    public function newAction()
    {
        if($_POST) {

            $request = $this->getRequest();
            $form = new Default_Form_ItemSolicitudCompra();

            if ($this->getRequest()->isPost()) {
                if ($form->isValid($request->getPost())) {
                    
                    try {
                        
                        $item = new Default_Model_ItemSolicitudCompra();
                        $row = $item->createRow();
                        
                        $row->solicitud_id = $form->getValue('solicitud_id');
                        if($form->getValue('orden_id')!=''){
                            $row->orden_id = $form->getValue('orden_id');
                        }
                        $row->codigo = $form->getValue('codigo');
                        $row->cantidad = $form->getValue('cantidad');
                        $row->unidad_medida = $form->getValue('unidad_medida');
                        $row->descuento = $this->_calcularDescuento($form->getValue('tipo_descuento'), $form->getValue('descuento'), $form->getValue('valor_neto'));
                        $row->valor_neto = $this->_calcularValorNeto($form->getValue('tipo_valor'), $form->getValue('valor_neto'));
                        $row->nombre = $form->getValue('nombre');
                        $row->descripcion = $form->getValue('descripcion');
                        
                        $row->save();

                        $form->reset();
                        $form->solicitud_id->setValue($row->solicitud_id);

                        $aviso = '<div id="aviso-form" class="confirmacion"><ul>';
                        $aviso .= '<li>El ítem fue agregado de forma satisfactoria. </li>';
                        $aviso .= '</ul></div>';

                        echo $aviso.$form;

                    } catch (Exception $e) {

                        $aviso = '<div id="aviso-form" class="error"><ul><li>Ocurrió un error el intentar agregar el ítem</li></ul></div>';

                    }

                } else {
                    $form->populate($request->getPost());
                    $form->buscador->setLabel('Buscar artículo');
                    $form->buscador->setAttrib('onkeypress', 'ajaxSearchArticulo($(this), "#codigo", "#neto", "#descripcion")');
                    echo $form;
                }
            }
        }
        
    }

    public function editAction()
    {
        if($_POST) {

            $request = $this->getRequest();
            $form = new Default_Form_ItemSolicitudCompra();

            if ($this->getRequest()->isPost()) {
                if ($form->isValid($request->getPost())) {

                    try {

                        $id = $form->getValue('id');

                        $item = new Default_Model_ItemSolicitudCompra();
                        $where = $item->getAdapter()->quoteInto("id=?", $id);
                        $row = $item->fetchRow($where);
                        
                        if($form->getValue('orden_id')!=''){
                            $row->orden_id = $form->getValue('orden_id');
                        } else {
                            $row->orden_id = NULL;
                        }
                        
                        $row->codigo = $form->getValue('codigo');
                        $row->cantidad = $form->getValue('cantidad');
                        $row->unidad_medida = $form->getValue('unidad_medida');
                        $row->descuento = $this->_calcularDescuento($form->getValue('tipo_descuento'), $form->getValue('descuento'), $form->getValue('valor_neto'));
                        $row->valor_neto = $this->_calcularValorNeto($form->getValue('tipo_valor'), $form->getValue('valor_neto'));
                        $row->nombre = $form->getValue('nombre');
                        $row->descripcion = $form->getValue('descripcion');
                        $row->save();
                        $aviso = '<div id="aviso-form" class="confirmacion"><ul>';
                        $aviso .= '<li>El ítem fue editado de forma satisfactoria. </li>';
                        $aviso .= '</ul></div>';

                        echo $aviso;

                    } catch (Exception $e) {

                        $aviso = '<div id="aviso-form" class="error"><ul><li>Ocurrió un error el intentar editar el ítem</li></ul></div>';
                    }
                } else {
                    $form->populate($request->getPost());
                    echo $form;
                }
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $solicitud_id = $this->_getParam('solicitud_id');

            if($this->_helper->validateRecordExists('solicitudes_compras', 'id', $solicitud_id)){

                $data = $this->_getParam('data');
                $items = explode(",", $data);

                $itemSolicitudCompra = new Default_Model_ItemSolicitudCompra();

                foreach($items as $id){

                    if($this->_helper->validateRecordExists('items_solicitudes_compras', 'id', $id)){
                        $where = $itemSolicitudCompra->getAdapter()->quoteInto("id=?", $id);
                        $itemSolicitudCompra->delete($where);
                    }
                }
                return true;
            }
        }
    }

    private function _calcularDescuento($tipo, $descuento, $neto)
    {
        if(!isset($tipo) OR !isset($descuento) OR !isset($neto)){
            return false;
        }

        if($tipo=='MONTO') {
            return $descuento;
        }

        if($tipo=='PORCENTAJE'){
            $monto = round($neto * ($descuento/100));
            return $monto;
        }
    }

    private function _calcularValorNeto($tipo, $valor)
    {
        if(!isset($tipo) OR !isset($valor)){
            return 0;
        }

        if($tipo=='NETO') {
            return $valor;
        }

        if($tipo=='BRUTO'){
            $iva = 1 + (Default_Model_Preferencia::getPref('IVA') / 100);
            $monto = $valor / $iva;
            return round($monto);
        }
    }
}