<?php
class ItemSolicitudCompraRepuestoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();

        if (!$auth->hasIdentity()) {
            $this->_redirect('/');
        }
    }
    
    public function init()
    {
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/item-solicitud-compra-repuesto';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function getFormAction()
    {

        if($this->getRequest()->isXmlHttpRequest()){
            
            if($this->_getParam('id') AND
               $this->_helper->validateRecordExists('items_solicitudes_compras_repuestos','id', $this->_getParam('id'))) {

                $request = $this->getRequest();
                $form = new Default_Form_ItemSolicitudCompraRepuesto();

                $item = new Default_Model_ItemSolicitudCompraRepuesto();
                $where = $item->getAdapter()->quoteInto("id=?", (int)$this->_request->getParam('id'));
                $row = $item->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/item-solicitud-compra-repuesto/edit');
                $form->submit->setLabel('Guardar cambios');
                
                echo $form;
                
            } elseif($this->_getParam('from_id') AND
                     $this->_helper->validateRecordExists('solicitudes_compras_repuestos','id', $this->_getParam('from_id'))) {

                $request = $this->getRequest();
                $form = new Default_Form_ItemSolicitudCompraRepuesto();
                $form->solicitud_id->setValue($this->_request->getParam('from_id'));
                echo $form;
            }
        }
    }

    public function newAction()
    {
        if($_POST) {

            $request = $this->getRequest();
            $form = new Default_Form_ItemSolicitudCompraRepuesto();

            if ($this->getRequest()->isPost()) {
                if ($form->isValid($request->getPost())) {
                    
                    try {

                        $item = new Default_Model_ItemSolicitudCompraRepuesto();
                        $row = $item->createRow();
                        $row->solicitud_id = $form->getValue('solicitud_id');
                        $row->nombre = $form->getValue('nombre');
                        $row->cantidad = $form->getValue('cantidad');
                        $row->actual_codigo = $form->getValue('actual_codigo');
                        $row->actual_marca = $form->getValue('actual_marca');
                        $row->actual_descripcion = $form->getValue('actual_descripcion');
                        $row->nuevo_codigo = $form->getValue('nuevo_codigo');
                        $row->nuevo_marca = $form->getValue('nuevo_marca');
                        $row->nuevo_descripcion = $form->getValue('nuevo_descripcion');
                        $row->muestra = $form->getValue('muestra');
                        $row->save();

                        $form->reset();
                        $form->solicitud_id->setValue($row->solicitud_id);

                        $aviso = '<div id="aviso-form" class="confirmacion"><ul>';
                        $aviso .= '<li>El ítem fue agregado de forma satisfactoria. </li>';
                        $aviso .= '</ul></div>';

                        echo $aviso.$form;

                    } catch (Exception $e) {
                        $aviso = '<div id="aviso-form" class="error"><ul><li>Ocurrió un error el intentar agregar el ítem</li></ul></div>';
                    }

                } else {
                    $form->populate($request->getPost());
                    echo $form;
                }
            }
        }
    }

    public function editAction()
    {
        if($_POST) {

            $request = $this->getRequest();
            $form = new Default_Form_ItemSolicitudCompraRepuesto();

            if ($this->getRequest()->isPost()) {
                if ($form->isValid($request->getPost())) {

                    try {

                        $id = $form->getValue('id');

                        $item = new Default_Model_ItemSolicitudCompraRepuesto();
                        $where = $item->getAdapter()->quoteInto("id=?", $id);
                        $row = $item->fetchRow($where);
                        $row->nombre = $form->getValue('nombre');
                        $row->cantidad = $form->getValue('cantidad');
                        $row->actual_codigo = $form->getValue('actual_codigo');
                        $row->actual_marca = $form->getValue('actual_marca');
                        $row->actual_descripcion = $form->getValue('actual_descripcion');
                        $row->nuevo_codigo = $form->getValue('nuevo_codigo');
                        $row->nuevo_marca = $form->getValue('nuevo_marca');
                        $row->nuevo_descripcion = $form->getValue('nuevo_descripcion');
                        $row->muestra = $form->getValue('muestra');
                        $row->save();

                        $aviso = '<div id="aviso-form" class="confirmacion"><ul>';
                        $aviso .= '<li>El ítem fue editado de forma satisfactoria. </li>';
                        $aviso .= '</ul></div>';

                        echo $aviso;

                    } catch (Exception $e) {

                        $aviso = '<div id="aviso-form" class="error"><ul><li>Ocurrió un error el intentar editar el ítem</li></ul></div>';
                    }
                } else {
                    $form->populate($request->getPost());
                    echo $form;
                }
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $solicitud_id = $this->_getParam('solicitud_id');

            if($this->_helper->validateRecordExists('solicitudes_compras_repuestos', 'id', $solicitud_id)){

                $data = $this->_getParam('data');
                $items = explode(",", $data);

                $itemSolicitudCompra = new Default_Model_ItemSolicitudCompraRepuesto();

                foreach($items as $id){

                    if($this->_helper->validateRecordExists('items_solicitudes_compras_repuestos', 'id', $id)){
                        $where = $itemSolicitudCompra->getAdapter()->quoteInto("id=?", $id);
                        $itemSolicitudCompra->delete($where);
                    }
                }
                return true;
            }
        }
    }
}