<?php
class MarcaVehiculoController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/marca-vehiculo';
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            
            $currentPage = $this->_getParam('page', 1);

            $marca_vehiculo = new Default_Model_MarcaVehiculo();
            $marcas = $marca_vehiculo->fetchAll();

            $paginador = Zend_Paginator::factory($marcas);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
            
            $this->view->marcas = $paginador;
            $this->view->title = 'Marcas de vehículos';

            $this->renderScript('marca-vehiculo/index.phtml');
        }

    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_MarcaVehiculo(null, $this->path);

            if($this->_request->getParam('id')) {

                $marca = new Default_Model_MarcaVehiculo();
                $where = $marca->getAdapter()->quoteInto("id=?", (int)$this->_request->getParam('id'));
                $row = $marca->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/marca-vehiculo/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar marca de vehículos";

            } else {

                $this->view->title = "Agregar marca de vehículos";

            }
            $this->view->form = $form;
            $this->renderScript('marca-vehiculo/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Default_Form_MarcaVehiculo(null, $this->path);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    
                    $marca = new Default_Model_MarcaVehiculo();
                    $row = $marca->createRow();
                    $row->nombre = $form->getValue('nombre');
                    $row->cargo_adicional = $form->getValue('cargo_adicional');
                    $row->save();
                    $mSession->mensajes[] = 'El registro fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                }

                $this->_forward('index', 'marca-vehiculo');
                
            } else {
                $this->view->title = 'Agregar marca de vehículo';
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('marca-vehiculo/form.phtml');
            }
        }
        $this->view->form = $form;
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $marca = new Default_Model_MarcaVehiculo();

        $request = $this->getRequest();
        $form = new Default_Form_MarcaVehiculo(null, $this->path);
        $form->setAction($this->path . '/edit');
        $form->submit->setLabel("guardar cambios");

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {
                
                try {
                    
                    $where = $marca->getAdapter()->quoteInto("id=?", (int)$form->getValue('id'));
                    $row = $marca->fetchRow($where);
                    $row->nombre = $form->getValue('nombre');
                    $row->cargo_adicional = $form->getValue('cargo_adicional');
                    $row->save();
                    $mSession->mensajes[] = 'El registro fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                }
                
                $this->_forward('index', 'marca-vehiculo');
                
            } else {
                $this->view->title = 'Editar marca de vehículo';
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('marca-vehiculo/form.phtml');
            }
        } else {

            if ($this->_request->getParam('id')) {
                
                $where = $marca->getAdapter()->quoteInto("id=?", (int)$this->_request->getParam('id'));
                $registro = $marca->fetchRow($where);
                $form->populate($registro->toArray());
            }
        }
        $form->setAction($this->path . '/edit');
        $form->submit->setLabel("guardar cambios");
        $this->view->form = $form;
    }

    public function deleteAction()
    {
        if($this->_getParam('id')){

            $mSession = new Zend_Session_Namespace('expressauto');
            
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            try {

                $model = new Default_Model_MarcaVehiculo();
                $where = $model->getAdapter()->quoteInto("id = ?" , (int)$this->_getParam('id'));
                $model->delete($where);

                $mSession->mensajes[] = 'La marca de vehículo fue eliminada de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';

                $this->_forward('index','marca-vehiculo');

            } catch (Exception $e) {

                $mSession->tipo_error = 1;
                $mSession->errores[] = $e->getMessage();

                $this->_forward('error-delete-registro','error');
            }
        }
    }
}