<?php
class ModeloVehiculoController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/modelo-vehiculo';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $modelo = new Default_Model_VistaModelosVehiculos();
            $order = 'marca';
            $modelos = $modelo->fetchAll(null, $order);

            $paginador = Zend_Paginator::factory($modelos);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->modelos = $paginador;
            $this->view->title = 'Modelos de vehículos';

            $this->renderScript('modelo-vehiculo/index.phtml');
        }
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_ModeloVehiculo(null, $this->path);

            if($this->_request->getParam('id')) {

                $modelo = new Default_Model_ModeloVehiculo();
                $where = $modelo->getAdapter()->quoteInto("id=?", (int)$this->_request->getParam('id'));
                $row = $modelo->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/modelo-vehiculo/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar modelo de vehículo";

            } else {

                $this->view->title = "Agregar modelo de vehículo";

            }
            $this->view->form = $form;
            $this->renderScript('modelo-vehiculo/form.phtml');
        }
    }

    public function getFormModalAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_ModeloVehiculoModal();
            $this->view->title = "Agregar modelo de vehículo";
            echo $form;
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Default_Form_ModeloVehiculo(null, $this->path);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    
                    $modelo = new Default_Model_ModeloVehiculo();
                    $row = $modelo->createRow();
                    $row->marca_id = $form->getValue('marca_id');
                    $row->nombre = $form->getValue('nombre');
                    $row->version = $form->getValue('version');
                    $row->cilindrada = $form->getValue('cilindrada');
                    $row->traccion = $form->getValue('traccion');
                    $row->years = $form->getValue('years');
                    $row->tipo_combustible = $form->getValue('tipo_combustible');
                    $row->cargo_adicional = $form->getValue('cargo_adicional');
                    $row->save();
                    
                    $mSession->mensajes[] = 'El registro fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    if($form->getValue('accion')==1){
                        $this->_forward('get-form-info-adicional', 'modelo-vehiculo', null, array('id' => $row->id));
                    } else {
                        $this->_forward('view', 'modelo-vehiculo', null, array('id' => $row->id));
                    }

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                    $this->_forward('index', 'modelo-vehiculo');
                }

                

            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
    }

    public function newModalAction()
    {
        $request = $this->getRequest();
        $form = new Default_Form_ModeloVehiculo(null, $this->path);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $modelo = new Default_Model_ModeloVehiculo();
                    $row = $modelo->createRow();
                    $row->marca_id = $form->getValue('marca_id');
                    $row->nombre = $form->getValue('nombre');
                    $row->version = $form->getValue('version');
                    $row->cilindrada = $form->getValue('cilindrada');
                    $row->traccion = $form->getValue('traccion');
                    $row->years = $form->getValue('years');
                    $row->tipo_combustible = $form->getValue('tipo_combustible');
                    $row->cargo_adicional = $form->getValue('cargo_adicional');
                    $row->save();

                } catch (Exception $e) {

                    echo 'Error';
                }
            } else {
                $form->populate($request->getPost());
            }
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $modelo = new Default_Model_ModeloVehiculo();
        $request = $this->getRequest();
        $form = new Default_Form_ModeloVehiculo();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $id = (int)$form->getValue('id');
                    $where = $modelo->getAdapter()->quoteInto("id=?", $id);
                    $row = $modelo->fetchRow($where);
                    $row->marca_id = $form->getValue('marca_id');
                    $row->nombre = $form->getValue('nombre');
                    $row->version = $form->getValue('version');
                    $row->years = $form->getValue('years');
                    $row->cilindrada = $form->getValue('cilindrada');
                    $row->traccion = $form->getValue('traccion');
                    $row->tipo_combustible = $form->getValue('tipo_combustible');
                    $row->cargo_adicional = $form->getValue('cargo_adicional');
                    $row->save();

                    $mSession->mensajes[] = 'El modelo de vehículo fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    if($form->getValue('accion')==1){
                        $this->_forward('get-form-info-adicional', 'modelo-vehiculo', null, array('id' => $row->id));
                    } else {
                        $this->_forward('view', 'modelo-vehiculo', null, array('id' => $row->id));
                    }

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','modelo-vehiculo');
                }
            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/modelo-vehiculo/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar modelo de vehiculo";
                $this->renderScript('modelo-vehiculo/form.phtml');
            }
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('modelos_vehiculos','id',$this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = $this->_getParam('id');

            $modelo = new Default_Model_VistaModelosVehiculos();
            $where = $modelo->getAdapter()->quoteInto("id=?", $id);
            $row = $modelo->fetchRow($where);

            $pauta = new Default_Model_PautaModelo();
            $where_pautas = $pauta->getAdapter()->quoteInto("modelo_id=?", $id);
            $pautas = $pauta->fetchAll($where_pautas);

            $this->view->modelo = $row;
            $this->view->pautas = $pautas;
            $this->view->title = 'Modelo de vehículo';

            $this->renderScript('modelo-vehiculo/view.phtml');
        }

    }

    public function deleteAction()
    {
        if($this->_getParam('id')){
            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $model = new Default_Model_ModeloVehiculo();
            $where = $model->getAdapter()->quoteInto("id = ?" , (int)$this->_getParam('id'));
            $model->delete($where);
            $mSession->mensajes[] = 'El modelo de vehículo fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('index','modelo-vehiculo');
        }
    }

    public function getFormInfoAdicionalAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('modelos_vehiculos', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $this->view->title = "Información adicional ";
            $id = (int)$this->_getParam('id');

            $request = $this->getRequest();
            $form = new Default_Form_DetallesModeloVehiculo(null, $this->path, '/modelo-vehiculo/view/id/'.$id);

            $modelo = new Default_Model_VistaModelosVehiculos();
            $where = $modelo->getAdapter()->quoteInto("id=?", $id);
            $row = $modelo->fetchRow($where)->toArray();

            $nombreModelo = $row['marca'] . ' : ' . $row['nombre'] . ' : ' . $row['version'] . ' : ' . $row['years'];

            $form->populate($row);
            $form->modelo->setValue($nombreModelo);
            $this->view->form = $form;
            $this->renderScript('modelo-vehiculo/form.phtml');
        }
    }

    public function editInfoAdicionalAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Default_Form_DetallesModeloVehiculo(null, $this->path);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $id = $form->getValue('id');
                    $modelo = new Default_Model_ModeloVehiculo();
                    $where = $modelo->getAdapter()->quoteInto("id=?", $id);
                    $row = $modelo->fetchRow($where);
                    $row->obs_lit_aceite_motor      = $this->_helper->checkNullToDb($form->getValue('obs_lit_aceite_motor'));
                    $row->obs_lit_aceite_caja       = $this->_helper->checkNullToDb($form->getValue('obs_lit_aceite_caja'));
                    $row->obs_filtro_aceite         = $this->_helper->checkNullToDb($form->getValue('obs_filtro_aceite'));
                    $row->obs_filtro_aire           = $this->_helper->checkNullToDb($form->getValue('obs_filtro_aite'));
                    $row->obs_filtro_combustible    = $this->_helper->checkNullToDb($form->getValue('obs_filtro_combustible'));
                    $row->obs_bujias                = $this->_helper->checkNullToDb($form->getValue('obs_bujias'));
                    $row->save();

                    $mSession->mensajes[] = 'La información adicional fue guardada de forma existosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view', 'modelo-vehiculo', null, array('id' => $id));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar guardar la información adicional.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                    $this->_forward('index', 'modelo-vehiculo');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
    }

    public function asignarPautaAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('pauta_id') AND
           $this->_helper->validateRecordExists('pautas_mantenciones', 'id', $this->_getParam('pauta_id')) AND 
           $this->_getParam('modelo_id') AND
           $this->_helper->validateRecordExists('modelos_vehiculos', 'id', $this->_getParam('modelo_id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $modelo_id = $this->_getParam('modelo_id');
            $pauta_id = (int)$this->_getParam('pauta_id');

            try {

                $pautaModelo = new Default_Model_PautaModelo();
                $where = "pauta_id='$pauta_id' AND modelo_id='$modelo_id'";
                $row = $pautaModelo->fetchRow($where);

                if(!$row){
                    $new = $pautaModelo->createRow();
                    $new->modelo_id = $modelo_id;
                    $new->pauta_id = $pauta_id;
                    $new->save();
                }

                $this->_forward('view', 'modelo-vehiculo', null, array('id' => $modelo_id));

            } catch (Exception $e) {

                $this->_forward('view', 'modelo-vehiculo', null, array('id' => $modelo_id));

            }
        }
    }

    public function eliminarAsociacionPautaAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('patente') AND
           $this->_helper->validateRecordExists('vehiculos', 'patente', $this->_getParam('patente'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $patente = $this->_getParam('patente');

            try {

                $vehiculo = new Default_Model_Vehiculo();
                $where = $vehiculo->getAdapter()->quoteInto("patente=?", $patente);
                $row = $vehiculo->fetchRow($where);
                $row->pauta_id = null;
                $row->save();

                $this->_forward('view', 'vehiculo', null, array('patente' => $patente));

            } catch (Exception $e) {

                $this->_forward('view', 'vehiculo', null, array('patente' => $patente));

            }
        }
    }
}