<?php
class NotaCompraController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/nota-compra';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->preferencias = Default_Model_NotaCompra::_getPrefs();
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $nota = new Default_Model_VistaNotasCompras();
            $notas = $nota->fetchAll();

            $paginador = Zend_Paginator::factory($notas);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->notas = $paginador;
            $this->view->title = 'Notas de compra';
            $this->renderScript('nota-compra/index.phtml');
        }
    }

    public function getFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $request = $this->getRequest();
            $form = new Default_Form_NotaCompra(null, $this->path);

            if($this->_request->getParam('id')) {

                $id = (int)$this->_request->getParam('id');
                $nota = new Default_Model_NotaCompra();
                $where = $nota->getAdapter()->quoteInto("id=?", $id);
                $row = $nota->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/nota-compra/edit');
                $rut = App_Rut::format($form->proveedor->getValue());
                $form->proveedor->setValue($rut);
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar nota de compra Nº $id";

            } else {
                $this->view->title = "Crear nota de compra";
            }
            $this->view->form = $form;
            $this->renderScript('nota-compra/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_NotaCompra(null, $this->path);
        $this->view->title = 'Crear nota de compra';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $nota = new Default_Model_NotaCompra();
                    $row = $nota->createRow();
                    $row->creador = $this->usuario->rut;
                    $row->proveedor = App_Rut::cleanToDb($form->getValue('proveedor'));
                    $row->iva = $this->view->getPref('IVA');
                    if($form->getValue('observaciones')!='') {
                        $row->observaciones = $form->getValue('observaciones');
                    } else {
                        $row->observaciones = NULL;
                    }
                    $row->estado = 'BORRADOR';
                    $row->save();
                    $id = $row->id;
                    $mSession->mensajes[] = 'La nota de venta fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view','nota-compra', null, array('id'=>$id));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la nota de compra.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','nota-compra');
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('nota-compra/form.phtml');
            }
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('notas_compras', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');
            $nota = new Default_Model_VistaNotasCompras();
            $where = $nota->getAdapter()->quoteInto("id=?", $id);
            $row = $nota->fetchRow($where);

            $envio = new Default_Model_EnvioDocumento();
            $where_envio = "documento_id='$id' AND tipo='nota-compra'";
            $order_envio = "id DESC";
            $count_envio = '1';
            $rows_envios = $envio->fetchAll($where_envio, $order_envio, $count_envio)->toArray();

            $items = new Default_Model_ItemNotaCompra();
            $where_items = $items->getAdapter()->quoteInto("nota_id=?", $id);

            if(false==$row) {
                $this->_forward('index','nota-compra');
            } else {

                $this->view->title = "Nota de compra Nº $id";
                $this->view->nota = $row;
                $this->view->items = $items->fetchAll($where_items);
                $this->view->envios = $rows_envios;

                if($row->estado=='BORRADOR') {

                    $this->renderScript('nota-compra/view-borrador.phtml');

                } elseif($row->estado=='PENDIENTE') {

                    $this->view->title .= " : Pendiente aprobación";
                    $this->renderScript('nota-compra/view-pendiente.phtml');

                } elseif($row->estado=='EMITIDA') {

                    $this->view->title .= " : En proceso";
                    $this->renderScript('nota-compra/view-emitida.phtml');

                } elseif($row->estado=='FACTURADA') {

                    $this->view->title .= " : Facturada";
                    $this->renderScript('nota-compra/view-facturada.phtml');

                } elseif($row->estado=='RECHAZADA') {

                    $this->view->title .= " : Rechazada";
                    //$rechazo = new Default_Model_RechazoCotizacion();
                    //$this->view->rechazo = $rechazo->fetchRow('cotizacion_id=' . $row->id);
                    $this->renderScript('nota-compra/view-rechazada.phtml');

                } elseif($row->estado=='CANCELADA') {

                    $this->view->title .= " : Cancelada";
                    $this->renderScript('nota-compra/view-cancelada.phtml');

                } else {
                    $this->renderScript('nota-compra/view-simple.phtml');
                }
            }
        }
    }

    public function detalleAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            if($this->_getParam('id') AND
                $this->_helper->validateRecordExists('notas_compras','id', $this->_getParam('id'))){

                $id = $this->_getParam('id');

                $nota = new Default_Model_VistaNotasCompras();
                $where = $nota->getAdapter()->quoteInto("id=?", $id);
                $row = $nota->fetchRow($where);

                $items = new Default_Model_ItemNotaCompra();
                $where_items = $items->getAdapter()->quoteInto("nota_id=?", $id);

                $this->view->items = $items->fetchAll($where_items);
                $this->view->nota = $row;

               $this->renderScript('nota-compra/detalle.phtml');
            }
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $nota = new Default_Model_NotaCompra();

        $request = $this->getRequest();
        $form = new Default_Form_NotaCompra();

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {

                    $id = (int)$form->getValue('id');
                    $where = $nota->getAdapter()->quoteInto("id=?", $id);
                    $row = $nota->fetchRow($where);
                    $row->proveedor = App_Rut::cleanToDb($form->getValue('proveedor'));
                    $row->iva = $this->view->getPref('IVA');
                    if($form->getValue('observaciones')!='') {
                        $row->observaciones = $form->getValue('observaciones');
                    } else {
                        $row->observaciones = NULL;
                    }
                    $row->save();

                    $mSession->mensajes[] = 'La nota de compra fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view', 'nota-compra', null, array('id'=> $id));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la nota de compra.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','nota-compra');
                }

            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/nota-compra/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar nota";
                $this->renderScript('nota-compra/form.phtml');
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('notas_compras', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');
            $nota = new Default_Model_NotaCompra();
            $where = $nota->getAdapter()->quoteInto("id=?", $id);
            $nota->delete($where);
            $mSession->mensajes[] = 'La nota de compra fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('index','nota-compra');
        }
    }

    public function finishAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND 
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('notas_compras', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $v_nota = new Default_Model_VistaNotasCompras();
            $id = $v_nota->getAdapter()->quote($this->_getParam('id'));
            $v_row = $v_nota->fetchRow('id='.$id);

            $nota = new Default_Model_NotaCompra();
            $row = $nota->fetchRow('id='.$id);

            if($v_row->estado=='BORRADOR') {

                if((NULL!=$v_row->total_neto) AND ($v_row->total_neto >= (int)$this->preferencias['NC_MONTO_APROB'])) {
                    $row->estado = 'PENDIENTE';
                } else {
                    $row->estado = 'EMITIDA';
                }
                $row->save();
                $mSession->mensajes[] = 'La nota de compra fue emitida de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
            }
            $this->_forward('view','nota-compra', null, array('id' => $row->id));
        }
    }

    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();

            $formularios = array(
                new Default_Form_BuscarNumero(null, $this->path),
                new Default_Form_ConsultaNotaCompra(null, $this->path),
            );

            $request = $this->getRequest();
            $this->view->formularios = $formularios;
            $this->view->title = 'Notas de compra : Buscar';
            $this->renderScript('nota-compra/find.phtml');
        }
    }
}