<?php
class NotaVentaController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->path = '/nota-venta';
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $propietario = new Default_Model_Propietario();
        $this->view->propietario = $propietario->fetchRow();
        $this->preferencias = Default_Model_NotaVenta::_getPrefs();
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $nota = new Default_Model_VistaNotasVentas();
            $notas = $nota->fetchAll();

            $paginador = Zend_Paginator::factory($notas);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->notas = $paginador;
            $this->view->title = 'Notas de venta';
            $this->renderScript('nota-venta/index.phtml');
        }
    }

    public function getFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $request = $this->getRequest();
            $form = new Default_Form_NotaVenta(null, $this->path);

            if($this->_getParam('id')) {

                $id = (int)$this->_request->getParam('id');
                $nota = new Default_Model_NotaVenta();
                $where = $nota->getAdapter()->quoteInto("id=?", $id);
                $row = $nota->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/nota-venta/edit');
                $rut = App_Rut::format($row['cliente']);
                $form->cliente->setValue($rut);
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar nota de venta Nº $id";

            } else {

                $this->view->title = "Crear nota de venta";
                if($this->_getParam('from_id') &&
                   $this->_helper->validateRecordExists('clientes','rut',  App_Rut::cleanToDb($this->_getParam('from_id')))){
                    $form->cliente->setValue($this->_getParam('from_id'));
                }
            }
            $this->view->form = $form;
            $this->renderScript('nota-venta/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_NotaVenta(null, $this->path);
        $this->view->title = 'Crear nota de venta';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $nota = new Default_Model_NotaVenta();
                    $row = $nota->createRow();
                    $row->creador = $this->usuario->rut;
                    $row->cliente = App_Rut::cleanToDb($form->getValue('cliente'));
                    $row->iva = $this->view->getPref('IVA');

                    if(is_int($form->getValue('recepcion_id'))) {
                        $row->recepcion_id = $form->getValue('recepcion_id');
                    } else {
                        $row->recepcion_id = NULL;
                    }

                    if($form->getValue('observaciones')!='') {
                        $row->observaciones = $form->getValue('observaciones');
                    } else {
                        $row->observaciones = NULL;
                    }
                    
                    $row->estado = 'BORRADOR';
                    $row->save();
                    $id = $row->id;
                    $mSession->mensajes[] = 'La nota de venta fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view','nota-venta', null, array('id'=>$id));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la nota de venta.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','nota-venta');
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('nota-venta/form.phtml');
            }
        } 
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND 
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('notas_ventas', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');
            $nota = new Default_Model_VistaNotasVentas();
            $where = $nota->getAdapter()->quoteInto("id=?", $id);
            $row = $nota->fetchRow($where);
            $items = new Default_Model_ItemNotaVenta();
            $where_items = $items->getAdapter()->quoteInto("nota_id=?", $id);
            $this->view->items = $items->fetchAll($where_items);
            $this->view->title = "Nota de venta Nº $id";

            if(false==$row) {
                $this->_forward('index','nota-venta');
            } else {

                $this->view->nota = $row;

                if($row->estado=='BORRADOR') {

                    $this->renderScript('nota-venta/view-borrador.phtml');

                } elseif($row->estado=='PENDIENTE') {

                    $this->view->title .= " : Pendiente aprobación";
                    $this->renderScript('nota-venta/view-pendiente.phtml');

                } elseif($row->estado=='EN PROCESO') {

                    $this->view->title .= " : En proceso";
                    $this->renderScript('nota-venta/view-en-proceso.phtml');

                } elseif($row->estado=='TERMINADA') {

                    $this->view->title .= " : Terminada";
                    $this->renderScript('nota-venta/view-terminada.phtml');

                } elseif($row->estado=='CANCELADA') {

                    $this->view->title .= " : Cancelada";
                    $this->renderScript('nota-venta/view-cancelada.phtml');

                } else {
                    $this->renderScript('nota-venta/view-simple.phtml');
                }
            }
        }
    }

    public function detalleAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            if($this->_getParam('id') AND
                $this->_helper->validateRecordExists('notas_ventas','id', $this->_getParam('id'))){

                $id = $this->_getParam('id');

                $nota = new Default_Model_VistaNotasVentas();
                $where = $nota->getAdapter()->quoteInto("id=?", $id);
                $row = $nota->fetchRow($where);

                $items = new Default_Model_ItemNotaVenta();
                $where_items = $items->getAdapter()->quoteInto("nota_id=?", $id);

                $this->view->items = $items->fetchAll($where_items);
                $this->view->nota = $row;

               $this->renderScript('nota-venta/detalle.phtml');
            }
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $nota = new Default_Model_NotaVenta();

        $request = $this->getRequest();
        $form = new Default_Form_NotaVenta();

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {

                    $id = (int)$form->getValue('id');
                    $where = $nota->getAdapter()->quoteInto("id=?", $id);
                    $row = $nota->fetchRow($where);
                    $row->creador = $this->usuario->rut;
                    $row->cliente = App_Rut::cleanToDb($form->getValue('cliente'));
                    $row->recepcion_id = $form->getValue('recepcion_id');
                    $row->iva = $this->view->getPref('IVA');
                    if($form->getValue('observaciones')!='') {
                        $row->observaciones = $form->getValue('observaciones');
                    } else {
                        $row->observaciones = NULL;
                    }
                    $row->save();

                    $mSession->mensajes[] = 'La nota de venta fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view', 'nota-venta', null, array('id'=> $id));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la nota de venta.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','nota-venta');
                }

            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/nota-venta/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar nota";
                $this->renderScript('nota-venta/form.phtml');
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $id = (int)$this->_getParam('id');
            $nota = new Default_Model_NotaVenta();
            $where = $nota->getAdapter()->quoteInto("id=?", $id);
            $nota->delete($where);
            $mSession->mensajes[] = 'La nota de venta fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('index','nota-venta');
        } 
    }

    public function newFromAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $cotizacion_id = $this->_getParam('id');
        $cotizacion = new Default_Model_Cotizacion();

        $nota = new Default_Model_NotaVenta();

        $origen = $cotizacion->fetchRow('id='.$cotizacion_id);

        $nueva  = $nota->createRow();
        $nueva->creador = $this->usuario->rut;
        $nueva->cliente = $origen->cliente;
        $nueva->iva = $this->view->getPref('IVA');
        $nueva->observaciones = $origen->observaciones;
        $nueva->estado = 'BORRADOR';
        $nueva->save();

        $nota_id = $nueva->id;

        $item_ct = new Default_Model_ItemCotizacion();
        $item_nv = new Default_Model_ItemNotaVenta();

        $items_origen = $item_ct->fetchAll('cotizacion_id='.$cotizacion_id);

        foreach($items_origen as $item_o){

            $item_n = $item_nv->createRow();
            $item_n->nota_id        = $nota_id;
            $item_n->codigo         = $item_o->codigo;
            $item_n->nombre         = $item_o->nombre;
            $item_n->vehiculo        = $item_o->vehiculo;
            $item_n->descripcion    = $item_o->descripcion;
            $item_n->cantidad       = $item_o->cantidad;
            $item_n->unidad_medida  = $item_o->unidad_medida;
            $item_n->valor_neto     = $item_o->valor_neto;
            $item_n->descuento      = $item_o->descuento;
            $item_n->codigo         = $item_o->codigo;
            $item_n->table          = $item_o->table;
            $item_n->save();
            $item_n = false;

        }

        $this->_forward('view','nota-venta', null, array('id' => $nota_id));

    }

    public function seleccionarItemsCotizacionAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('notas_ventas', 'id', $this->_getParam('id'))){

            $nota_id = (int)$this->_getParam('id');

            $modelNota = new Default_Model_NotaVenta();
            $whereNota = "id='" . $nota_id . "'";
            $rowNota = $modelNota->fetchRow($whereNota);
            
            $modelCotizacion = new Default_Model_VistaCotizaciones();
            $whereCotizacion = "estado='EMITIDA' AND cliente_id='" . $rowNota->cliente . "' AND archivar='0'";
            $cotizacionesDisponibles = $modelCotizacion->fetchAll($whereCotizacion);

            $this->view->cotizaciones = $cotizacionesDisponibles;
            $this->view->nota_id = $nota_id;
            $this->renderScript('nota-venta/seleccionar-items-cotizacion.phtml');
            
        }
    }

    public function listarItemsCotizacionAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('notas_ventas', 'id', $this->_getParam('id'))){
           
            $nota_id = (int)$this->_getParam('id');
            $cotizacion_id = (int)$this->_getParam('from_id');
            
            $model = new Default_Model_ItemCotizacion();
            $where = $model->getAdapter()->quoteInto("cotizacion_id=?", $cotizacion_id);
            $items = $model->fetchAll($where);
            
            $this->view->items = $items;
            $this->view->nota_id = $nota_id;
            $this->view->cotizacion_id = $cotizacion_id;

            $this->renderScript('nota-venta/listar-items-cotizacion.phtml');
            
        }
    }

    public function emitirAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND 
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('notas_ventas', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            
            $vistaNota = new Default_Model_VistaNotasVentas();
            $id = (int)$this->_getParam('id');
            $whereVista = $vistaNota->getAdapter()->quoteInto("id=?", $id);
            $rowVista = $vistaNota->fetchRow($whereVista);

            $nota = new Default_Model_NotaVenta();
            $whereNota = $nota->getAdapter()->quoteInto("id=?", $id);
            $rowNota = $nota->fetchRow($whereNota);

            if($rowVista->estado=='BORRADOR' AND NULL!=$rowVista->total_neto) {

                if($rowVista->total_neto < (int)$this->preferencias['NV_MONTO_APROB']) {

                    if($this->_moveItems((int)$this->_getParam('id'))){

                        $rowNota->estado = 'EN PROCESO';
                        $rowNota->save();
                        $mSession->mensajes[] = 'La nota de venta ha sido emitida de forma satisfatoria.';
                        $mSession->claseMensaje = 'confirmacion';
                        
                    } else {
                        
                        $mSession->mensajes[] = 'Ocurrió un error al intentar mover los ítems a la nota de venta.';
                        $mSession->claseMensaje = 'error';
                        
                    }
                } else {

                    $rowNota->estado = 'PENDIENTE';
                    $rowNota->save();
                    $mSession->mensajes[] = 'La nota de venta ha quedado a la espera de aprobación.';
                    $mSession->claseMensaje = 'advertencia';

                }
            }
            $this->_forward('view','nota-venta', null, array('id' => $id));
        }
    }

    public function finishAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('notas_ventas', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $v_nota = new Default_Model_VistaNotasVentas();
            $id = $v_nota->getAdapter()->quote($this->_getParam('id'));
            $v_row = $v_nota->fetchRow('id='.$id);

            $nota = new Default_Model_NotaVenta();
            $row = $nota->fetchRow('id='.$id);

            if($v_row->estado=='EN PROCESO') {

                if($this->_checkOrdenesRelacionadas((int)$this->_getParam('id'))){

                    $row->estado = 'TERMINADA';
                    $row->save();
                    $mSession->mensajes[] = 'La nota de venta fue terminada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } else {

                    $mSession->mensajes[] = 'Aún hay ítems pendientes: La orden no pudo ser terminada.';
                    $mSession->claseMensaje = 'error';

                }
                
            }
            $this->_forward('view','nota-venta', null, array('id' => $row->id));
        }
    }

    public function listByClienteAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('clientes', 'rut', App_Rut::cleanToDb($this->_getParam('id')))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $rut = App_Rut::cleanToDb($this->_getParam('id'));
            $currentPage = $this->_getParam('page', 1);

            $model = new Default_Model_VistaNotasVentas();
            $where = $model->getAdapter()->quoteInto('cliente_id=?', $rut);
            $notas = $model->fetchAll($where);

            $paginador = Zend_Paginator::factory($notas);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control_extra.phtml');

            $this->view->notas = $paginador;
            $this->renderScript('nota-venta/list-by-cliente.phtml');
        }
    }

    public function printInformeServiciosAction()
    {
        if($this->_getParam('id') AND
           $this->_helper->validateRecordExists('vista_notas_ventas','id', $this->_getParam('id'))){

            $this->_helper->layout->disableLayout(false);
            $this->_helper->viewRenderer->setNoRender(false);
            $this->_helper->layout->setLayout('print');

            $id = (int)$this->_getParam('id');
            $nota = new Default_Model_VistaNotasVentas();
            $whereNota = $nota->getAdapter()->quoteInto("id=?", $id);
            $rowNota = $nota->fetchRow($whereNota);

            if(false!==$rowNota AND $rowNota->estado=='TERMINADA') {

                $orden = new Default_Model_VistaOrdenesServicios();
                $whereOrden = $orden->getAdapter()->quoteInto("nota_id=?", $id);
                $rowsOrdenes = $orden->fetchAll($whereOrden);

                $this->view->title = "Informe servicios Nº $id";
                $this->view->nota = $rowNota;
                $this->view->condiciones_generales = Default_Model_CondicionGeneral::getTexto('INFORME_SERVICIOS');
                $this->view->ordenes = $rowsOrdenes;
            }
        }
    }

    private function _moveItems($id)
    {
        if($this->_helper->validateRecordExists('notas_ventas', 'id', $id)) {
            
            $nota = new Default_Model_NotaVenta();
            $where = $nota->getAdapter()->quoteInto("id=?", $id);
            $rowNota = $nota->fetchRow($where);
            
            if($rowNota->estado=="BORRADOR") {

                $item = new Default_Model_ItemNotaVenta();
                $whereItems = $item->getAdapter()->quoteInto("nota_id=?", $id);
                $items = $item->fetchAll($whereItems);
                
                foreach($items as $rowItem){
                    
                    if($rowItem->table=='servicios'){
                        
                        $ordenServicio              = new Default_Model_OrdenServicio();
                        $rowOrden                   = $ordenServicio->createRow();
                        $rowOrden->creador          = $this->usuario->rut;
                        $rowOrden->nota_id          = $id;
                        $rowOrden->vehiculo         = $rowItem->vehiculo;
                        $rowOrden->servicio         = $rowItem->codigo;
                        $rowOrden->cantidad         = $rowItem->cantidad;
                        $rowOrden->unidad_medida    = $rowItem->unidad_medida;
                        $rowOrden->nombre           = $rowItem->nombre;
                        $rowOrden->descripcion      = $rowItem->descripcion;
                        $rowOrden->estado           = 'PENDIENTE';
                        $rowOrden->save();

                    } elseif($rowItem->table=='articulos'){
                        /*
                        $solicitudArticulo = new Default_Model_SolicitudArticulo();
                        $rowSolicitud = $solicitudArticulo->createRow();
                        $rowSolicitud->creador = $this->usuario->rut;
                        $rowSolicitud->documento = 'ORDEN SERVICIO';
                        $rowSolicitud->documento_id = $id;
                        $rowSolicitud->articulo = $rowItem->codigo;
                        $rowSolicitud->cantidad = $rowItem->cantidad;
                        $rowSolicitud->estado = 'PENDIENTE';
                        $rowSolicitud->save();
                        */
                    }
                }

                return true;
                
            } else {
                return false;
            }
        }
    }

    private function _checkOrdenesRelacionadas($nota_id)
    {
        $orden = new Default_Model_OrdenServicio();
        $where = $orden->getAdapter()->quoteInto("nota_id=? AND estado!='TERMINADA'", $nota_id);
        $ordenes = $orden->fetchAll($where);

        if(count($ordenes) > 0 ) {
            return false;
        }
        return true;
    }
}