<?php
class OrdenServicioController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $propietario = new Default_Model_Propietario();
        $this->view->propietario = $propietario->fetchRow();
        $this->path = '/orden-servicio';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $orden = new Default_Model_VistaOrdenesServicios();
            $where = "estado!='BORRADOR'";
            $order_by = "id DESC";
            $ordenes = $orden->fetchAll($where, $order_by);

            $paginador = Zend_Paginator::factory($ordenes);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->ordenes = $paginador;
            $this->view->title = 'Órdenes de servicio';
            $this->renderScript('orden-servicio/index.phtml');
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('ordenes_servicios', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            
            $id = (int)$this->_getParam('id');
            $orden = new Default_Model_VistaOrdenesServicios();
            $where = $orden->getAdapter()->quoteInto("id=?", $id);
            $row = $orden->fetchRow($where);

            $orderUltimo = 'id DESC';

            $recepcion = new Default_Model_VistaRecepcionesVehiculos();
            $whereRecepcion = $recepcion->getAdapter()->quoteInto("vehiculo=? AND estado='TERMINADA'", $row->vehiculo);
            $rowRecepcion = $recepcion->fetchRow($whereRecepcion, $orderUltimo);

            $servicio = new Default_Model_VistaOrdenesServicios();
            $whereServicio = $servicio->getAdapter()->quoteInto("vehiculo=? AND estado='TERMINADA'", $row->vehiculo);
            $rowServicio = $servicio->fetchRow($whereServicio, $orderUltimo);

            $anotacion = new Default_Model_VistaAnotacionesVehiculos();
            $whereAnotacion = $anotacion->getAdapter()->quoteInto("vehiculo=?", $row->vehiculo);
            $rowAnotacion = $anotacion->fetchRow($whereAnotacion, $orderUltimo);

            $informe = new Default_Model_OrdenServicioInforme();
            $whereInforme = $informe->getAdapter()->quoteInto("orden_id=?", $id);
            $rowInforme = $informe->fetchRow($whereInforme, $orderUltimo);

            $recomendacion = new Default_Model_OrdenServicioRecomendacion();
            $whereRecomendacion = $recomendacion->getAdapter()->quoteInto("orden_id=?", $id);
            $rowsRecomendaciones = $recomendacion->fetchAll($whereRecomendacion);

            $this->view->title = "Orden de servicio Nº $id";
            $this->view->orden = $row;
            $this->view->informe = $rowInforme;
            $this->view->recomendaciones = $rowsRecomendaciones;
            $this->view->ultimaRecepcion = $rowRecepcion;
            $this->view->ultimoServicio = $rowServicio;
            $this->view->ultimaAnotacion = $rowAnotacion;

            if($row->estado=='BORRADOR') {
                $this->renderScript('orden-servicio/view-borrador.phtml');
            } elseif($row->estado=='PENDIENTE') {

                $form = new Default_Form_AsignacionOrdenServicio(null, $this->path);
                $form->id->setValue($id);
                $this->view->form = $form;
                $this->view->title .= " : pendiente";
                $this->renderScript('orden-servicio/view-pendiente.phtml');
                
            } elseif($row->estado=='EN PROCESO') {
                $this->view->title .= " : en proceso";
                $this->renderScript('orden-servicio/view-en-proceso.phtml');
            } else {
                $this->renderScript('orden-servicio/view.phtml');
            }
        }
    }

    public function detalleAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('ordenes_servicios', 'id', $this->_getParam('id'))){
           
            $id = (int)$this->_getParam('id');
            $orden = new Default_Model_VistaOrdenesServicios();
            $where = $orden->getAdapter()->quoteInto("id=?", $id);
            $row = $orden->fetchRow($where);
            
            $informe = new Default_Model_OrdenServicioInforme();
            $whereInforme = $informe->getAdapter()->quoteInto("orden_id=?", $id);
            $orderInforme = "id DESC";
            $rowInforme = $informe->fetchRow($whereInforme, $orderInforme);

            $recomendacion = new Default_Model_OrdenServicioRecomendacion();
            $whereRecomendacion = $recomendacion->getAdapter()->quoteInto("orden_id=?", $id);
            $rowsRecomendaciones = $recomendacion->fetchAll($whereRecomendacion);
            
            $this->view->title = "Orden de servicio Nº $id";
            $this->view->orden = $row;
            $this->view->informe = $rowInforme;
            $this->view->recomendaciones = $rowsRecomendaciones;
            $this->renderScript('orden-servicio/detalle.phtml');
        }
    }

    public function viewSmallAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('ordenes_servicios', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');
            $orden = new Default_Model_VistaOrdenesServicios();
            $where = $orden->getAdapter()->quoteInto("id=?", $id);
            $row = $orden->fetchRow($where);

            $informe = new Default_Model_OrdenServicioInforme();
            $whereInforme = $informe->getAdapter()->quoteInto("orden_id=?", $id);
            $orderInforme = "id DESC";
            $rowInforme = $informe->fetchRow($whereInforme, $orderInforme);

            $recomendacion = new Default_Model_OrdenServicioRecomendacion();
            $whereRecomendacion = $recomendacion->getAdapter()->quoteInto("orden_id=?", $id);
            $rowsRecomendaciones = $recomendacion->fetchAll($whereRecomendacion);

            $this->view->informe = $rowInforme;
            $this->view->recomendaciones = $rowsRecomendaciones;
            $this->view->type_user = $this->_getParam('type_user');
            $this->view->title = "Orden de servicio Nº $id";
            $this->view->orden = $row;

            $this->renderScript('orden-servicio/view-small.phtml');
        }
    }

    public function startAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_AsignacionOrdenServicio(null, $this->path);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $orden = new Default_Model_OrdenServicio();
                    $where = $orden->getAdapter()->quoteInto("id=?", $form->getValue('id'));
                    $row = $orden->fetchRow($where);
                    $row->creador = $this->usuario->rut;
                    $row->estado = 'EN PROCESO';
                    $row->asignada_a = $form->getValue('asignada_a');
                    $row->fecha_inicio = date("Y-m-d H:i:s");
                    $row->save();
                    $id = $row->id;
                    $mSession->mensajes[] = 'La orden de servicio fue emitida de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view','orden-servicio', null, array('id' => $id));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la solicitud de servicio.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','orden-servicio');
                    
                }
            } else {

                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('orden-servicio/view.phtml');
            }
        }
    }

    public function terminarAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_TerminoOrdenServicio(null, $this->path);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                try {
                    
                    $orden = new Default_Model_OrdenServicio();
                    $where = $orden->getAdapter()->quoteInto("id=?", $form->getValue('id'));
                    $row = $orden->fetchRow($where);
                    $row->creador = $this->usuario->rut;
                    $row->estado = 'TERMINADA';
                    $row->horas_reales = $form->getValue('horas_reales');
                    $row->fecha_termino = date("Y-m-d H:i:s");
                    $row->prueba_ruta = $form->getValue('prueba_ruta');
                    $row->control_calidad = $form->getValue('control_calidad');
                    $row->save();
                    $mSession->mensajes[] = 'La orden de servicio ha concluído su proceso de forma satisfatoria.';
                    $mSession->claseMensaje = 'confirmacion';
                    
                    $this->_forward('view','orden-servicio', null, array('id' => $form->getValue('id')));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la solicitud de servicio.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','orden-servicio');

                }
            } else {

                $this->view->title = "Terminar orden de servicio";
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('orden-servicio/form.phtml');
            }
        }
    }

    public function getFormFinishAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('ordenes_servicios', 'id', $this->_getParam('id'))){

            $id = (int)$this->_getParam('id');
            $model = new Default_Model_OrdenServicio();
            $where = $model->getAdapter()->quoteInto("id=?", $id);
            $orden = $model->fetchRow($where)->toArray();
           
            $request = $this->getRequest();
            $form = new Default_Form_TerminoOrdenServicio(null, $this->path, $this->path . '/view/' . $id);
            $form->populate($orden);
            $form->id->setValue($id);
            $form->id->setAttrib('disabled', 'disabled');
            $this->view->title = "Terminar orden de servicio";
            $this->view->form = $form;
            $this->renderScript('orden-servicio/form-finish.phtml');
        }
    }

    public function listByVehiculoAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('vehiculos', 'patente', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $patente = strtoupper($this->_getParam('id'));
            $currentPage = $this->_getParam('page', 1);

            $model = new Default_Model_VistaOrdenesServicios();
            $where = $model->getAdapter()->quoteInto('vehiculo=?', $patente);
            $ordenes = $model->fetchAll($where);

            $paginador = Zend_Paginator::factory($ordenes);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control_extra.phtml');

            $this->view->ordenes = $paginador;
            $this->renderScript('orden-servicio/list-by-vehiculo.phtml');
        }
    }

    public function listByNotaVentaAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('notas_ventas', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = strtoupper($this->_getParam('id'));
            $currentPage = $this->_getParam('page', 1);

            $model = new Default_Model_VistaOrdenesServicios();
            $where = $model->getAdapter()->quoteInto('nota_id=?', $id);
            $ordenes = $model->fetchAll($where);

            $paginador = Zend_Paginator::factory($ordenes);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control_extra.phtml');

            $this->view->ordenes = $paginador;
            $this->renderScript('orden-servicio/list-by-nota-venta.phtml');
        }
    }

    public function printAction()
    {
        if($this->_getParam('id') AND
           $this->_helper->validateRecordExists('ordenes_servicios','id', $this->_getParam('id'))){

            $this->_helper->layout->disableLayout(false);
            $this->_helper->viewRenderer->setNoRender(false);
            $this->_helper->layout->setLayout('print');

            $id = (int)$this->_getParam('id');
            $orden = new Default_Model_VistaOrdenesServicios();
            $where = $orden->getAdapter()->quoteInto("id=?", $id);
            $row = $orden->fetchRow($where)->toArray();

            if($row['estado']!='BORRADOR') {
                $this->view->title = "Orden de servicio Nº $id";
                $this->view->orden = $row;
            }
        }
    }

    /*
    public function guardarBorradorAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('ordenes_servicios', 'id', $this->_getParam('id'))){

            try {

                $id = (int)$this->_getParam('id');
                $orden = new Default_Model_OrdenServicio();
                $where = $orden->getAdapter()->quoteInto("id=?", $id);

                $filtroTags = new Zend_Filter_StripTags();
                $recomendaciones = $filtroTags->filter($this->_getParam('recomendaciones'));
                $observaciones = $filtroTags->filter($this->_getParam('observaciones'));

                $row = $orden->fetchRow($where);
                $row->observaciones = $observaciones;
                $row->recomendaciones = $recomendaciones;
                $row->save();

                echo '<div id="aviso-form" class="confirmacion desaparecer"><ul><li>El borrador se guardó satisfactoriamente</li></ul></div>';

            } catch (Exception $e) {

                echo '<div id="aviso-form" class="error desaparecer"><ul><li>Ocurrió un error al intentar guardar el borrador</li></ul></div>';

            }
        }
    }
    
    public function getFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $request = $this->getRequest();
            $form = new Default_Form_OrdenServicio(null, $this->path);

            if($this->_request->getParam('id')) {

                $id = (int)$this->_request->getParam('id');
                $orden = new Default_Model_OrdenServicio();
                $where = $orden->getAdapter()->quoteInto("id=?", $id);
                $row = $orden->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/orden-servicio/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar orden de servicio Nº $id";

            } else {

                $this->view->title = "Crear orden de servicio";
                if($this->_request->getParam('patente')) {
                    $patente = strtoupper($this->_request->getParam('patente'));
                    $form->vehiculo->setValue($patente);
                }

            }
            $this->view->form = $form;
            $this->renderScript('orden-servicio/form.phtml');
        }
    }    
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_OrdenServicio(null, $this->path);
        $this->view->title = 'Crear orden de servicio';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $orden = new Default_Model_OrdenServicio();
                    $row = $orden->createRow();
                    $row->creador = $this->usuario->rut;
                    $row->vehiculo = strtoupper($form->getValue('vehiculo'));
                    //$row->descripcion
                    $row->save();
                    $id = $row->id;
                    $mSession->mensajes[] = 'La orden de servicio fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view','orden-servicio', null, array('id' => $id));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la solicitud de servicio.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','orden-servicio');
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('orden-servicio/form.phtml');
            }
        }
    }
    */
}