<?php
class OrdenServicioRecomendacionController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
    }
    
    public function init()
    {
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/orden-servicio-recomendacion';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function getFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            if($this->_getParam('id') &&
               $this->_helper->validateRecordExists('ordenes_servicios_recomendaciones','id', $this->_getParam('id'))) {

                $request = $this->getRequest();
                $form = new Default_Form_OrdenServicioRecomendacion();

                if($this->_getParam('type_user')==1){
                    $form->type_user->setValue(1);
                }

                $recomendacion = new Default_Model_OrdenServicioRecomendacion();
                $where = $recomendacion->getAdapter()->quoteInto("id=?", (int)$this->_getParam('id'));
                $row = $recomendacion->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/orden-servicio-recomendacion/edit');
                $form->submit->setLabel('Guardar cambios');
                echo $form;

            } elseif($this->_getParam('from_id') &&
                     $this->_helper->validateRecordExists('ordenes_servicios','id', (int)$this->_getParam('from_id'))) {

                $request = $this->getRequest();
                $form = new Default_Form_OrdenServicioRecomendacion();
                $form->orden_id->setValue((int)$this->_getParam('from_id'));

                if($this->_getParam('type_user')==1){
                    $form->type_user->setValue(1);
                }
                
                echo $form;
            }
        }
    }

    public function newAction()
    {
        $request = $this->getRequest();
        $form = new Default_Form_OrdenServicioRecomendacion();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $recomendacion = new Default_Model_OrdenServicioRecomendacion();
                    $row = $recomendacion->createRow();
                    $row->orden_id = $form->getValue('orden_id');
                    $row->creador = $this->usuario->rut;
                    $row->plazo = $form->getValue('plazo');
                    $row->recomendacion = $form->getValue('recomendacion');
                    $row->save();

                    $aviso = '<div id="aviso-form" class="confirmacion"><ul>';
                    $aviso .= '<li>La recomendación fue agregada de forma exitosa.</li>';
                    $aviso .= '</ul></div>';

                    if($form->getValue('type_user')=='1'){
                        $this->_forward('view-small', 'orden-servicio', null,
                            array(
                                'id' => $row->orden_id,
                                'type_user' => 1
                            )
                        );
                    } else {
                        echo $aviso;
                    }

                } catch (Exception $e) {

                    $aviso = '<div id="aviso-form" class="error">';
                    $aviso .= '<ul>';
                    $aviso .= '<li>'.  $e->getMessage() .'</li>';
                    $aviso .= '<li>Ocurrió un error al intentar guardar la recomendación</li></ul>';
                    $aviso .= '</div>';

                    echo $aviso;
                }
            } else {
                $form->populate($request->getPost());
                echo $form;
            }
        }
    }

    public function editAction()
    {
        $request = $this->getRequest();
        $form = new Default_Form_OrdenServicioRecomendacion();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $id = $form->getValue('id');

                    $recomendacion = new Default_Model_OrdenServicioRecomendacion();
                    $where = $recomendacion->getAdapter()->quoteInto("id=?", $id);
                    $row = $recomendacion->fetchRow($where);
                    $row->creador = $this->usuario->rut;
                    $row->plazo = $form->getValue('plazo');
                    $row->recomendacion = $form->getValue('recomendacion');
                    $row->save();

                    $aviso = '<div id="aviso-form" class="confirmacion"><ul>';
                    $aviso .= '<li>La recomendación fue editada de forma exitosa.</li>';
                    $aviso .= '</ul></div>';

                    if($form->getValue('type_user')=='1'){
                        $this->_forward('view-small', 'orden-servicio', null,
                            array(
                                'id' => $row->orden_id,
                                'type_user' => 1
                            )
                        );
                    } else {
                        echo $aviso;
                    }

                } catch (Exception $e) {

                    $aviso = '<div id="aviso-form" class="error">';
                    $aviso .= '<ul>';
                    $aviso .= '<li>'.  $e->getMessage() .'</li>';
                    $aviso .= '<li>Ocurrió un error al intentar guardar los cambios</li></ul>';
                    $aviso .= '</div>';

                    echo $aviso;
                }
            } else {
                $form->populate($request->getPost());
                echo $form;
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $orden_id = $this->_getParam('id');

            if($this->_helper->validateRecordExists('ordenes_servicios', 'id', $orden_id)){

                $data = $this->_getParam('data');
                $items = explode(",", $data);

                $recomendacion = new Default_Model_OrdenServicioRecomendacion();

                foreach($items as $id){

                    if($this->_helper->validateRecordExists('ordenes_servicios_recomendaciones', 'id', $id)){
                        $where = $recomendacion->getAdapter()->quoteInto("id=?", $id);
                        $recomendacion->delete($where);
                    }
                }

                $aviso = '<div id="aviso-form" class="confirmacion"><ul>';
                $aviso .= '<li>Los ítems fueron eliminados de forma exitosa.</li>';
                $aviso .= '</ul></div>';

                if($this->_getParam('type_user')=='1'){
                    $this->_forward('view-small', 'orden-servicio', null,
                        array(
                            'id' => $orden_id,
                            'type_user' => 1
                        )
                    );
                } else {
                    echo $aviso;
                }
            }
        }
    }
}