<?php

class PagoRecibidoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
    }
    
    public function init()
    {   
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/pago-recibido';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');
            $mSession->history = '/' . $this->getRequest()->getControllerName() .
                             '/' . $this->getRequest()->getActionName();

            if($mSession->mensajes!='') {
                
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = (int)$this->_getParam('page', 1);
            
            $pago = new Default_Model_VistaPagosRecibidos();
            $pagos = $pago->fetchAll()->toArray();

            $paginador = Zend_Paginator::factory($pagos);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
            
            $this->view->pagos = $paginador;
            
            $this->view->title = "Pagos recibidos";
            $this->renderScript('pago-recibido/index.phtml');
        } 
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_PagoRecibido(null, $this->path);

            if($this->_getParam('id') AND
               $this->_helper->validateRecordExists('pagos_recibidos', 'id', $this->_getParam('id'))) {

                $pago = new Default_Model_PagoRecibido();
                $id = (int)$this->_getParam('id');
                $where= $pago->getAdapter()->quoteInto("id=?", $id);
                $row = $pago->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/pago-recibido/edit');
                $rut = App_Rut::format($form->cliente->getValue());
                $form->cliente->setValue($rut);
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar el pago recibido";
            } else {

                $this->view->title = "Ingresar pago recibido";
                if($this->_getParam('rut')) {
                    $rut = App_Rut::format($this->_getParam('rut'));
                    $form->cliente->setValue($rut);
                }
            }
            $this->view->form = $form;
            $this->renderScript('pago-recibido/form.phtml');
        }
    }

    public function getFormDocumentoAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_PagoRecibido(null, $this->path);

            if($this->_getParam('id') AND
               $this->_helper->validateRecordExists('pagos_recibidos', 'id', $this->_getParam('id'))) {

                $pago = new Default_Model_PagoRecibido();
                $id = (int)$this->_getParam('id');
                $where= $pago->getAdapter()->quoteInto("id=?", $id);
                $row = $pago->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/pago-recibido/edit');
                $rut = App_Rut::format($form->cliente->getValue());
                $form->cliente->setValue($rut);
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar el pago recibido";
            } else {

                $this->view->title = "Ingresar pago recibido";
                if($this->_getParam('rut')) {
                    $rut = App_Rut::format($this->_getParam('rut'));
                    $form->cliente->setValue($rut);
                }
            }
            $this->view->form = $form;
            $this->renderScript('pago-recibido/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_PagoRecibido(null, $this->path);
        $this->view->title = 'Ingresar pago emitido';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $pago = new Default_Model_PagoRecibido();
                    $row = $pago->createRow();
                    $row->creador  = $this->usuario->rut;
                    $row->forma_id = $form->getValue('forma_id');
                    $row->cliente  = App_Rut::cleanToDb($form->getValue('cliente'));
                    $row->monto    = $form->getValue('monto');
                    if($form->getValue('observaciones')!='') {
                        $row->observaciones = $form->getValue('observaciones');
                    } else {
                        $row->observaciones = NULL;
                    }
                    $row->save();
                    $id = $row->id;
                    $mSession->mensajes[] = 'El pago fue ingresado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view','pago-recibido', null, array('id'=>$id));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar ingresar el pago recibido.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','pago-recibido');
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('pago-recibido/form.phtml');
            }
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $pago = new Default_Model_PagoRecibido();

        $request = $this->getRequest();
        $form = new Default_Form_PagoRecibido(null, $this->path);
        $form->id->setRequired(true);

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {

                    $id = (int)$form->getValue('id');
                    $where = $pago->getAdapter()->quoteInto("id=?", $id);
                    $row = $pago->fetchRow($where);
                    $row->creador = $this->usuario->rut;
                    $row->forma_id = $form->getValue('forma_id');
                    $row->cliente = App_Rut::cleanToDb($form->getValue('cliente'));
                    $row->monto = $form->getValue('monto');
                    if($form->getValue('observaciones')!='') {
                        $row->observaciones = $form->getValue('observaciones');
                    } else {
                        $row->observaciones = NULL;
                    }
                    $row->save();
                    
                    $mSession->mensajes[] = 'El pago recibido fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view', 'pago-recibido', null, array('id'=> $id));


                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el pago recibido.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                    $this->_forward('index','pago-recibido');
                }

            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/pago-recibido/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar pago recibido";
                $this->renderScript('pago-recibido/form.phtml');
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('pagos_recibidos', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            try {

                $model = new Default_Model_PagoRecibido();
                $where = $model->getAdapter()->quoteInto("id = ?" , (int)$this->_getParam('id'));
                $model->delete($where);
                $mSession->mensajes[] = 'El pago recibido fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_forward('index','pago-recibido');

            } catch (Exception $e) {

                $mSession->tipo_error = 1;
                $mSession->errores[] = $e->getMessage();
                $this->_forward('error-delete-registro','error');
            }
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('pagos_recibidos','id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');

            $pago = new Default_Model_VistaPagosRecibidos();
            $where = $pago->getAdapter()->quoteInto("id=?", $id);
            $row = $pago->fetchRow($where)->toArray();

            $this->view->title = "Pago recibido";

            if($row['detallar']!='NO'){
                if($row['detallar']=='DOCUMENTO') {

                    $this->view->documentoBancario = Default_Model_VistaPagosRecibidos::getDocumentoBancario($id);

                } elseif($row['detallar']=='CODIGO') {

                    $this->view->codigoTransaccion = Default_Model_VistaPagosRecibidos::getCodigoTransaccion($id);

                }
            }

            $this->view->pago = $row;


            if($row['estado']=='BORRADOR') {
                $this->renderScript('pago-recibido/view-borrador.phtml');
            } elseif($row['estado']=='TERMINADO') {
                $this->renderScript('pago-recibido/view-terminado.phtml');
            }
        }
    }

    public function finishAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND $this->_helper->validateRecordExists('pagos_recibidos', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            
            $pago = new Default_Model_PagoRecibido();
            $where = $pago->getAdapter()->quoteInto("id=?", (int)$this->_getParam('id'));
            $row = $pago->fetchRow($where);

            if($row->estado=='BORRADOR') {

                $row->estado = 'TERMINADO';
                $row->save();
                
                $mSession->mensajes[] = 'La cotización fue emitida de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';

            }
            $this->_forward('view','pago-recibido', null, array('id' => $row->id));
        }
    }
}