<?php
class ProductoController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/producto';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $t = $this->view->t = $this->_getParam('t');

            $currentPage = $this->_getParam('page', 1);

            $producto = new Default_Model_VistaProductos();
            
            if($t!=='a') {
                $where = "estado!='BORRADOR'";
                $productos = $producto->fetchAll($where);
            } else {
                $productos = $producto->fetchAll();
            }

            $paginador = Zend_Paginator::factory($productos);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->title = "Productos";
            $this->view->productos = $paginador;
            $this->renderScript('producto/index.phtml');
        }
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_Producto(null, $this->path);

            if($this->_request->getParam('codigo')) {

                $producto = new Default_Model_Producto();
                $codigo = $this->_request->getParam('codigo');
                $where = $producto->getAdapter()->quoteInto("codigo=?", $codigo);
                $row = $producto->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/producto/edit');
                $form->codigo->setAttrib('disabled','disabled');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar producto código : $codigo";

            } else {

                $this->view->title = "Crear producto";

            }
            $this->view->form = $form;
            $this->renderScript('producto/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Producto(null, $this->path);
        $this->view->title = "Crear producto";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $producto = new Default_Model_Producto();
                    $row = $producto->createRow();
                    $row->codigo = $form->getValue('codigo');
                    $row->creador = $this->usuario->rut;
                    $row->categoria_id = $form->getValue('categoria_id');
                    $row->nombre = $form->getValue('nombre');

                    if($form->getValue('unidades')==''){
                        $row->unidades = 0;
                    } else {
                        $row->unidades = $form->getValue('unidades');
                    }

                    if($form->getValue('fecha_termino')==''){
                        $row->fecha_termino = null;
                    } else {
                        $row->fecha_termino = $form->getValue('fecha_termino');
                    }
                    if($form->getValue('descripcion')==''){
                        $row->descripcion = NULL;
                    } else {
                        $row->descripcion = $form->getValue('descripcion');
                    }
                    $row->save();

                    $precio = new Default_Model_PrecioProducto();
                    $row_precio = $precio->createRow();
                    $row_precio->creador = $this->usuario->rut;
                    $row_precio->producto = $row->codigo;
                    $row_precio->precio_unitario_neto = 0;
                    $row_precio->save();

                    $mSession->mensajes[] = 'El producto fue creado de forma exitosa y ya se encuentra disponible para la venta.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view','producto', null, array('codigo' => $row->codigo));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el servicio.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                    $this->_forward('index','producto');
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('producto/form.phtml');
            }
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Producto();
        $form->codigo->setAttrib('disabled','disabled');

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    $producto = new Default_Model_Producto();
                    $codigo = $form->getValue('codigo');
                    $where = $producto->getAdapter()->quoteInto("codigo=?", $codigo);
                    $row = $producto->fetchRow($where);
                    $row->creador = $this->usuario->rut;
                    $row->categoria_id = $form->getValue('categoria_id');
                    $row->nombre = $form->getValue('nombre');

                    if($form->getValue('unidades')==''){
                        $row->unidades = 0;
                    } else {
                        $row->unidades = $form->getValue('unidades');
                    }

                    if($form->getValue('fecha_termino')==''){
                        $row->fecha_termino = null;
                    } else {
                        $row->fecha_termino = $form->getValue('fecha_termino');
                    }

                    if($form->getValue('descripcion')==''){
                        $row->descripcion = NULL;
                    } else {
                        $row->descripcion = $form->getValue('descripcion');
                    }
                    
                    $row->save();

                    $mSession->mensajes[] = 'El producto fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view', 'producto', null, array('codigo'=> $codigo));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el producto.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','producto');
                }
            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/producto/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar producto";
                $this->renderScript('producto/form.phtml');
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            if($this->_getParam('codigo')) {
                $codigo = $this->_getParam('codigo');
                $producto = new Default_Model_Producto();
                $where = $producto->getAdapter()->quoteInto('codigo = ?' , $codigo);
                $producto->delete($where);
                $mSession->mensajes[] = 'El producto fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';

            }
            $this->_forward('index','producto');
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $codigo = $this->_getParam('codigo');

            $producto = new Default_Model_VistaProductos();
            $where = $producto->getAdapter()->quoteInto("codigo=?", $codigo);
            $row = $producto->fetchRow($where);
            
            $articulo = new Default_Model_VistaArticulosProductos();
            $where_articulos = $articulo->getAdapter()->quoteInto("producto=?", $codigo);
            
            $servicio = new Default_Model_VistaServiciosProductos();
            $where_servicios = $servicio->getAdapter()->quoteInto("producto=?", $codigo);

            $precio = new Default_Model_PrecioProducto();
            $where_precio = $precio->getAdapter()->quoteInto("producto=?", $codigo);
            $order_precio = 'id DESC';
            $row_precio = $precio->fetchRow($where_precio, $order_precio);

            $costo = $row['costo_total_servicios'] + $row['costo_total_articulos'];

            if($row_precio->precio_unitario_neto!=0){
                $this->view->margen = $this->_helper->_calcularMargen($costo, $row_precio->precio_unitario_neto);
            } else {
                $this->view->margen = 0;
            }

            if(false==$row) {
                $this->_forward('index','producto', null, array('t' => $this->_getParam('t')));
            } else {

                $this->view->t = $this->_getParam('t');
                $this->view->margen_sugerido = Default_Model_PreferenciaMargenDefault::getMargenByValue('PRODUCTO', $row_precio->precio_unitario_neto);
                $this->view->precio_sugerido = $this->_helper->calcularPrecioSugerido($costo, $this->view->margen_sugerido);

                $this->view->title = "Producto código: $codigo";
                $this->view->producto = $row;
                $this->view->precio = $row_precio;
                $this->view->articulos = $articulo->fetchAll($where_articulos);
                $this->view->servicios = $servicio->fetchAll($where_servicios);

                if($row->estado=='BORRADOR') {

                    $this->renderScript('producto/view-draft.phtml');

                } else {

                    switch ($this->_getParam('t')){
                        case "a" :
                            $this->renderScript('producto/view-admin.phtml');
                            break;
                        default :
                            $this->renderScript('producto/view.phtml');
                            break;
                    }
                }
            }
        }
    }

    public function detalleAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            if($this->_getParam('codigo') AND
                $this->_helper->validateRecordExists('productos','codigo', $this->_getParam('codigo'))){

                $codigo = $this->_getParam('codigo');

                $producto = new Default_Model_VistaProductos();
                $where = $producto->getAdapter()->quoteInto("codigo=?", $codigo);
                $row = $producto->fetchRow($where);

                $total_costo = $row->costo_total_articulos + $row->costo_total_servicios;

                $articulo = new Default_Model_VistaArticulosProductos();
                $where_articulos = $articulo->getAdapter()->quoteInto("producto=?", $codigo);

                $servicio = new Default_Model_VistaServiciosProductos();
                $where_servicios = $servicio->getAdapter()->quoteInto("producto=?", $codigo);

                $precio = new Default_Model_PrecioProducto();
                $where_precio = $precio->getAdapter()->quoteInto("producto=?", $codigo);
                $order_precio = 'id DESC';
                $row_precio = $precio->fetchRow($where_precio, $order_precio);

                $costo = $row['costo_total_servicios'] + $row['costo_total_articulos'];

                if($row_precio->precio_unitario_neto!=0){
                    $this->view->margen = $this->_helper->_calcularMargen($costo, $row_precio->precio_unitario_neto);
                } else {
                    $this->view->margen = 0;
                }

                $this->view->t = $this->_getParam('t');
                $this->view->margen_sugerido = Default_Model_PreferenciaMargenDefault::getMargenByValue('PRODUCTO', $row_precio->precio_unitario_neto);
                $this->view->precio_sugerido = $this->_helper->calcularPrecioSugerido($costo, $this->view->margen_sugerido);

                $this->view->title = "Producto código: $codigo";
                $this->view->producto = $row;
                $this->view->precio = $row_precio;
                $this->view->articulos = $articulo->fetchAll($where_articulos);
                $this->view->servicios = $servicio->fetchAll($where_servicios);

               $this->renderScript('producto/detalle.phtml');
            }
        }
    }

    public function finishAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND $this->_getParam('codigo')){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $v_producto = new Default_Model_VistaProductos();
            $where_v_producto = $v_producto->getAdapter()->quoteInto("codigo=?", $this->_getParam('codigo'));
            $row_v_producto = $v_producto->fetchRow($where_producto)->toArray();
            
            $precio = new Default_Model_PrecioProducto();
            $where_precio = $precio->getAdapter()->quoteInto("producto=?", $this->_getParam('codigo'));
            $order_precio = 'id DESC';
            $row_precio = $precio->fetchRow($where_precio, $order_precio);

            $num_items = $row_v_producto['num_articulos'] + $row_v_producto['num_servicios'];

            if($num_items == 0){

                $mSession->mensajes[] = 'No ha añadido ítems al producto.';
                $mSession->claseMensaje = 'error';

            } elseif($row_precio AND $row_precio->precio_unitario_neto > 0) {

                $producto = new Default_Model_Producto();
                $where = $producto->getAdapter()->quoteInto("codigo=?", $this->_getParam('codigo'));
                $row = $producto->fetchRow($where);
                $row->estado = 'DISPONIBLE';
                $row->save();
                
                $mSession->mensajes[] = 'El producto fue creado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';

            } else {

                $mSession->mensajes[] = 'No ha definido el precio de venta del producto.';
                $mSession->claseMensaje = 'error';
                
            }

            $this->_forward('view','producto', null, array('codigo' => $this->_getParam('codigo'), 't' => 'a'));

            
            
        }
    }

    public function searchTooltipAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $producto = new Default_Model_VistaProductos();

            $filter_tags    = new Zend_Filter_StripTags();
            $criterio       = $filter_tags->filter(trim($this->_getParam('criterio')));
            $valor          = $filter_tags->filter(trim($this->_getParam('valor')));
            $this->view->t  = $filter_tags->filter(trim($this->_getParam('t')));

            if($criterio!='' AND $valor!='') {

                if($criterio=='codigo') {

                    $valor = strtoupper($valor);
                    $where = "$criterio='$valor'";

                } else {

                    $where = "$criterio LIKE '%$valor%'";
                }

                $where = $where . " AND estado='TERMINADO'";
                
                $this->view->productos = $producto->fetchAll($where)->toArray();
            }

            $this->renderScript('producto/search.phtml');
        }
    }

    public function viewSmallAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $this->view->t  = $this->_getParam('t');
            $codigo = $this->_getParam('codigo');
            $producto = new Default_Model_VistaProductos();
            $where = $producto->getAdapter()->quoteInto("codigo=?", $codigo);
            $this->view->producto = $producto->fetchRow($where)->toArray();
            $this->renderScript('producto/view-tooltip.phtml');
        }
    }  

    public function ajustarPrecioVentaAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('codigo') AND
           $this->_helper->validateRecordExists('productos', 'codigo', $this->_getParam('codigo'))){

            $codigo = $this->_getParam('codigo');
            $valor = (int)$this->_getParam('valor');

            try {

                $precio = new Default_Model_PrecioProducto();
                $row = $precio->createRow();
                $row->creador = $this->usuario->rut;
                $row->producto = $codigo;
                $row->precio_unitario_neto = $valor;
                $row->save();

                $producto = new Default_Model_VistaProductos();
                $where_producto = $producto->getAdapter()->quoteInto("codigo=?", $codigo);
                $row_producto = $producto->fetchRow($where_producto)->toArray();

                $costo = $row_producto['costo_total_servicios'] + $row_producto['costo_total_articulos'];

                $margen = $this->_helper->calcularMargen($costo, $valor);

                $data = array();
                $data['mensaje'] = array("valor" => "Valor guardado", "style" => "color:green;");
                $data['valores'] = array(
                    array('id' => '#porcentaje_margen', 'html' => $this->view->formatDecimal($margen,2))
                );

                echo Zend_Json_Encoder::encode($data);

            } catch (Exception $e) {

                echo '<span style="color:red;">No se pudo guardar el nuevo valor</span>';
            }
        }
    }

    public function habilitarAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('codigo') AND
           $this->_helper->validateRecordExists('productos', 'codigo', $this->_getParam('codigo'))){

            $codigo = $this->_getParam('codigo');
            $t = $this->_getParam('t');

            try {

                $producto = new Default_Model_Producto();
                $where = $producto->getAdapter()->quoteInto("codigo=?", $codigo);
                $row = $producto->fetchRow($where);
                $row->estado = 'DISPONIBLE';
                $row->save();

                $mSession->mensajes[] = 'El producto ya se encuentra disponible para la venta.';
                $mSession->claseMensaje = 'confirmacion';

                $this->_forward('view', 'producto', null, array('codigo' => $codigo, 't' => $t));

            } catch (Exception $e) {

                $mSession->mensajes[] = 'Ocurrió un error al intentar habilitar el producto para la venta.';
                $mSession->mensajes[] = $e->getMessage();
                $mSession->claseMensaje = 'error';
                $this->_forward('index','producto');
            }
        }
    }

    public function deshabilitarAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('codigo') AND
           $this->_helper->validateRecordExists('productos', 'codigo', $this->_getParam('codigo'))){

            $codigo = $this->_getParam('codigo');
            $t = $this->_getParam('t');

            try {

                $producto = new Default_Model_Producto();
                $where = $producto->getAdapter()->quoteInto("codigo=?", $codigo);
                $row = $producto->fetchRow($where);
                $row->estado = 'NO DISPONIBLE';
                $row->save();

                $mSession->mensajes[] = 'El producto ya se encuentra disponible para la venta.';
                $mSession->claseMensaje = 'confirmacion';

                $this->_forward('view', 'producto', null, array('codigo' => $codigo, 't' => $t));

            } catch (Exception $e) {

                $mSession->mensajes[] = 'Ocurrió un error al intentar habilitar el producto para la venta.';
                $mSession->mensajes[] = $e->getMessage();
                $mSession->claseMensaje = 'error';
                $this->_forward('index','producto');
            }
        }
    }
}