<?php
class ProveedorController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/proveedor';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $proveedor = new Default_Model_VistaProveedores();
            $proveedores = $proveedor->fetchAll(null,'razon_social');
            
            $paginador = Zend_Paginator::factory($proveedores);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
            
            $this->view->proveedores = $paginador;
            $this->view->title = "Proveedores";
            $this->renderScript('proveedor/index.phtml');
            
        }
    }

    public function getFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $request = $this->getRequest();
            $form = new Default_Form_Proveedor(null, $this->path);

            if($this->_request->getParam('rut')) {

                $proveedor = new Default_Model_Proveedor();
                $where = $proveedor->getAdapter()->quoteInto("rut=?", $this->_request->getParam('rut'));
                $row = $proveedor->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/proveedor/edit');
                $rut = App_Rut::format($form->rut->getValue());
                $form->rut->setValue($rut);
                $this->view->title = "Editar proveedor";

            } else {

                $this->view->title = "Agregar proveedor";

            }
            $this->view->form = $form;
            $this->renderScript('proveedor/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Proveedor(null, $this->path);
        $this->view->title = "Agregar proveedor";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                try {
                    $proveedor = new Default_Model_Proveedor();
                    $row = $proveedor->createRow();
                    $row->razon_social = $form->getValue('razon_social');
                    $row->rut = App_Rut::cleanToDb($form->getValue('rut'));
                    $row->direccion = $form->getValue('direccion');
                    $row->comuna = $form->getValue('comuna');
                    $row->ciudad = $form->getValue('ciudad');
                    $row->telefono = $form->getValue('telefono');
                    $row->giro = $form->getValue('giro');
                    $row->web = $form->getValue('web');
                    $row->nombre_fantasia = $form->getValue('nombre_fantasia');
                    $row->transporte = $form->getValue('transporte');
                    $row->save();
                    $mSession->mensajes[] = 'El proveedor fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view','proveedor', null, array('id' => $row->rut));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el proveedor.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','proveedor');
                }
            } else {

                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('proveedor/form.phtml');
            }
        }
    }
    
    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            if($this->_getParam('id')) {
                
                $mSession = new Zend_Session_Namespace('expressauto');

                if($mSession->mensajes!='') {
                    $this->view->mensajes = $mSession->mensajes;
                    $this->view->claseMensaje = $mSession->claseMensaje;
                    $mSession->mensajes = '';
                    $mSession->claseMensaje = '';
                }

                $proveedor = new Default_Model_VistaProveedores();
                
                $where = $proveedor->getAdapter()->quoteInto("rut=?", $this->_getParam('id'));
                $this->view->proveedor = $proveedor->fetchRow($where);
                $this->view->title = 'Proveedor';

                if(false==$this->view->proveedor) {
                    $this->_forward('index','proveedor');
                } else {
                    $this->renderScript('proveedor/view.phtml');
                }
            }
        }   
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $proveedor = new Default_Model_Proveedor();

        $request = $this->getRequest();
        $form = new Default_Form_Proveedor();

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {
                    $rut = App_Rut::cleanToDb($form->getValue('rut'));
                    $where = $proveedor->getAdapter()->quoteInto("rut=?", $rut);
                    $row = $proveedor->fetchRow($where);
                    $row->razon_social = $form->getValue('razon_social');
                    $row->direccion = $form->getValue('direccion');
                    $row->comuna = $form->getValue('comuna');
                    $row->ciudad = $form->getValue('ciudad');
                    $row->telefono = $form->getValue('telefono');
                    $row->giro = $form->getValue('giro');
                    $row->web = $form->getValue('web');
                    $row->nombre_fantasia = $form->getValue('nombre_fantasia');
                    $row->transporte = $form->getValue('transporte');
                    $row->save();

                    $mSession->mensajes[] = 'El proveedor fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view', 'proveedor', null, array('id'=> $rut));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','proveedor');
                }

            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/proveedor/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar proveedor";
                $this->renderScript('proveedor/form.phtml');
            }
        } 
        
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            
            $rut = $this->_getParam('id');
            $proveedor = new Default_Model_Proveedor();
            $where = $proveedor->getAdapter()->quoteInto('rut = ?' , $rut);
            $proveedor->delete($where);
            $mSession->mensajes[] = 'El proveedor fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('index','proveedor');
            
        }
    }

    public function estadoCuentaAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('proveedores', 'rut', App_Rut::cleanToDb($this->_getParam('id')))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $this->view->title = "Estado de cuenta";
            $this->renderScript('proveedor/estado-cuenta.phtml');

        }
    }

    /*
    public function setSearchAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();

            $formularios = array(
                new Default_Form_ConsultaProveedor(null, $this->path),
            );

            $request = $this->getRequest();
            $this->view->formularios = $formularios;
            $this->view->title = "Proveedores : Buscar";
            $this->renderScript('proveedor/find.phtml');
        }
    }
    
    public function searchAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_ConsultaProveedor(null, $this->path);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el proveedor.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('new','proveedor');
                }
            } else {

                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('proveedor/form.phtml');
            }
        } else {
            $this->_forward('logout','index');
        }
    }
    
    public function getContactsToTooltipAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $proveedor = new Default_Model_Proveedor();
            $rut = App_Rut::cleanToDb($this->_getParam('rut'));
            $rut = $proveedor->getAdapter()->quote($rut);
            $this->view->proveedor = $proveedor->fetchRow('rut='.$rut);
            $contactos = new Default_Model_VistaContactos();
            $this->view->contactos = $contactos->fetchAll("ref_tabla='proveedores' AND ref_id=" . $rut);
            $this->renderScript('proveedor/view-contacts-tooltip.phtml');
        }
    }
    */

    public function searchTooltipAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $proveedor = new Default_Model_VistaProveedores();

            $filter_tags    = new Zend_Filter_StripTags();
            $criterio       = $filter_tags->filter(trim($this->_getParam('criterio')));
            $valor          = $filter_tags->filter(trim($this->_getParam('valor')));
            $this->view->t  = $filter_tags->filter(trim($this->_getParam('t')));

            if($criterio!='' AND $valor!='') {

                if($criterio=='rut') {

                    $valor = App_Rut::cleanToDb($valor);
                    $where = "$criterio='$valor'";

                } else {

                    $where = "$criterio LIKE '%$valor%'";
                }

                $this->view->proveedores = $proveedor->fetchAll($where)->toArray();
            }
            $this->renderScript('proveedor/search.phtml');
        }
    }

    public function viewSmallAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $this->view->t  = $this->_getParam('t');
            $rut = $this->_getParam('id');
            $proveedor = new Default_Model_VistaProveedores();
            $where = $proveedor->getAdapter()->quoteInto("rut=?", $rut);
            $this->view->proveedor = $proveedor->fetchRow($where);
            $this->renderScript('proveedor/view-tooltip.phtml');
        }
    }

    
}