<?php
class RendicionCajaChicaController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/rendicion-caja-chica';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function listByCicloAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('cc_ciclos_cajas', 'id', (int)$this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');
            $currentPage = $this->_getParam('page', 1);
            $model = new Default_Model_VistaCajasChicasRendiciones();
            $where = $model->getAdapter()->quoteInto('ciclo_id=?', $id);
            $rendiciones = $model->fetchAll($where);
            /*
            $paginador = Zend_Paginator::factory($rendiciones);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control_extra.phtml');
            */
            $this->view->rendiciones = $rendiciones;//$paginador;
            $this->view->u = $this->_getParam('type_user');
            $this->renderScript('rendicion-caja-chica/list-by-ciclo.phtml');
        }
    }

    public function getFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            if($this->_getParam('from_id') AND
               $this->_helper->validateRecordExists('vista_cc_egresos_activos', 'id', $this->_getParam('from_id'))){

                $egreso_id = (int)$this->_getParam('from_id');
                $saldoDisponible = $this->_getSaldoDisponible($egreso_id);

                $request = $this->getRequest();
                $form = new Default_Form_RendicionCajaChica($this->usuario->rut, null, $this->path);
                $form->egreso_id->setValue($egreso_id);
                $form->egreso_id->setAttrib('disabled', 'disabled');
                $form->maximo->setValue($saldoDisponible);
                $form->maximo->setAttrib('disabled', 'disabled');
                $this->view->title = "Registrar rendición de dinero";
                $this->view->form = $form;
                $this->renderScript('caja-chica/form.phtml');

            } else {
                $this->_forward('user', 'caja-chica');
            }
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_RendicionCajaChica($this->usuario->rut, null, $this->path);
        $this->view->title = 'Registrar rendición de dinero';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                
                $egreso_id = (int)$form->getValue('egreso_id');
                $saldoDisponible = $this->_getSaldoDisponible($egreso_id);
                $optionsMinMax = array('min' => '1', 'max' => $saldoDisponible);
                $validadorMinMax = new Zend_Validate_Between($optionsMinMax);

                if($validadorMinMax->isValid($form->getValue('cantidad'))) {

                    $rendicion = new Default_Model_CajaChicaRendicion();
                    $db = $rendicion->getAdapter();
                    $db->beginTransaction();
                    
                    try {
                        $row = $rendicion->createRow();
                        $row->egreso_id = $form->getValue('egreso_id');
                        $row->tipo_rendicion = $form->getValue('tipo_rendicion');
                        $row->tipo_documento = $form->getValue('tipo_documento');
                        $row->fecha = date("Y-m-d H:i:s");
                        $row->cantidad = (int)$form->getValue('cantidad');
                        $row->proveedor = App_Rut::cleanToDb($form->getValue('proveedor'));
                        $row->documento_numero = $form->getValue('documento_numero');
                        $row->save();

                        if($saldoDisponible == $form->getValue('cantidad')){

                            $modelEgreso = new Default_Model_CajaChicaEgreso();
                            $whereEgreso = $modelEgreso->getAdapter()->quoteInto("id=?", $row->egreso_id);
                            $rowEgreso = $modelEgreso->fetchRow($whereEgreso);
                            $rowEgreso->estado = '1';
                            $rowEgreso->save();
                            
                        }

                        $db->commit();
                        $mSession->mensajes[] = 'La rendición fue ingresada de forma exitosa.';
                        $mSession->claseMensaje = 'confirmacion';
                        $this->_forward('user','caja-chica');

                    } catch (Exception $e) {

                        $db->rollBack();
                        $mSession->mensajes[] = 'Ocurrió un error al intentar ingresar la rendición.';
                        $mSession->mensajes[] = $e->getMessage();
                        $mSession->claseMensaje = 'error';
                        $this->_forward('user','caja-chica');
                    }
                } else {
                    $form->populate($request->getPost());
                    $form->cantidad->setErrorMessages(array('El monto a ingresar debe estar entre 1 y ' . $saldoDisponible));
                    $form->cantidad->markAsError();
                    $form->maximo->setAttrib('disabled', 'disabled');
                    $this->view->form = $form;
                    $this->renderScript('caja-chica/form.phtml');
                }
            } else {
                $form->maximo->setAttrib('disabled', 'disabled');
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('caja-chica/form.phtml');
            }
        }
    }

    public function deleteAction()
    {
        if($this->_getParam('id') AND
           $this->_helper->validateRecordExists('cc_rendiciones', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $modelRendicion = new Default_Model_CajaChicaRendicion();
            $db = $modelRendicion->getAdapter();
            $db->beginTransaction();

            try {

                $whereRendicion = $modelRendicion->getAdapter()->quoteInto("id = ?" , (int)$this->_getParam('id'));
                $rowRendicion = $modelRendicion->fetchRow($whereRendicion);

                $modelEgreso = new Default_Model_CajaChicaEgreso();
                $whereEgreso = $modelEgreso->getAdapter()->quoteInto("id=?", (int)$rowRendicion->egreso_id);
                $rowEgreso = $modelEgreso->fetchRow($whereEgreso);

                if($rowEgreso->estado=='1'){
                    $rowEgreso->estado='0';
                    $rowEgreso->save();
                }

                $rowRendicion->delete($whereRendicion);

                $db->commit();

                $mSession->mensajes[] = 'La rendición fue eliminada de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_forward('user','caja-chica');

            } catch (Exception $e) {

                $db->rollBack();
                $mSession->tipo_error = 1;
                $mSession->errores[] = $e->getMessage();
                $this->_forward('error-delete-registro','error');
            }
        }
    }

    public function formConsultaAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            if($this->_getParam('type_user')=='a') {

                if($this->_getParam('id')!='0' &&
                   $this->_helper->validateRecordExists('cc_cajas', 'id', App_Rut::cleanToDb($this->_getParam('id')))) {
                    $this->view->caja_id = App_Rut::cleanToDb($this->_getParam('id'));
                }

                $this->view->cajas = Default_Model_VistaCajasChicas::getPairsToSelect();
                $this->view->back = '/caja-chica/view/' . App_Rut::cleanToDb($this->_getParam('id'));
                $this->view->user = 'a';

            } elseif($this->_getParam('type_user')=='u') {
                $this->view->back = '/caja-chica/user';
                $this->view->user = 'u';
            }

            $this->view->empleados = Default_Model_Empleado::getPairsToSelect();
            $this->view->tiposRendiciones = Default_Model_CajaChicaTipoRendicion::getPairsToSelect();
            $this->view->tiposDocumentos = Default_Model_CajaChicaTipoDocumento::getPairsToSelect();
            $this->view->title = "Consultar rendiciones de compras/gastos";
            $this->renderScript('rendicion-caja-chica/form-consulta.phtml');
        }
    }

    public function consultaAction()
    {
        if($_POST) {
            
            $model = new Default_Model_VistaCajasChicasRendiciones();
            
            if($this->_getParam('type_user')=='u'){

                $where = "caja_id='" . $this->usuario->rut . "'";
                $consulta = "/rendicion-caja-chica/form-consulta/0/u";

            } elseif($this->_getParam('user')=='a') {

                $consulta = "/rendicion-caja-chica/form-consulta/0/a";
                if($this->_getParam('caja_id')!='0'){

                    $where = "caja_id='" . $this->_getParam('caja_id') . "'";
                    
                } else {
                    $where = "caja_id IS NOT NULL";
                }
            } else {
                return false;
            }
            
            // filtro por fechas
            $fecha_i = $this->_getParam('fecha_i');
            $fecha_t = $this->_getParam('fecha_t');

            if(Zend_Date::isDate($fecha_i . ' 00:00:00', Zend_Date::ISO_8601)) {
                $fecha_i = $fecha_i . ' 00:00:00';
                $where .= " AND fecha > '" . $fecha_i . "'";
            }

            if(Zend_Date::isDate($fecha_t . ' 23:59:59', Zend_Date::ISO_8601)) {
                $fecha_t = $fecha_t . ' 23:59:59';
                $where .= " AND fecha < '" . $fecha_t . "'";
            }

            // filtro por estados
            $tipo_documento = (int)$this->_getParam('tipo_documento');
            if($tipo_documento!=''){
                $where .= " AND tipo_documento_id='" . $tipo_documento. "'";
            }

            // filtro por tipo de ingreso
            $cuenta = (int)$this->_getParam('cuenta');
            if($cuenta!=''){
                $where .= " AND tipo_rendicion_id='" . $cuenta . "'";
            }

            // filtro por montos
            $signo = (int)$this->_getParam('signo');
            $cantidad = (int)$this->_getParam('monto');
            if($signo==1) {
                $where .= " AND cantidad >= '" . $cantidad . "'";
            } elseif($signo==2) {
                $where .= " AND cantidad <= '" . $cantidad . "'";
            }

            // filtro por empleado
            $rendido_por = App_Rut::cleanToDb($this->_getParam('rendido_por'));
            if($rendido_por!='' && $this->_helper->validateRecordExists('empleados', 'rut', $rendido_por)){
                $where .= " AND entregado_a='" . $rendido_por . "'";
            }
            
            $rows = $model->fetchAll($where);
            
            $this->view->rendiciones = $rows;
            $this->view->back = $this->_getParam('back');
            $this->view->user = $this->_getParam('type_user');
            $this->view->consulta = $consulta;
            $this->view->title = "Consultar rendiciones de dinero";
            $this->renderScript('rendicion-caja-chica/resultados-busqueda.phtml');

        } else {
            $this->_forward("form-consulta", "rendicion-caja-chica");
        }
    }

    
    
    private function _getSaldoDisponible($egreso_id)
    {
        $egreso = new Default_Model_VistaCajasChicasEgresos();
        $where = $egreso->getAdapter()->quoteInto("id=?", $egreso_id);
        $row = $egreso->fetchRow($where);
        $saldoDisponible = $row->cantidad - $row->rendido;
        return $saldoDisponible;
    }
}