<?php
class ReservaController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/reserva';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $reserva = new Default_Model_VistaReservas();
            $reservas = $reserva->fetchAll();

            $paginador = Zend_Paginator::factory($reservas);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->reservas = $paginador;
            $this->view->title = 'Reservas';
            $this->renderScript('reserva/index.phtml');
        }
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
            unset($mSession->recepcion);
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_Reserva(null, $this->path);

            if($this->_request->getParam('id')) {
                
                $reserva = new Default_Model_Reserva();
                $id = (int)$this->_request->getParam('id');
                $where= $reserva->getAdapter()->quoteInto("id=?", $id);
                $row = $reserva->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/reserva/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar reserva Nº $id";

            } else {
                $this->view->title = "Reserva";
            }

            $this->view->form = $form;
            $this->renderScript('reserva/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Reserva(null, $this->path);
        $this->view->title = "Crear reserva";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $reserva = new Default_Model_Reserva();
                    $row = $reserva->createRow();
                    $row->creador = $this->usuario->rut;
                    $row->cliente = App_Rut::cleanToDb($form->getValue('cliente'));
                    $row->vehiculo = strtoupper($form->getValue('vehiculo'));
                    $row->fecha = $form->getValue('fecha');
                    $row->hora = $form->getValue('hora');
                    $row->comentarios = $form->getValue('comentarios');
                    $row->tipo = $form->getValue('tipo');
                    $row->save();
                    $mSession->mensajes[] = 'La reserva de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('index','reserva');

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la reserva.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('get-form', 'reserva');
                }
            } else {

                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('reserva/form.phtml');
            }
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        

        $request = $this->getRequest();
        $form = new Default_Form_Reserva();

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {

                    $id = (int)$form->getValue('id');
                    $reserva = new Default_Model_Reserva();
                    $where = $reserva->getAdapter()->quoteInto("id=?", $id);
                    $row = $reserva->fetchRow($where);
                    $row->creador = $this->usuario->rut;
                    $row->cliente = App_Rut::cleanToDb($form->getValue('cliente'));
                    $row->vehiculo = strtoupper($form->getValue('vehiculo'));
                    $row->fecha = $form->getValue('fecha');
                    $row->hora = $form->getValue('hora');
                    $row->comentarios = $form->getValue('comentarios');
                    $row->tipo = $form->getValue('tipo');
                    $row->save();

                    $mSession->mensajes[] = 'La reserva fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view', 'reserva', null, array('id'=> $id));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','reserva');
                }

            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/reserva/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar reserva";
                $this->renderScript('reserva/form.phtml');
            }
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $reserva = new Default_Model_VistaReservas();

            $id = (int)$this->_getParam('id', 0);
            $where = $reserva->getAdapter()->quoteInto("id=?", $id);
            $row = $reserva->fetchRow($where);
            $this->view->title = "Reserva Nº $id";

            if(false==$row) {
                $this->_forward('index','reserva');
            } else {

                $this->view->reserva = $row;
                $this->renderScript('reserva/view.phtml');
            }
        }
    }

    public function concretarAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND $this->_getParam('id')){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $reserva = new Default_Model_Reserva();
            
            $id = (int)$this->_getParam('id');
            $where = $reserva->getAdapter()->quoteInto("id=?", $id);
            $row = $reserva->fetchRow($where);
            $row->estado = 'CONCRETADA';
            $row->save();

            $mSession->mensajes[] = 'La reserva fue concretada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('index','reserva');
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('reservas', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $reserva = new Default_Model_Reserva();
            $id = (int)$this->_getParam('id');
            $where = $reserva->getAdapter()->quoteInto("id=?", $id);
            $reserva->delete($where);
            $mSession->mensajes[] = 'La reserva fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('index','reserva');
        }
    }
}