<?php
class SendAttachController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->path = '/send-attach';
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $propietario = new Default_Model_Propietario();
        $this->view->propietario = $propietario->fetchRow()->toArray();
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }


        if($this->getRequest()->isXmlHttpRequest() AND 
           $this->_getParam('documento') AND
           $this->_getParam('id') AND
           $this->_helper->validateDocToPdf($this->_getParam('documento'))){

            $documento = $this->_getParam('documento');
            $id = (int)$this->_getParam('id');
            $name = $documento . '-' . $id .'.pdf';
            $back = '/' . $documento . '/view/' . $id;

            $formValues = array(
                'archivo'       => $name,
                'id'            => $id,
                'documento'     => $documento,
                'asunto'        => $this->_getDefaultSubject($documento, $id),
                'texto_mensaje' => $this->_getDefaultMessage($documento),
                'back'          => $back
            );

            $request = $this->getRequest();
            $form = new Default_Form_SendAttach();
            $form->copia->setLabel('Enviar una copia a mi casilla ('.  $this->usuario->mail .')');
            $form->populate($formValues);

            $this->view->title = "Enviar documento adjunto por mail";
            $this->view->form = $form;
            $this->renderScript('send-attach/form.phtml');
        }
    }

    public function sendAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_SendAttach();
        $form->copia->setLabel('Enviar una copia a mi casilla ('.  $this->usuario->mail .')');
        $this->view->title = "Enviar documento adjunto por mail";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    
                    $mail = new App_HtmlMailerDocument('UTF-8');
                    $mail->setFrom($this->usuario->mail, $this->usuario->empleado);
                    $mail->setType(Zend_Mime::MULTIPART_RELATED);
                    $mail->setSubject($form->getValue('asunto'))
                         ->setViewParam('nombre', $form->getValue('nombre'))
                         ->setViewParam('usuario', $this->usuario->empleado)
                         ->setViewParam('mensaje', $form->getValue('texto_mensaje'));

                    $mail->addTo($form->getValue('mail'), $form->getValue('nombre'));

                    if($form->copia->getValue()==1){
                        $mail->addBcc($this->usuario->mail);
                    }

                    $path = $form->getValue('documento') . $form->getValue('id');
                    $pdf = new App_Pdf($path);
                    $attach = $mail->createAttachment($pdf->getContent());
                    $attach->filename = $form->getValue('archivo');

                    $mail->sendHtmlTemplate('send-attach.phtml');

                    $envio = new Default_Model_EnvioDocumento();
                    $row = $envio->createRow();
                    $row->creador = $this->usuario->rut;
                    $row->tipo = $form->getValue('documento');
                    $row->documento_id = $form->getValue('id');
                    $row->nombre = $form->getValue('nombre');
                    $row->mail = $form->getValue('mail');
                    $row->save();
                    
                    $mSession->mensajes[] = 'El mensaje fue enviado de forma satisfactoria.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_redirect($form->getValue('back'));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar enviar el mensaje, por favor inténtelo más tarde.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect($form->getValue('back'));
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('send-attach/form.phtml');
            }
        }
    }


    private function _getDefaultSubject($documento, $id)
    {
        $asuntos = array(
            'cotizacion'    => "ExpressAuto - Cotización Nº $id",
            'orden-compra'  => "ExpressAuto - Orden de compra Nº $id"
        );

        foreach($asuntos as $key => $value){
            if($documento==$key){
                return $value;
                break;
            }
        }
    }

    private function _getDefaultMessage($documento)
    {
        $mensajes = array(
            'cotizacion'    => "Adjunto cotización según lo solicitado",
            'orden-compra'  => "Adjunto orden de compra"
        );

        foreach($mensajes as $key => $value){
            if($documento==$key){
                return $value;
                break;
            }
        }
    }
}