<?php
class ServicioProductoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();

        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
    }
    
    public function init()
    {
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/servicio-producto';
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function getFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_ServicioProducto();

            if($this->_request->getParam('id') AND
               $this->_helper->validateRecordExists('servicios_productos', 'id', $this->_request->getParam('id'))) {

                $serv_producto = new Default_Model_ServicioProducto();
                $where = $serv_producto->getAdapter()->quoteInto("id=?", (int)$this->_request->getParam('id'));
                $row = $serv_producto->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction($this->path .'/edit');
                $form->submit->setLabel('Guardar cambios');
                echo $form;

            } elseif($this->_request->getParam('codigo') AND
                     $this->_helper->validateRecordExists('productos', 'codigo', $this->_request->getParam('codigo'))) {
                $form->producto->setValue($this->_request->getParam('codigo'));
                echo $form;
            }
        }
    }

    public function newAction()
    {
        $request = $this->getRequest();
        $form = new Default_Form_ServicioProducto();

        if ($this->getRequest()->isPost()) {
            
            if ($form->isValid($request->getPost())) {
 
                try {
                    
                    $serv_producto = new Default_Model_ServicioProducto();
                    $row = $serv_producto->createRow();
                    $row->producto = $form->getValue('producto');
                    $row->servicio = $form->getValue('servicio');
                    $row->unidades = $form->getValue('unidades');
                    $row->descripcion = $form->getValue('descripcion');
                    $row->save();

                    $form->reset();
                    $form->producto->setValue($row->producto);
                    
                    $aviso = '<div id="aviso-form" class="confirmacion"><ul>';
                    $aviso .= '<li>El servicio fue agregado de forma satisfactoria. </li>';
                    $aviso .= '</ul></div>';

                    echo $aviso.$form;

                } catch (Exception $e) {

                    $aviso = '<div id="aviso-form" class="error"><ul><li>Ocurrió un error el intentar agregar el servicio</li></ul></div>';

                }
            } else {
                $form->populate($request->getPost());
                echo $form;
            }
        }
    }

    public function editAction()
    {
        $request = $this->getRequest();
        $form = new Default_Form_ServicioProducto();
        $form->id->setRequired(true);

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {

                    $serv_producto = new Default_Model_ServicioProducto();
                    $where = $serv_producto->getAdapter()->quoteInto("id=?",$form->getValue('id'));
                    $row = $serv_producto->fetchRow($where);
                    $row->servicio = $form->getValue('servicio');
                    if($form->getValue('descripcion_alt')!='') {
                        $row->descripcion_alt = $form->getValue('descripcion_alt');
                    } else {
                        $row->descripcion_alt = NULL;
                    }
                    $row->save();

                    $aviso = '<div id="aviso-form" class="confirmacion"><ul>';
                    $aviso .= '<li>El servicio fue editado de forma satisfactoria. </li>';
                    $aviso .= '</ul></div>';

                    echo $aviso;

                } catch (Exception $e) {

                    $aviso = '<div id="aviso-form" class="error"><ul><li>Ocurrió un error el intentar editar el servicio</li></ul></div>';

                }
            } else {
                $form->populate($request->getPost());
                echo $form;
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $producto = $this->_getParam('producto');

            if($this->_helper->validateRecordExists('productos', 'codigo', $producto)){

                $data = $this->_getParam('data');
                $items = explode(",", $data);

                $servicioProducto = new Default_Model_ServicioProducto();

                foreach($items as $id){

                    if($this->_helper->validateRecordExists('servicios_productos', 'id', $id)){
                        $where = $servicioProducto->getAdapter()->quoteInto("id=?", $id);
                        $servicioProducto->delete($where);
                    }
                }
                return true;
            }
        }
    }
}