<?php
class SolicitudArticuloController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/solicitud-articulo';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $solicitud = new Default_Model_VistaSolicitudesArticulos();
            $solicitudes = $solicitud->fetchAll();

            $paginador = Zend_Paginator::factory($solicitudes);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->solicitudes = $paginador;
            $this->view->title = 'Solicitudes artículos';
            $this->renderScript('solicitud-articulo/index.phtml');
        }
    }

    public function listByNotaVentaAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('notas_ventas', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = strtoupper($this->_getParam('id'));
            $currentPage = $this->_getParam('page', 1);

            $model = new Default_Model_VistaSolicitudesArticulos();
            $where = $model->getAdapter()->quoteInto('nota_id=?', $id);
            $solicitudes = $model->fetchAll($where);

            $paginador = Zend_Paginator::factory($solicitudes);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control_extra.phtml');

            $this->view->solicitudes = $paginador;
            $this->renderScript('solicitud-articulo/list-by-nota-venta.phtml');
        }
    }
    
    public function getFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $request = $this->getRequest();
            $form = new Default_Form_SolicitudArticulo(null, $this->path);

            if($this->_getParam('id')) {

                $id = $this->_getParam('id');
                $solicitud = new Default_Model_SolicitudArticulo();
                $where = $solicitud->getAdapter()->quoteInto("id=?", $id);
                $row = $solicitud->fetchRow($where)->toArray();

                $form->populate($row);
                $form->setAction('/solicitud-articulo/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar solicitud de artículo";

            } else {

                $this->view->title = "Crear solicitud de artículo";

            }
            $this->view->form = $form;
            $this->renderScript('solicitud-articulo/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_SolicitudArticulo(null, $this->path);
        $this->view->title = "Crear solicitud de artículo";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                try {
                    
                    $solicitud = new Default_Model_SolicitudArticulo();
                    
                    $row = $solicitud->createRow();
                    $row->creador  = $this->usuario->rut;
                    $row->cantidad = $form->getValue('cantidad');
                    $row->articulo = $form->getValue('articulo');
                    $row->cargar_a = $form->getValue('cargar_a');
                    $row->save();
                    
                    $mSession->mensajes[] = 'La solicitud ha sido creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la solicitud.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                }

                $this->_forward('view','solicitud-articulo', null, array('id' => $row->id));
                
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('solicitud-articulo/form.phtml');
            }
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('solicitudes_articulos', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = $this->_getParam('id');
            $solicitud = new Default_Model_VistaSolicitudesArticulos();
            $where = $solicitud->getAdapter()->quoteInto("id=?", $id);
            $row = $solicitud->fetchRow($where);

            if(false==$row) {
                $this->_forward('index','solicitud-articulo');
            } else {

                $this->view->solicitud = $row;
                $this->view->title = 'Solicitud de artículo';

                if($row->estado=='BORRADOR') {

                    $this->renderScript('solicitud-articulo/view-borrador.phtml');

                } elseif($row->estado=='PENDIENTE') {

                    $this->view->title .= " : Pendiente entrega";
                    $this->renderScript('solicitud-articulo/view-pendiente.phtml');

                } elseif($row->estado=='ENTREGADA') {

                    $this->view->title .= " : Entregado";
                    $this->renderScript('solicitud-articulo/view-entregada.phtml');

                } elseif($row->estado=='CANCELADA') {

                    $this->view->title .= " : Cancelada";
                    $this->renderScript('solicitud-articulo/view-cancelada.phtml');
                }
            }
        }


    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $solicitud = new Default_Model_SolicitudArticulo();

        $request = $this->getRequest();
        $form = new Default_Form_SolicitudArticulo();

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {

                    $id = (int)$form->getValue('id');
                    $where = $solicitud->getAdapter()->quoteInto("id=?", $id);
                    $row = $solicitud->fetchRow($where);
                    $row->cantidad = $form->getValue('cantidad');
                    $row->articulo = $form->getValue('articulo');
                    $row->cargar_a = $form->getValue('cargar_a');
                    $row->save();

                    $mSession->mensajes[] = 'La solicitud fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view', 'solicitud-articulo', null, array('id'=> $id));


                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la solicitud.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                    $this->_forward('index','solicitud-articulo');
                }

            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/solicitud-articulo/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar solicitud de artículo";
                $this->renderScript('solicitud-articulo/form.phtml');
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $solicitud = new Default_Model_SolicitudArticulo();
            $id = (int)$this->_getParam('id');
            $where = $solicitud->getAdapter()->quoteInto("id=?", $id);
            $solicitud->delete($where);
            $mSession->mensajes[] = 'La solicitud fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('index','solicitud-articulo');
        }
    }

    public function finishAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND $this->_getParam('id')){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');
            $solicitud = new Default_Model_SolicitudArticulo();
            $where = $solicitud->getAdapter()->quoteInto("id=?", $id);
            $row = $solicitud->fetchRow($where);

            if($row->estado=='BORRADOR') {

                $row->estado = 'PENDIENTE';
                $row->save();
                $mSession->mensajes[] = 'La solicitud fue emitida y enviada de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';

            }
            $this->_forward('view','solicitud-articulo', null, array('id' => $id));
        }
    }
}