<?php
class SolicitudCompraRepuestoController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $propietario = new Default_Model_Propietario();
        $this->view->propietario = $propietario->fetchRow();
        $this->path = '/solicitud-compra-repuesto';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $solicitud = new Default_Model_VistaSolicitudesComprasRepuestos();
            $order = 'id DESC';
            $solicitudes = $solicitud->fetchAll(null, $order);

            $paginador = Zend_Paginator::factory($solicitudes);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->solicitudes = $paginador;
            $this->view->title = 'Solicitudes de compra de repuestos';
            $this->renderScript('solicitud-compra-repuesto/index.phtml');
        }  
    }

    public function listAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $solicitud = new Default_Model_VistaSolicitudesComprasRepuestos();
            $where = "estado!='BORRADOR'";
            $order = 'id DESC';
            $solicitudes = $solicitud->fetchAll($where, $order);

            $paginador = Zend_Paginator::factory($solicitudes);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->mode = 'a';
            $this->view->solicitudes = $paginador;
            $this->view->title = 'Solicitudes de compra de repuestos';
            $this->renderScript('solicitud-compra-repuesto/index.phtml');
        }
    }

    public function listByOrdenServicioAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('ordenes_servicios', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');
            $currentPage = $this->_getParam('page', 1);

            $model = new Default_Model_VistaSolicitudesComprasRepuestos();
            $where = $model->getAdapter()->quoteInto('orden_id=?', $id);
            $solicitudes = $model->fetchAll($where);

            $paginador = Zend_Paginator::factory($solicitudes);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control_extra.phtml');

            $this->view->solicitudes = $paginador;
            $this->renderScript('solicitud-compra-repuesto/list-by-orden-servicio.phtml');
        }
    }

    public function listByNotaVentaAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('notas_ventas', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = strtoupper($this->_getParam('id'));
            $currentPage = $this->_getParam('page', 1);

            $model = new Default_Model_VistaSolicitudesComprasRepuestos();
            $where = $model->getAdapter()->quoteInto('nota_id=?', $id);
            $solicitudes = $model->fetchAll($where);

            $paginador = Zend_Paginator::factory($solicitudes);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control_extra.phtml');

            $this->view->solicitudes = $paginador;
            $this->renderScript('solicitud-compra-repuesto/list-by-nota-venta.phtml');
        }
    }
    
    public function newAction()
    {
        if($this->getRequest()->isXmlHttpRequest() &&
           $this->_getParam('from_id') &&
           $this->_helper->validateRecordExists('ordenes_servicios', 'id', $this->_getParam('from_id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            
            $id = (int)$this->_getParam('from_id');

            try {
                
                $solicitud = new Default_Model_SolicitudCompraRepuesto();
                $row = $solicitud->createRow();
                $row->creador = $this->usuario->rut;
                $row->orden_id = $id;
                $row->estado = 'BORRADOR';
                $row->save();
                $this->_forward('view','solicitud-compra-repuesto', null, array('id' => $row->id));
                
            } catch (Exception $e) {
                $mSession->mensajes[] = 'Ocurrió un error al intentar crear la solicitud de compra de repuestos';
                $mSession->claseMensaje = 'error';
                $this->_forward('view','orden-servicio', null, array('id' => $id));
            }
        }
    }

    public function deleteAction()
    {
        if($this->_getParam('id')){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $solicitud = new Default_Model_SolicitudCompraRepuesto();
            $where = $solicitud->getAdapter()->quoteInto('id = ?' , $this->_getParam('id'));
            $row = $solicitud->fetchRow($where);
            $id = $row->orden_id;
            $solicitud->delete($where);
            $mSession->mensajes[] = 'La solicitud de compra de repuestos fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('view','orden-servicio', null, array('id' => $id));
        }
    }

    public function sendAction()
    {
        if($this->getRequest()->isXmlHttpRequest() &&
           $this->_getParam('id') &&
           $this->_helper->validateRecordExists('solicitudes_compras_repuestos', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $id = (int)$this->_getParam('id');

            $modelVista = new Default_Model_VistaSolicitudesComprasRepuestos();
            $where = $modelVista->getAdapter()->quoteInto("id=?", $id);
            $rowVista = $modelVista->fetchRow($where);

            if($rowVista->num_items > 0 && $rowVista->estado=='BORRADOR') {

                $solicitud = new Default_Model_SolicitudCompraRepuesto();
                $row = $solicitud->fetchRow($where);
                $row->estado = 'PENDIENTE';
                $row->save();
                $mSession->mensajes[] = 'La solicitud de compra de repuestos fue enviada al encargado de compras.';
                $mSession->claseMensaje = 'confirmacion';

            } else {

                $mSession->mensajes[] = 'No ha agregado ítems a la solicitud.';
                $mSession->claseMensaje = 'error';

            }
            $this->_forward('view','solicitud-compra-repuesto', null, array('id' => $id));
        }
    }

    public function finishAction()
    {
        if($this->getRequest()->isXmlHttpRequest() &&
           $this->_getParam('id') &&
           $this->_helper->validateRecordExists('solicitudes_compras_repuestos', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $id = (int)$this->_getParam('id');
            
            $modelVista = new Default_Model_VistaSolicitudesComprasRepuestos();
            $where = $modelVista->getAdapter()->quoteInto("id=?", $id);
            $rowVista = $modelVista->fetchRow($where);
            
            if($rowVista->num_items > 0 && $rowVista->estado=='APROBADA') {

                $solicitud = new Default_Model_SolicitudCompraRepuesto();
                $row = $solicitud->fetchRow($where);
                $row->estado = 'TERMINADA';
                $row->save();
                $mSession->mensajes[] = 'La solicitud de compra de repuestos fue enviada al encargado de compras.';
                $mSession->claseMensaje = 'confirmacion';

            } else {

                $mSession->mensajes[] = 'No ha agregado ítems a la solicitud.';
                $mSession->claseMensaje = 'error';

            }
            $this->_forward('list','solicitud-compra-repuesto');
        }
    }

     public function aprobarAction()
    {
        if($this->getRequest()->isXmlHttpRequest() &&
           $this->_getParam('id') &&
           $this->_helper->validateRecordExists('solicitudes_compras_repuestos', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');

            try {

                $solicitud = new Default_Model_SolicitudCompraRepuesto();
                $where = $solicitud->getAdapter()->quoteInto("id=?", $id);
                $row = $solicitud->fetchRow($where);
                $row->estado = 'APROBADA';
                $row->save();

                $mSession->mensajes[] = 'La solicitud de compra de repuestos fue aprobada de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';

            } catch (Exception $e) {

                $mSession->mensajes[] = 'Ocurrió un error al intentar aprobar la solicitud.';
                $mSession->claseMensaje = 'error';

            }

            $this->_forward('view','solicitud-compra-repuesto', null, array('id' => $id));
        }
    }

    public function rechazarAction()
    {
        if($this->getRequest()->isXmlHttpRequest() &&
           $this->_getParam('id') &&
           $this->_helper->validateRecordExists('solicitudes_compras_repuestos', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');

            try {

                $solicitud = new Default_Model_SolicitudCompraRepuesto();
                $where = $solicitud->getAdapter()->quoteInto("id=?", $id);
                $row = $solicitud->fetchRow($where);
                $row->estado = 'RECHAZADA';
                $row->save();

                $mSession->mensajes[] = 'La solicitud de compra de repuestos fue rechazada de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';

            } catch (Exception $e) {

                $mSession->mensajes[] = 'Ocurrió un error al intentar rechazar la solicitud.';
                $mSession->claseMensaje = 'error';

            }
            
            $this->_forward('list','solicitud-compra-repuesto');
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id', 0);
            $solicitud = new Default_Model_VistaSolicitudesComprasRepuestos();
            $where = $solicitud->getAdapter()->quoteInto("id=?", $id);
            $row = $solicitud->fetchRow($where);

            $item = new Default_Model_ItemSolicitudCompraRepuesto();
            $where_items = $item->getAdapter()->quoteInto("solicitud_id=?", $id);
            $items = $item->fetchAll($where_items);
            
            $this->view->title = "Solicitud de compra de repuestos Nº $id";
            $this->view->solicitud = $row;
            $this->view->items = $items;

            if($row->estado=='BORRADOR') {

                $this->renderScript('solicitud-compra-repuesto/view-borrador.phtml');

            } elseif($row->estado=='APROBADA') {

                    $this->view->title .= ': Aprobada';
                    $this->renderScript('solicitud-compra-repuesto/view-aprobada.phtml');
                
            } elseif($row->estado=='PENDIENTE') {

                if($this->_getParam('type_user')=='a') {

                    $this->view->title .= ': Pendiente';
                    $this->renderScript('solicitud-compra-repuesto/review.phtml');

                } else {
                    $this->view->title .= ': Pendiente';
                    $this->renderScript('solicitud-compra-repuesto/view.phtml');
                }

            } else {
                $this->renderScript('solicitud-compra-repuesto/view.phtml');
            }
        }
    }

    public function reviewAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $id = (int)$this->_getParam('id', 0);
            $solicitud = new Default_Model_VistaSolicitudesCompras();
            $row = $solicitud->fetchRow('id=' . $id);
            $this->view->title = "Solicitud de compra Nº $id";

            if(false==$row) {
                $this->_forward('index','solicitud-compra');
            } else {
                $this->view->solicitud = $row;
                $this->renderScript('solicitud-compra/review.phtml');
            }
        }
    }

    public function detalleAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            if($this->_getParam('id') AND
                $this->_helper->validateRecordExists('solicitudes_compras_repuestos','id', $this->_getParam('id'))){

                $id = $this->_getParam('id');

                $solicitud = new Default_Model_VistaSolicitudesComprasRepuestos();
                $where = $solicitud->getAdapter()->quoteInto("id=?", $id);
                $row = $solicitud->fetchRow($where);

                $items = new Default_Model_ItemSolicitudCompraRepuesto();
                $where_items = $items->getAdapter()->quoteInto("solicitud_id=?", $id);

                $this->view->items = $items->fetchAll($where_items);
                $this->view->solicitud = $row;

               $this->renderScript('solicitud-compra-repuesto/detalle.phtml');
            }
        }
    }

    public function printAction()
    {
        if($this->_getParam('id') AND
           $this->_helper->validateRecordExists('vista_solicitudes_compras_repuestos','id', $this->_getParam('id'))){

            $this->_helper->layout->disableLayout(false);
            $this->_helper->viewRenderer->setNoRender(false);
            $this->_helper->layout->setLayout('print-landscape');

            $id = (int)$this->_getParam('id');
            $solicitud = new Default_Model_VistaSolicitudesComprasRepuestos();
            $where = $solicitud->getAdapter()->quoteInto("id=?", $id);
            $row = $solicitud->fetchRow($where);

            if(false!==$row AND $row['estado']=='APROBADA') {

                $item = new Default_Model_ItemSolicitudCompraRepuesto();
                $where_items = $item->getAdapter()->quoteInto("solicitud_id=?",$id);
                $items = $item->fetchAll($where_items);

                $this->view->title = "Solicitud de compra de repuestos Nº $id";
                $this->view->solicitud = $row;
                $this->view->items = $items;
            }
        }
    }
}