<?php
class UsuarioController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/usuario';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {

                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $usuario = new Default_Model_Empleado();
            $usuarios = $usuario->fetchAll();
            
            $paginador = Zend_Paginator::factory($usuarios);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
            
            $this->view->usuarios = $paginador;
            $this->view->title = "Usuarios";
            $this->renderScript('usuario/index.phtml');

        }
    }

    public function renovarClaveAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $mSession->mensajes[] = 'La clave del usuario fue renovada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';

            $this->_forward('index', 'usuario');
        }
    }

    public function disableUserAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            if($this->_getParam('rut')) {

                $empleado = new Default_Model_Empleado();
                $where = $empleado->getAdapter()->quoteInto("rut=?", App_Rut::cleanToDb($this->_getParam('rut')));

                try {

                    $row = $empleado->fetchRow($where);
                    $row->acceso_sistema = 'DESHABILITADO';
                    $row->save();
                    $mSession->mensajes[] = 'El empleado ha sido deshabilitado para acceder al sistema.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch(Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar deshabilitar el acceso del empleado al sistema.';
                    $mSession->claseMensaje = 'error';
                    
                }
                $this->_forward('index', 'usuario');
            }
        }
    }

    public function enableUserAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            if($this->_getParam('rut') AND 
               $this->_helper->validateRecordExists('empleados', 'rut', App_Rut::cleanToDb($this->_getParam('rut')))) {

                $empleado = new Default_Model_Empleado();
                $where = $empleado->getAdapter()->quoteInto("rut=?", App_Rut::cleanToDb($this->_getParam('rut')));

                try {

                    $row = $empleado->fetchRow($where);
                    $row->acceso_sistema = 'HABILITADO';

                    $clave = $this->_generatePassword($row->nombres);

                    $row->clave = md5($clave);
                    $row->save();
                    
                    $mail = new App_HtmlMailerDocument('UTF-8');
                    $mail->setFrom('admin@expressauto.cl', 'Admin Expressauto');
                    $mail->setSubject('Habilitación acceso iMecanix')
                         ->setViewParam('empleado', $row->nombres . ' ' . $row->apellidos)
                         ->setViewParam('usuario', $row->mail)
                         ->setViewParam('clave', $clave);
                    
                    $mail->addTo($row->mail, $row->nombres . ' ' . $row->apellidos);
                    $mail->sendHtmlTemplate('enable-user-sistema.phtml');
                    
                    $mSession->mensajes[] = 'El empleado ha sido habilitado de forma exitosa para acceder al sistema.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch(Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar habilitar el usuario.';
                    $mSession->claseMensaje = 'error';

                }
                $this->_forward('index', 'usuario');
            }
        }
    }

    private function _generatePassword($semilla)
    {
        $md5 = md5($semilla);
        $clave = substr($md5, 1, 8);
        return $clave;
    }

    public function preferenciasAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $formClaveAcceso = new Default_Form_CambiarClave(null, $this->path);
        $formClaveAcceso->usuario->setValue($this->usuario->rut);

        $formClaveCajaChica = new Default_Form_CambiarClaveCajaChica(null, $this->path);
        $formClaveCajaChica->usuario->setValue($this->usuario->rut);

        $this->view->title = 'Preferencias del usuario';
       
        $this->view->formClaveAcceso = $formClaveAcceso;
        $this->view->formClaveCajaChica = $formClaveCajaChica;
        $this->renderScript('usuario/preferencias.phtml');
    }

    public function cambiarClaveAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_CambiarClave(null, $this->path);
        $this->view->title = 'Cambiar clave';

        if($this->getRequest()->isPost()){
            if($form->isValid($request->getPost())){
                if($this->usuario->rut==$form->getValue('usuario')){

                    try {

                        $usuario = new Default_Model_Empleado();
                        $where = $usuario->getAdapter()->quoteInto("rut=?", $form->getValue('usuario'));
                        $row = $usuario->fetchRow($where);

                        if($row->acceso_sistema=='HABILITADO') {

                            if($row->clave==md5($form->getValue('clave_actual'))){

                                $row->clave = md5($form->getValue('clave_nueva'));
                                $row->save();
                                $mSession->mensajes[] = 'Su clave fue cambiada de forma satisfactoria';
                                $mSession->claseMensaje = 'confirmacion';

                            } else {
                                $mSession->mensajes[] = 'La clave actual ingresada no es válida';
                                $mSession->claseMensaje = 'error';
                            }
                        } else {
                            $mSession->mensajes[] = 'El usuario no se encuentra habilitado';
                            $mSession->claseMensaje = 'error';
                        }
                    } catch (Exception $e) {

                        $mSession->mensajes[] = 'Ocurrió un error al intentar cambiar la clave, por favor inténtelo más tarde.';
                        $mSession->claseMensaje = 'error';

                    }
                    $this->_forward('preferencias', 'usuario');
                }
                
            } else {
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('usuario/cambiar-clave.phtml');
            }
        }
    }

    public function configurarPermisosAction()
    {

        if($this->getRequest()->isXmlHttpRequest() AND 
           $this->_getParam('rut') AND
           $this->_helper->validateRecordExists('empleados', 'rut', App_Rut::cleanToDb($this->_getParam('rut')))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $rut = App_Rut::cleanToDb($this->_getParam('rut'));

            $request = $this->getRequest();
            $form = new Default_Form_PermisosUsuario(null, $this->path);
            $form->usuario->setValue($rut);
            $form->usuario->setAttrib('disabled', 'disabled');
            $this->view->form = $form;
            $this->view->title = 'Configurar permisos usuario';
            $this->renderScript('usuario/configurar-permisos.phtml');

        }


    }
}