<?php
class VehiculoController extends Zend_Controller_Action
{
    public function init()
    {
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/index/exit');
        }
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->path = '/vehiculo';
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $this->view->title = "Vehículos";
            $vehiculo = new Default_Model_VistaVehiculos();
            $vehiculos = $vehiculo->fetchAll(null, 'marca');

            $paginador = Zend_Paginator::factory($vehiculos);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->vehiculos = $paginador;
            $this->renderScript('vehiculo/index.phtml');
        }
    }

    public function getFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $request = $this->getRequest();
            

            if($this->_request->getParam('id')) {

                $patente = $this->_getParam('id');
                $vehiculo = new Default_Model_VistaVehiculos();
                $where = $vehiculo->getAdapter()->quoteInto("patente=?", $patente);
                $row = $vehiculo->fetchRow($where)->toArray();

                $form = new Default_Form_Vehiculo(null, $this->path, $row['marca_id']);

                $form->populate($row);
                $form->cliente->setValue($row['cliente_id']);
                $form->setAction('/vehiculo/edit');
                $form->patente->setAttrib('disabled', 'disabled');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar vehiculo";

            } else {

                $form = new Default_Form_Vehiculo(null, $this->path);

                if($this->_request->getParam('from_id')){
                    $form->cliente->setValue(App_Rut::cleanToDb($this->_request->getParam('from_id')));
                }

                $this->view->title = "Agregar vehículo";

            }
            $this->view->form = $form;
            $this->renderScript('vehiculo/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Vehiculo(null, $this->path);
        $this->view->title = "Agregar vehículo";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $vehiculo = new Default_Model_Vehiculo();
                    $row = $vehiculo->createRow();
                    $row->cliente = App_Rut::cleanToDb($form->getValue('cliente'));
                    $row->patente = strtoupper($form->getValue('patente'));
                    $row->vin_chassis = strtoupper($form->getValue('vin_chassis'));
                    $row->numero_motor = strtoupper($form->getValue('numero_motor'));
                    $row->marca_id = $form->getValue('marca_id');
                    $row->modelo = $form->getValue('modelo');
                    $row->version = $form->getValue('version');
                    $row->cilindrada = $form->getValue('cilindrada');
                    $row->traccion = $form->getValue('traccion');
                    $row->transmision = $form->getValue('transmision');
                    $row->tipo_combustible = $form->getValue('tipo_combustible');
                    $row->anio = $form->getValue('anio');
                    $row->color = $form->getValue('color');
                    $row->km_anual = $form->getValue('km_anual');
                    $row->save();
                    $mSession->mensajes[] = 'El vehículo fue agregado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view','vehiculo', null , array('id' => $row->patente));

                } catch(Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar agregar el vehículo.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','vehiculo');
                }
            }  else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('vehiculo/form.phtml');
            }
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $vehiculo = new Default_Model_Vehiculo();
        $request = $this->getRequest();
        $form = new Default_Form_Vehiculo();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $patente = $form->getValue('patente');
                    $where = $vehiculo->getAdapter()->quoteInto("patente=?", $patente);
                    $row = $vehiculo->fetchRow($where);
                    $row->cliente = App_Rut::cleanToDb($form->getValue('cliente'));
                    $row->vin_chassis = strtoupper($form->getValue('vin_chassis'));
                    $row->numero_motor = strtoupper($form->getValue('numero_motor'));
                    $row->marca_id = $form->getValue('marca_id');
                    $row->modelo = $form->getValue('modelo');
                    $row->version = $form->getValue('version');
                    $row->cilindrada = $form->getValue('cilindrada');
                    $row->traccion = $form->getValue('traccion');
                    $row->transmision = $form->getValue('transmision');
                    $row->tipo_combustible = $form->getValue('tipo_combustible');
                    $row->anio = $form->getValue('anio');
                    $row->color = $form->getValue('color');
                    $row->km_anual = $form->getValue('km_anual');
                    $row->save();

                    $mSession->mensajes[] = 'El vehículo fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view', 'vehiculo', null, array('id' => $patente));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','vehiculo');
                }
            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/vehiculo/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar vehiculo";
                $this->renderScript('vehiculo/form.phtml');
            }
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            if($this->_getParam('id')) {

                $mSession = new Zend_Session_Namespace('expressauto');

                if($mSession->mensajes!='') {
                    $this->view->mensajes = $mSession->mensajes;
                    $this->view->claseMensaje = $mSession->claseMensaje;
                    $mSession->mensajes = '';
                    $mSession->claseMensaje = '';
                }

                $vehiculo = new Default_Model_VistaVehiculos();
                $patente = $this->_getParam('id');
                $where = $vehiculo->getAdapter()->quoteInto("patente=?", $patente);
                $this->view->vehiculo = $vehiculo->fetchRow($where);
                $this->view->title = 'Vehículo';

                if(false==$this->view->vehiculo) {
                    $this->_forward('index','vehiculo');
                } else {
                    $this->renderScript('vehiculo/view.phtml');
                }
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('vehiculos','patente', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');
            
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $vehiculo = new Default_Model_Vehiculo();
            $where = $vehiculo->getAdapter()->quoteInto("patente=?",$this->_getParam('id'));
            $vehiculo->delete($where);
            
            $mSession->mensajes[] = 'El vehículo fue eliminado de forma exitosa.';
            
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('index','vehiculo');
        }
    }

    public function searchTooltipAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $vehiculo = new Default_Model_VistaVehiculos();

            $filter_tags    = new Zend_Filter_StripTags();
            $criterio       = $filter_tags->filter(trim($this->_getParam('criterio')));
            $valor          = $filter_tags->filter(trim($this->_getParam('valor')));
            $this->view->t  = $filter_tags->filter(trim($this->_getParam('t')));

            if($criterio!='' AND $valor!='') {

                if($criterio=='patente') {

                    $valor = strtoupper($valor);
                    $where = "$criterio='$valor'";

                } else {

                    $where = "$criterio LIKE '%$valor%'";
                }

                $this->view->vehiculos = $vehiculo->fetchAll($where)->toArray();
            }

            $this->renderScript('vehiculo/search.phtml');
        }
    }

    public function viewSmallAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $patente = $this->_getParam('id');
            $vehiculo = new Default_Model_VistaVehiculos();
            $where = $vehiculo->getAdapter()->quoteInto("patente=?", $patente);
            $this->view->vehiculo = $vehiculo->fetchRow($where)->toArray();
            $this->renderScript('vehiculo/view-tooltip.phtml');
        }
    }

    public function asignarPautaAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('pauta_id') AND
           $this->_helper->validateRecordExists('pautas_mantenciones', 'id', $this->_getParam('pauta_id')) AND 
           $this->_getParam('patente') AND
           $this->_helper->validateRecordExists('vehiculos', 'patente', $this->_getParam('patente'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $patente = $this->_getParam('patente');
            $pauta_id = (int)$this->_getParam('pauta_id');

            try {

                $vehiculo = new Default_Model_Vehiculo();
                $where = $vehiculo->getAdapter()->quoteInto("patente=?", $patente);
                $row = $vehiculo->fetchRow($where);
                $row->pauta_id = $pauta_id;
                $row->save();

                $this->_forward('view', 'vehiculo', null, array('patente' => $patente));

            } catch (Exception $e) {

                $this->_forward('view', 'vehiculo', null, array('patente' => $patente));

            }
        } else {
            echo 'error';
        }
    }

    public function eliminarAsociacionPautaAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('patente') AND
           $this->_helper->validateRecordExists('vehiculos', 'patente', $this->_getParam('patente'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $patente = $this->_getParam('patente');

            try {

                $vehiculo = new Default_Model_Vehiculo();
                $where = $vehiculo->getAdapter()->quoteInto("patente=?", $patente);
                $row = $vehiculo->fetchRow($where);
                $row->pauta_id = null;
                $row->save();

                $this->_forward('view', 'vehiculo', null, array('patente' => $patente));

            } catch (Exception $e) {

                $this->_forward('view', 'vehiculo', null, array('patente' => $patente));

            }
        }
    }

    public function listByClienteAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('clientes', 'rut', App_Rut::cleanToDb($this->_getParam('id')))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $rut = App_Rut::cleanToDb($this->_getParam('id'));
            $currentPage = $this->_getParam('page', 1);

            $vehiculo = new Default_Model_VistaVehiculos();
            $where = $vehiculo->getAdapter()->quoteInto('cliente_id=?', $rut);
            $vehiculos = $vehiculo->fetchAll($where);

            $paginador = Zend_Paginator::factory($vehiculos);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control_extra.phtml');

            $this->view->vehiculos = $paginador;
            $this->renderScript('vehiculo/list-by-cliente.phtml');
        }
    }
}