<?php
class Default_Form_Articulo extends Zend_Form
{ 
    public function __construct($options = null, $path = null, $history = '/articulo')
    { 
        parent::__construct($options);

        $descripcionCategoria = 'Escriba el nombre de la categoría hasta que '
                              . 'encuentre la que corresponde para el artículo';

        $descripcionCodigoProveedor = 'Recuerde que este código es una referencia y no todos artículos poseen uno.';

        $optionsCategoria = array('table' => 'categorias_articulos', 'field' => 'id');
        $validadorCategoria = new Zend_Validate_Db_RecordExists($optionsCategoria);

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));
        

        $back = new Zend_Form_Element_Hidden('back');
        $back->setValue($history)
             ->setDecorators(array('ViewHelper'));

        $codigo_proveedor = new Zend_Form_Element_Text('codigo_proveedor');
        $codigo_proveedor->setLabel('Código proveedor')
                         ->setRequired(false)
                         ->addFilter('StripTags')
                         ->addFilter('StringTrim')
                         ->setAttrib('class', 'tooltip')
                         ->setDescription($descripcionCodigoProveedor);

        $categoria_id = new Zend_Form_Element_Text('categoria_id');
        $categoria_id->setLabel('ID Categoría')
                     ->setRequired(true)
                     ->addFilter('StripTags')
                     ->addFilter('StringTrim')
                     ->addValidator($validadorCategoria);

        $categoria = new Zend_Form_Element_Text('categoria');
        $categoria->setLabel('Nombre categoria')
                  ->setRequired(false)
                  ->addFilter('StripTags')
                  ->addFilter('StringTrim')
                  ->setAttrib('onkeypress', 'ajaxSearchCategoriaArticulo($(this), "#categoria_id")');

        $envase_id = new Zend_Form_Element_Select('envase_id');
        $envase_id->setLabel('Envase')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addMultiOption('','-- Seleccionar --')
               ->addMultiOptions(Default_Model_VistaEnvases::getPairsToSelect());

        $fabricante_id = new Zend_Form_Element_Select('fabricante_id');
        $fabricante_id->setLabel('Marca / Fabricante')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addMultiOption('','-- Seleccionar --')
               ->addMultiOptions(Default_Model_Fabricante::getPairsToSelect());

        $almacen_id = new Zend_Form_Element_Select('almacen_id');
        $almacen_id->setLabel('Almacén')
                   ->setRequired(true)
                   ->addMultiOption('', '-- Seleccionar --')
                   ->addMultiOptions(Default_Model_Almacen::getPairsToSelect());

        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre del artículo')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim');

        $sector_almacenaje = new Zend_Form_Element_Text('sector_almacenaje');
        $sector_almacenaje->setLabel('Sector de almacenaje en la bodega')
                          ->setRequired(false)
                          ->addFilter('StripTags')
                          ->addFilter('StringTrim');

        $descripcion = new Zend_Form_Element_Textarea('descripcion');
        $descripcion->setLabel('Descripción')
                    ->setRequired(false)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim');

        
        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Crear artículo')
               ->setAttrib('class','articulo')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setDecorators(array('ViewHelper'));
        
        $this->addElements(
            array(
                $codigo_proveedor, $categoria_id,
                $fabricante_id, $envase_id, $nombre,
                $descripcion, $almacen_id, $submit,
                $cancel, $back, $sector_almacenaje,
                $categoria, $id
            ));


        $this->addDisplayGroup(
            array(
                'codigo_proveedor', 'categoria', 
                'categoria_id', 'nombre',
                'fabricante_id', 'envase_id'
            ),
            'infoInputs2'
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );
            
        $this->addDisplayGroup(
            array(
                'almacen_id', 'sector_almacenaje', 'descripcion'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left-ancho'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel','back', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'articulo',
                'action'    => $path . '/new'
            ));
    } 
} 
