<?php
class Default_Form_Cliente extends Zend_Form 
{ 
    public function __construct($options = null, $path = null, $history = '/cliente')
    {
        parent::__construct($options);

        $validador_rut = new App_Validate_ValidRut();

        $back = new Zend_Form_Element_Hidden('back');
        $back->setValue($history)
             ->setDecorators(array('ViewHelper'));

        $id = new Zend_Form_Element_Hidden('id');
        $id->addFilter('StripTags')
           ->addFilter('StringTrim')
           ->addValidator($validador_rut);

        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim');

        $rut = new Zend_Form_Element_Text('rut');
        $rut->setLabel('R.U.T.')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->addValidator($validador_rut)
              ->setAttrib('class', 'tooltip')
              ->setDescription('Formato : 12345678-9');
             
        $direccion = new Zend_Form_Element_Text('direccion');
        $direccion->setLabel('Dirección')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim'); 
         
        $comuna = new Zend_Form_Element_Text('comuna');
        $comuna->setLabel('Comuna')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim');
        
        $ciudad = new Zend_Form_Element_Text('ciudad');
        $ciudad->setLabel('Ciudad')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim');

        $telefono = new Zend_Form_Element_Text('telefono');
        $telefono->setLabel('Teléfono')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim'); 

        $mail = new Zend_Form_Element_Text('mail');
        $mail->setLabel('Email')
              ->setRequired(false)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->addValidator('EmailAddress');
            
        $web = new Zend_Form_Element_Text('web');
        $web->setLabel('Sitio Web')
            ->setRequired(false)
            ->addFilter('StripTags')
            ->addFilter('StringTrim');

        $copiar = new Zend_Form_Element_Checkbox('copiar');
        $copiar->setLabel('¿Desea usar los mismos datos del cliente?');

        $nombre_web = new Zend_Form_Element_Text('nombre_web');
        $nombre_web->setLabel('Nombre')
               ->setRequired(false)
               ->addFilter('StripTags')
               ->addFilter('StringTrim');

        $telefono_web = new Zend_Form_Element_Text('telefono_web');
        $telefono_web->setLabel('Teléfono')
              ->setRequired(false)
              ->addFilter('StripTags')
              ->addFilter('StringTrim');

        $mail_web = new Zend_Form_Element_Text('mail_web');
        $mail_web->setLabel('Email')
              ->setRequired(false)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->addValidator('EmailAddress')
              ->setAttrib('class', 'tooltip')
              ->setDescription('Indispensable para el acceso web al historial del vehículo');

        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Crear cliente')
               ->setAttrib('class','cliente')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setDecorators(array('ViewHelper'));

        $this->addElements(
            array(
                $nombre, $rut, $direccion,
                $comuna, $ciudad, $telefono,
                $mail, $web, $submit, $cancel,
                $back, $id, $nombre_web, $telefono_web,
                $mail_web, $copiar
            ));

        $this->addDisplayGroup(
            array(
                'nombre', 'rut', 'direccion', 'comuna', 'ciudad', 'telefono', 'mail', 'web'
            ),
            'infoInputs',
            array('legend' => 'Información requerida')
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array(
                'copiar', 'nombre_web', 'telefono_web', 'mail_web'
            ),
            'optionalInputs',
            array('legend' => 'Acceso usuario vía web')
        );

        $optionalInputs = $this->getDisplayGroup('optionalInputs');
        $optionalInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel','back', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'cliente',
                'action'    => $path . '/new'
            ));

    } 
} 
