<?php
class Default_Form_ContratoEmpleado extends Zend_Form
{ 
    public function __construct($options = null, $path = null)
    { 
        parent::__construct($options);

        $validador_rut = new App_Validate_ValidRut();
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');

        $empleado = new Zend_Form_Element_Text('empleado');
        $empleado->setLabel('R.U.T. Empleado')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->addValidator($validador_rut);

        $cargo = new Zend_Form_Element_Text('cargo');
        $cargo->setLabel('Cargo')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim');

        $tipo_contrato = new Zend_Form_Element_Select('tipo_contrato');
        $tipo_contrato->setLabel('Tipo de contrato')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->addMultiOption('','-- Seleccionar --')
              ->addMultiOption('INDEFINIDO','INDEFINIDO')
              ->addMultiOption('PLAZO FIJO','PLAZO FIJO')
              ->addMultiOption('PROYECTO','PROYECTO');

        $fecha_i = new Zend_Form_Element_Text('fecha_i');
        $fecha_i->setLabel('Fecha de inicio')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->addValidator('Date');

        $fecha_t = new Zend_Form_Element_Text('fecha_t');
        $fecha_t->setLabel('Fecha de término')
                ->setRequired(false)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addValidator('Date');

        $bono_produccion = new Zend_Form_Element_Radio('bono_produccion');
        $bono_produccion->setLabel('Bono producción')
                        ->setRequired(true)
                        ->addMultiOption('SI','SI')
                        ->addMultiOption('NO','NO');

        $comision_ventas = new Zend_Form_Element_Radio('comision_ventas');
        $comision_ventas->setLabel('Comisión de ventas')
                        ->setRequired(true)
                        ->addMultiOption('SI','SI')
                        ->addMultiOption('NO','NO');

        $observaciones = new Zend_Form_Element_Textarea('observaciones');
        $observaciones->setLabel('Observaciones')
              ->setRequired(false)
              ->addFilter('StripTags')
              ->addFilter('StringTrim');

        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Continuar');
        $submit->setAttribs(array('class' => 'ui-button ui-state-default submit-inputs ui-corner-all'));
        
        $this->addElements(
            array(
                $id, $empleado, $cargo, $tipo_contrato,
                $fecha_i, $fecha_t, $observaciones, $bono_produccion,
                $comision_ventas, $submit
            ));

        $this->addDisplayGroup(
            array('id'),'hiddenInputs'
        );

        $hiddenInputs = $this->getDisplayGroup('hiddenInputs');
        $hiddenInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-hidden'))
            )
        );

        $this->addDisplayGroup(
            array(
                'empleado', 'cargo', 'tipo_contrato',
                'fecha_i', 'fecha_t', 'submit'
            ),
            'infoInputs',
            array('legend' => 'Información básica del contrato')
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            ));

        $this->addDisplayGroup(
            array(
                'bono_produccion', 'comision_ventas'
            ),
            'bonosVariables',
            array('legend' => 'Bonos variables')
        );

        $bonosVariables = $this->getDisplayGroup('bonosVariables');
        $bonosVariables->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-small'))
            ));



        $this->addDisplayGroup(
            array('observaciones'),'obs'
        );

        $obs = $this->getDisplayGroup('obs');
        $obs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left2'))
            )
        );

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido',
                'name'      => 'contrato-empleado',
                'action'    => $path . '/new'
            ));

    } 
} 
