<?php
class Default_Form_Cotizacion extends Zend_Form
{ 
    public function __construct($options = null, $path = null, $history = '/cotizacion')
    { 
        parent::__construct($options);

        $validadorRut = new App_Validate_ValidRut();

        $optionsRecepcion = array('table' => 'recepciones_vehiculos', 'field' => 'id');
        $validadorRecepcion = new Zend_Validate_Db_RecordExists($optionsRecepcion);

        $descripcionRecepcionId = 'Por favor ingrese el Nº de recepción si '
                                . 'es que corresponde. De lo contrario dejar en blanco';

        $buscador = new Zend_Form_Element_Text('buscador');
        $buscador->setLabel('Buscar cliente')
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->setRequired(false)
                 ->setAttrib('onkeypress', 'ajaxSearchCliente($(this), "#cliente")');

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));

        $back = new Zend_Form_Element_Hidden('back');
        $back->setValue($history)
             ->setDecorators(array('ViewHelper'));

        $cliente = new Zend_Form_Element_Text('cliente');
        $cliente->setLabel('R.U.T. Cliente')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addValidator($validadorRut);

        $fecha = new Zend_Form_Element_Text('fecha');
        $fecha->setLabel('Fecha emisión')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addValidator('Date')
               ->setAttrib('class', 'show-calendar');

        $validez = new Zend_Form_Element_Text('validez');
        $validez->setLabel('Validez (días)')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addValidator('Int');

        $atencion_a = new Zend_Form_Element_Text('atencion_a');
        $atencion_a->setLabel('Atención a')
                   ->setRequired(true)
                   ->addFilter('StripTags')
                   ->addFilter('StringTrim');

        $recepcion_id = new Zend_Form_Element_Text('recepcion_id');
        $recepcion_id->setLabel('Nº Recepción')
                   ->setRequired(false)
                   ->addFilter('StripTags')
                   ->addFilter('StringTrim')
                   ->addValidator($validadorRecepcion)
                   ->setDescription($descripcionRecepcionId)
                   ->setAttrib("class", "tooltip");

        $emitida_por = new Zend_Form_Element_Text('emitida_por');
        $emitida_por->setLabel('Emitida por')
                    ->setRequired(true)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim');

        $autoriza_ext_presupuesto = new Zend_Form_Element_Radio('autoriza_ext_presupuesto');
        $autoriza_ext_presupuesto->setLabel('¿Autoriza la extensión de presupuesto?')
                                 ->setRequired(true)
                                 ->addMultiOption('SI', 'SI')
                                 ->addMultiOption('NO', 'NO');

        $tope_ext_presupuesto = new Zend_Form_Element_Text('tope_ext_presupuesto');
        $tope_ext_presupuesto->setLabel('Tope de la extensión de presupuesto')
                             ->setRequired(false)
                             ->addFilter('StripTags')
                             ->addFilter('StringTrim');

        $aviso_ext_presupuesto = new Zend_Form_Element_Text('aviso_ext_presupuesto');
        $aviso_ext_presupuesto->setLabel('Avisar al número/mail')
                              ->setRequired(false)
                              ->addFilter('StripTags')
                              ->addFilter('StringTrim');

        $observaciones = new Zend_Form_Element_Textarea('observaciones');
        $observaciones->setLabel('Observaciones')
                      ->addFilter('StripTags')
                      ->addFilter('StringTrim')
                      ->setAttrib('style', 'height:113px;');
            

        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Crear cotización')
               ->setAttrib('class','cotizacion')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setDecorators(array('ViewHelper'));
        
        $this->addElements(
            array(
                $cliente, $fecha, $validez,
                $atencion_a, $emitida_por,
                $observaciones,
                $submit, $cancel, $back, $id,
                $recepcion_id, $autoriza_ext_presupuesto,
                $tope_ext_presupuesto, $aviso_ext_presupuesto,
                $buscador
            ));

        $this->addDisplayGroup(
            array(
                'buscador'
            ),
            'busquedaInputs'
        );

        $busquedaInputs = $this->getDisplayGroup('busquedaInputs');
        $busquedaInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-busqueda'))
            ));

        $this->addDisplayGroup(
            array(
                'cliente','fecha', 'validez',
                'atencion_a', 'emitida_por',
                'recepcion_id'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            ));


        $this->addDisplayGroup(array(
            'autoriza_ext_presupuesto',
            'tope_ext_presupuesto',
            'aviso_ext_presupuesto',
            'observaciones'
            ),'extension'
        );

        $extension = $this->getDisplayGroup('extension');
        $extension->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel','back','id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'cotizacion',
                'action'    => $path . '/new'
            ));

    } 
} 
