<?php
class Default_Form_DteFactura extends Zend_Form
{ 
    public function __construct($options = null, $path = null, $history = '/dte-factura')
    { 
        parent::__construct($options);

        $optionsFactura = array('table' => 'dte_facturas', 'field' => 'numero');
        $validadorNumero = new Zend_Validate_Db_NoRecordExists($optionsFactura);

        $optionsNota = array('table' => 'notas_ventas', 'field' => 'id');
        $validadorNota = new Zend_Validate_Db_RecordExists($optionsNota);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));

        $back = new Zend_Form_Element_Hidden('back');
        $back->setValue($history)
             ->setDecorators(array('ViewHelper'));

        $numero = new Zend_Form_Element_Text('numero');
        $numero->setLabel('Nº factura')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addValidator('Int');

        $nota_id = new Zend_Form_Element_Text('nota_id');
        $nota_id->setLabel('Nº Nota de venta')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addValidator($validadorNota);

        $fecha = new Zend_Form_Element_Text('fecha');
        $fecha->setLabel('Fecha emisión')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addValidator('Date')
                ->setAttrib('class', 'show-calendar')
                ->setValue(date("Y-m-d"));

        $forma_pago = new Zend_Form_Element_Select('forma_pago');
        $forma_pago->setLabel('Forma de pago')
                   ->setRequired(true)
                   ->addMultiOption('','-- Seleccionar --')
                   ->addMultiOptions(Default_Model_FormaPago::getPairsToSelect());

        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Crear factura')
               ->setAttrib('class','boleta')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setDecorators(array('ViewHelper'));
        
        $this->addElements(
            array(
                $submit, $cancel, $back, $id,
                $nota_id, $forma_pago, $numero,
                $fecha
            ));

        $this->addDisplayGroup(
            array(
                'nota_id', 'numero', 'fecha', 'forma_pago'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            ));

        $this->addDisplayGroup(
            array('submit', 'cancel','back','id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'dte-factura',
                'action'    => $path . '/new'
            ));

    } 
} 
