<?php
class Default_Form_Empleado extends Zend_Form
{ 
    public function __construct($options = null, $path = null, $history = '/empleado')
    { 
        parent::__construct($options);

        $validador_rut = new App_Validate_ValidRut();

        $opciones_accion = array(
            '1' => 'Ingresar contrato de trabajo',
            '2' => 'Ingresar un nuevo empleado',
            '3' => 'Ir al listado de empleados'
        );
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));

        $back = new Zend_Form_Element_Hidden('back');
        $back->setValue($history)
             ->setDecorators(array('ViewHelper'));

        $rut = new Zend_Form_Element_Text('rut');
        $rut->setLabel('R.U.T.')
            ->setRequired(true)
            ->addFilter('StripTags')
            ->addFilter('StringTrim')
            ->addValidator($validador_rut);

        $nombres = new Zend_Form_Element_Text('nombres');
        $nombres->setLabel('Nombres')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim');

        $apellidos = new Zend_Form_Element_Text('apellidos');
        $apellidos->setLabel('Apellidos')
                  ->setRequired(true)
                  ->addFilter('StripTags')
                  ->addFilter('StringTrim');

        $telefono = new Zend_Form_Element_Text('telefono');
        $telefono->setLabel('Teléfono')
                 ->setRequired(false)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim');

        $movil = new Zend_Form_Element_Text('movil');
        $movil->setLabel('Tel. Móvil')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim');

        $direccion = new Zend_Form_Element_Text('direccion');
        $direccion->setLabel('Dirección')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim');
        
        $ciudad = new Zend_Form_Element_Text('ciudad');
        $ciudad->setLabel('Ciudad')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim');

            
        $mail = new Zend_Form_Element_Text('mail');
        $mail->setLabel('Email')
            ->setRequired(false)
            ->addFilter('StripTags')
            ->addFilter('StringTrim')
            ->addValidator('EmailAddress');

        $accion = new Zend_Form_Element_Radio('accion');
        $accion->setLabel('¿Que desea hacer a continuación?')
                 ->setRequired(true)
                 ->addMultiOptions($opciones_accion)
                 ->setValue('2');
            
        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Agregar empleado')
               ->setAttrib('class','empleado')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setDecorators(array('ViewHelper'));
        
        $this->addElements(
            array(
                $id, $rut, $nombres, $apellidos,
                $telefono, $movil, $direccion,
                $ciudad, $mail, $submit, $accion,
                $cancel
            ));

        $this->addDisplayGroup(
            array(
                'rut','nombres', 'apellidos',
                'movil', 'ciudad'
            ),
            'requiredInputs',
            array('legend' => 'Ingrese toda la información requerida')
        );

        $requiredInputs = $this->getDisplayGroup('requiredInputs');
        $requiredInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            ));

        $this->addDisplayGroup(
            array(
                'direccion', 'telefono','mail', 'accion'
            ),
            'notRequiredInputs'
        );

        $notRequiredInputs = $this->getDisplayGroup('notRequiredInputs');
        $notRequiredInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left2'))
            ));

        $this->addDisplayGroup(
            array('submit', 'cancel','back', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido',
                'name'      => 'empleado',
                'action'    => $path . '/new'
            ));

    } 
} 
