<?php
class Default_Form_IngresoArticulo extends Zend_Form
{ 
    public function __construct($options = null, $path = null, $history = '/ingreso-articulo')
    { 
        parent::__construct($options);

        $validador_codigo = new Zend_Validate_Db_RecordExists(
            array(
                'table' => 'articulos',
                'field' => 'codigo'
            )
        );

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));

        $buscador = new Zend_Form_Element_Text('buscador');
        $buscador->setLabel('Buscar código artículo')
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->setRequired(false)
                 ->setAttrib('onkeypress', 'ajaxSearchArticulo($(this), "#articulo")');

        $back = new Zend_Form_Element_Hidden('back');
        $back->setValue($history)
             ->setDecorators(array('ViewHelper'));

        $tipo_ingreso_id = new Zend_Form_Element_Select('tipo_ingreso_id');
        $tipo_ingreso_id->setLabel('Tipo ingreso')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addMultiOption('','-- Seleccionar --')
               ->addMultiOptions(Default_Model_TipoIngresoArticulo::getPairsToSelect());

        $articulo = new Zend_Form_Element_Text('articulo');
        $articulo->setLabel('Código artículo')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addValidator($validador_codigo);
       
        $cantidad = new Zend_Form_Element_Text('cantidad');
        $cantidad->setLabel('Cantidad a ingresar')
                     ->setRequired(true)
                     ->addFilter('StripTags')
                     ->addFilter('StringTrim')
                     ->addValidator('Int')
                     ->setAttrib('class', 'tooltip')
                     ->setDescription('Sólo números enteros');

        $observaciones = new Zend_Form_Element_Textarea('observaciones');
        $observaciones->setLabel('Observaciones')
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim');

        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Ingresar stock')
               ->setAttrib('class','ingreso-articulo')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setDecorators(array('ViewHelper'));
        
        $this->addElements(
            array(
                $tipo_ingreso_id, $articulo, $cantidad,
                $observaciones, $submit, $cancel,
                $back, $buscador, $id
            ));

        $this->addDisplayGroup(
            array(
                'buscador'
            ),
            'busquedaInputs'
        );

        $busquedaInputs = $this->getDisplayGroup('busquedaInputs');
        $busquedaInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-busqueda'))
            ));

        $this->addDisplayGroup(
            array(
                'articulo', 'cantidad', 'tipo_ingreso_id', 'observaciones'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel','back', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'egreso-articulo',
                'action'    => $path . '/new'
            ));

    } 
} 
