<?php
class Default_Form_ItemCotizacion extends Zend_Form
{
    public function __construct($table, $options = null)
    {
        parent::__construct($options);

        $validadorCodigo = new Zend_Validate_Db_RecordExists(array(
            'table' => $table,
            'field' => 'codigo'
        ));

        $validadorVehiculo = new Zend_Validate_Db_RecordExists(array(
            'table' => 'vehiculos',
            'field' => 'patente'
        ));

        $validadorFloat = new App_Validate_Float();

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));

        $cotizacion_id = new Zend_Form_Element_Hidden('cotizacion_id');
        $cotizacion_id->addValidator('Int')
                      ->setDecorators(array('ViewHelper'));

        $buscador = new Zend_Form_Element_Text('buscador');
        $buscador->setRequired(false);

        $codigo = new Zend_Form_Element_Text('codigo');
        $codigo->setLabel('Código')
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->setRequired(true)
               ->addValidator($validadorCodigo);

        $vehiculo = new Zend_Form_Element_Text('vehiculo');
        $vehiculo->setLabel('Patente Vehículo')
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->setRequired(false)
               ->addValidator($validadorVehiculo);

        $valor_neto = new Zend_Form_Element_Text('valor_neto');
        $valor_neto->setLabel('Valor unitario neto')
                   ->setRequired(true)
                   ->addFilter('StripTags')
                   ->addFilter('StringTrim')
                   ->addValidator('Int');

        $tipo_descuento = new Zend_Form_Element_Radio('tipo_descuento');
        $tipo_descuento->setLabel('Tipo descuento')
                       ->setRequired(true)
                       ->addMultiOption('PORCENTAJE', '% porcentaje')
                       ->addMultiOption('MONTO', '$ monto')
                       ->setValue('MONTO');

        $descuento = new Zend_Form_Element_Text('descuento');
        $descuento->setLabel('Valor descuento')
                   ->setRequired(true)
                   ->addFilter('StripTags')
                   ->addFilter('StringTrim')
                   ->setValue(0);

        $cantidad = new Zend_Form_Element_Text('cantidad');
        $cantidad->setLabel('Cantidad')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addValidator($validadorFloat);

        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim');

        $unidad_medida = new Zend_Form_Element_Select('unidad_medida');
        $unidad_medida->setLabel('Unidad de medida')
                      ->setRequired(true)
                      ->addFilter('StripTags')
                      ->addFilter('StringTrim')
                      ->addMultiOption('', '-- Seleccionar --')
                      ->addMultiOptions(Default_Model_UnidadMedida::getPairsToSelectBasic());

        $descripcion = new Zend_Form_Element_Textarea('descripcion');
        $descripcion->setLabel('Descripción')
                    ->setRequired(true)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim')
                    ->setAttrib('style', 'width:400px;height:77px;');

        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Agregar a la cotización')
               ->setDecorators(array('ViewHelper'));

        $this->addElements(
            array(
                $id, $cotizacion_id, $codigo, $cantidad,
                $descripcion, $submit, $buscador, $valor_neto,
                $nombre, $unidad_medida, $descuento,
                $tipo_descuento, $vehiculo
            ));

        $this->addDisplayGroup(
            array(
                'buscador'
            ),
            'busquedaInputs'
        );

        $busquedaInputs = $this->getDisplayGroup('busquedaInputs');
        $busquedaInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-busqueda'))
            ));

        $this->addDisplayGroup(
            array(
                'vehiculo', 'cantidad', 'valor_neto', 'tipo_descuento', 'descuento'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            ));

        $this->addDisplayGroup(
            array(
                'unidad_medida', 'codigo', 'nombre', 'descripcion'
            ),
            'infoInputs2'
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'id', 'cotizacion_id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'item',
                'action'    => "/item-cotizacion/new/0/$table/0"
            ));
    }
}
