<?php
class Default_Form_ItemSolicitudCompraRepuesto extends Zend_Form
{
    public function __construct($options = null)
    {
        parent::__construct($options);

        $validadorFloat = new App_Validate_Float();

        $optionsSolicitud = array('table' => 'solicitudes_compras_repuestos', 'field' => 'id');
        $validadorSolicitud = new Zend_Validate_Db_RecordExists($optionsSolicitud);

        $descripcionNombre = 'Ingrese el nombre del repuesto a comprar. Por'
                           . ' ejemplo: "Filtro de aire" o "Correa distribución"'
                           . ' y las características en el cuadro de "Descripción'
                           . ' actual" ';

        $descripcionCantidad = 'Se aceptan números enteros y decimales (separados por un punto), por ejemplo 1.5';

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));

        $solicitud_id = new Zend_Form_Element_Hidden('solicitud_id');
        $solicitud_id->addValidator('Int')
                     ->addValidator($validadorSolicitud)
                     ->setDecorators(array('ViewHelper'));

        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->setRequired(true)
               ->setAttrib('class', 'tooltip')
               ->setDescription($descripcionNombre);

        $cantidad = new Zend_Form_Element_Text('cantidad');
        $cantidad->setLabel('Cantidad')
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addValidator($validadorFloat)
                 ->setRequired(true)
                 ->setAttrib('class', 'tooltip')
                 ->setDescription($descripcionCantidad);

        $actual_codigo = new Zend_Form_Element_Text('actual_codigo');
        $actual_codigo->setLabel('Código actual')
                      ->setRequired(false)
                      ->addFilter('StripTags')
                      ->addFilter('StringTrim');

        $actual_marca = new Zend_Form_Element_Text('actual_marca');
        $actual_marca->setLabel('Marca actual')
                     ->setRequired(false)
                     ->addFilter('StripTags')
                     ->addFilter('StringTrim');

        $actual_descripcion = new Zend_Form_Element_Textarea('actual_descripcion');
        $actual_descripcion->setLabel('Descripción actual')
                           ->setRequired(false)
                           ->addFilter('StripTags')
                           ->addFilter('StringTrim')
                           ->setAttrib('style', 'height:77px;');

        $nuevo_codigo = new Zend_Form_Element_Text('nuevo_codigo');
        $nuevo_codigo->setLabel('Código nuevo')
                     ->setRequired(false)
                     ->addFilter('StripTags')
                     ->addFilter('StringTrim');

        $nuevo_marca = new Zend_Form_Element_Text('nuevo_marca');
        $nuevo_marca->setLabel('Marca nuevo')
                    ->setRequired(false)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim');

        $nuevo_descripcion = new Zend_Form_Element_Textarea('nuevo_descripcion');
        $nuevo_descripcion->setLabel('Descripción nuevo')
                          ->setRequired(false)
                          ->addFilter('StripTags')
                          ->addFilter('StringTrim')
                          ->setAttrib('style', 'height:77px;');

        $muestra = new Zend_Form_Element_Radio('muestra');
        $muestra->setLabel('Se adjunta muestra')
                ->setRequired(true)
                ->addMultiOption('SI', 'SI')
                ->addMultiOption('NO', 'NO');

        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Agregar a la solicitud de compra')
               ->setDecorators(array('ViewHelper'));

        $this->addElements(
            array(
                $id, $solicitud_id, $nombre, $cantidad,
                $actual_codigo, $actual_marca, $actual_descripcion,
                $nuevo_codigo, $nuevo_marca, $nuevo_descripcion,
                $muestra, $submit
            ));

        $this->addDisplayGroup(
            array(
                'nombre', 'cantidad', 'muestra'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            ));

        

        $this->addDisplayGroup(
            array(
                'actual_codigo', 'actual_marca', 'actual_descripcion'
            ),
            'infoInputs1'
        );

        $infoInputs1 = $this->getDisplayGroup('infoInputs1');
        $infoInputs1->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            ));

        $this->addDisplayGroup(
            array(
                'nuevo_codigo', 'nuevo_marca', 'nuevo_descripcion'
            ),
            'infoInputs2'
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'id', 'solicitud_id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'item',
                'action'    => "/item-solicitud-compra-repuesto/new"
            ));
    }
}
