<?php
class Default_Form_ModeloVehiculoModal extends Zend_Form
{
    public function __construct($options = null)
    { 
        parent::__construct($options);

        $validadorFloat = new App_Validate_Float();

        $descripcionYears = 'Si el modelo sigue en fabricación, coloque el año actual. Por ej.: 2005-2011';
        $descripcionCilindrada = 'Utilice un formato abreviado, por ejemplo : 1.6 o 2.5';

        $marca_id = new Zend_Form_Element_Select('marca_id');
        $marca_id->setLabel('Marca')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addMultiOption('','-- Seleccionar --')
               ->addMultiOptions(Default_Model_MarcaVehiculo::getPairsToSelect());
              
        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre modelo')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim');

        $version = new Zend_Form_Element_Text('version');
        $version->setLabel('Versión')
                ->setRequired(false)
                ->addFilter('StripTags')
                ->addFilter('StringTrim');

        $cilindrada = new Zend_Form_Element_Text('cilindrada');
        $cilindrada->setLabel('Cilindrada')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->setAttrib('class', 'tooltip')
                ->setDescription($descripcionCilindrada);

        $years = new Zend_Form_Element_Text('years');
        $years->setLabel('Años durante los que se fabricó')
               ->setRequired(false)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->setAttrib('class', 'tooltip')
               ->setDescription($descripcionYears);

        $tipo_combustible = new Zend_Form_Element_Select('tipo_combustible');
        $tipo_combustible->setLabel('Tipo combustible')
                         ->setRequired(true)
                         ->addFilter('StripTags')
                         ->addFilter('StringTrim')
                         ->addMultiOption('','-- Seleccionar --')
                         ->addMultiOption('GASOLINA','GASOLINA')
                         ->addMultiOption('DIESEL','DIESEL')
                         ->addMultiOption('ETANOL','ETANOL')
                         ->addMultiOption('ALCOHOL','ALCOHOL');

        $traccion = new Zend_Form_Element_Select('traccion');
        $traccion->setLabel('Tracción')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addMultiOption('','-- Seleccionar --')
                 ->addMultiOption('4x2','4x2')
                 ->addMultiOption('4x4','4x4');

        $cargo_adicional = new Zend_Form_Element_Text('cargo_adicional');
        $cargo_adicional->setLabel('Cargo adicional por dificultad %')
              ->setRequired(true)
              ->setValue(0)
              ->addValidator($validadorFloat);

        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Agregar modelo de vehículo')
               ->setAttrib('class','modelo-vehiculo')
               ->setDecorators(array('ViewHelper'));

        $this->addElements(
            array(
                $marca_id, $nombre, $version, 
                $years, $tipo_combustible, $traccion,
                $cilindrada, $cargo_adicional,
                $submit));

        $this->addDisplayGroup(
            array(
                'marca_id', 'nombre', 'version', 'cilindrada', 'years'
            ),
            'infoInputs'
        );


        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array(
                'tipo_combustible', 'traccion', 'cargo_adicional'
            ),
            'infoInputs2'
        );


        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array('submit'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido-modal ajax',
                'name'      => 'modelo-vehiculo-modal',
                'action'    => '/modelo-vehiculo/new-modal'
            ));
    } 
} 
