<?php
class Default_Form_NotaVenta extends Zend_Form
{ 
    public function __construct($options = null, $path = null, $history = '/ventas/index')
    { 
        parent::__construct($options);

        $validadorRut = new App_Validate_ValidRut();

        $optionsRecepcion = array('table' => 'recepciones_vehiculos', 'field' => 'id');
        $validadorRecepcion = new Zend_Validate_Db_RecordExists($optionsRecepcion);

        $descripcionRecepcionId = 'Por favor ingrese el Nº de recepción si '
                                . 'es que corresponde. De lo contrario dejar en blanco';

        $buscador = new Zend_Form_Element_Text('buscador');
        $buscador->setLabel('Buscar cliente')
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->setRequired(false)
                 ->setAttrib('onkeypress', 'ajaxSearchCliente($(this), "#cliente")');
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));

        $back = new Zend_Form_Element_Hidden('back');
        $back->setValue($history)
             ->setDecorators(array('ViewHelper'));

        $cliente = new Zend_Form_Element_Text('cliente');
        $cliente->setLabel('R.U.T. Cliente')
            ->setRequired(true)
            ->addFilter('StripTags')
            ->addFilter('StringTrim')
            ->addValidator($validadorRut);

        $recepcion_id = new Zend_Form_Element_Text('recepcion_id');
        $recepcion_id->setLabel('Nº Recepción')
                   ->setRequired(false)
                   ->addFilter('StripTags')
                   ->addFilter('StringTrim')
                   ->addValidator($validadorRecepcion)
                   ->setDescription($descripcionRecepcionId)
                   ->setAttrib("class", "tooltip");

        $observaciones = new Zend_Form_Element_Textarea('observaciones');
        $observaciones->setLabel('Observaciones')
                      ->setRequired(false)
                      ->addFilter('StripTags')
                      ->addFilter('StringTrim');
            
        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Crear nota de venta')
               ->setAttrib('class','nota-venta')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setDecorators(array('ViewHelper'));
        
        $this->addElements(
            array(
                $id, $cliente, $observaciones,
                $submit, $cancel, $back,
                $buscador, $recepcion_id
            ));

        $this->addDisplayGroup(
            array(
                'buscador'
            ),
            'busquedaInputs'
        );

        $busquedaInputs = $this->getDisplayGroup('busquedaInputs');
        $busquedaInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-busqueda'))
            ));

        $this->addDisplayGroup(
            array(
                'cliente', 'recepcion_id', 'observaciones'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel','back', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'nota-venta',
                'action'    => $path . '/new'
            ));
    } 
} 
