<?php
class Default_Form_OrdenCompra extends Zend_Form
{ 
    public function __construct($options = null, $path = null, $history = '/status/compras')
    { 
        parent::__construct($options);

        $buscador = new Zend_Form_Element_Text('buscador');
        $buscador->setLabel('Buscar proveedor')
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->setRequired(false)
                 ->setAttrib('onkeypress', 'ajaxSearchProveedor($(this), "#proveedor")');

        $validador_rut = new App_Validate_ValidRut();
        $validadorFloat = new App_Validate_Float();

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));

        $back = new Zend_Form_Element_Hidden('back');
        $back->setValue($history)
             ->setDecorators(array('ViewHelper'));
        
        $proveedor = new Zend_Form_Element_Text('proveedor');
        $proveedor->setLabel('R.U.T. Proveedor')
            ->setRequired(true)
            ->addFilter('StripTags')
            ->addFilter('StringTrim')
            ->addValidator($validador_rut);

        $fecha = new Zend_Form_Element_Text('fecha');
        $fecha->setLabel('Fecha emisión')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addValidator('Date')
               ->setAttrib('class', 'show-calendar');

        $validez = new Zend_Form_Element_Text('validez');
        $validez->setLabel('Validez (días)')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addValidator('Int');

        $proveedor_paga_flete = new Zend_Form_Element_Checkbox('proveedor_paga_flete');
        $proveedor_paga_flete->setLabel('Proveedor paga flete')
                             ->setRequired(true)
                             ->addFilter('StripTags')
                             ->addFilter('StringTrim')
                             ->setCheckedValue('SI')
                             ->setUncheckedValue('NO');

        $atencion_a = new Zend_Form_Element_Text('atencion_a');
        $atencion_a->setLabel('Atención a')
            ->setRequired(true)
            ->addFilter('StripTags')
            ->addFilter('StringTrim');

        $descuento_global = new Zend_Form_Element_Text('descuento_global');
        $descuento_global->setLabel('% Descuento global orden')
                         ->setRequired(true)
                         ->addFilter('StripTags')
                         ->addFilter('StringTrim')
                         ->addValidator($validadorFloat)
                         ->setValue(0);

        $emitida_por = new Zend_Form_Element_Text('emitida_por');
        $emitida_por->setLabel('Emitida por')
            ->setRequired(true)
            ->addFilter('StripTags')
            ->addFilter('StringTrim');

        $condiciones_pago = new Zend_Form_Element_Text('condiciones_pago');
        $condiciones_pago->setLabel('Condiciones de pago (días)')
                         ->setRequired(true)
                         ->addFilter('StripTags')
                         ->addFilter('StringTrim');

        $referencia = new Zend_Form_Element_Text('referencia');
        $referencia->setLabel('Doc. referencia')
            ->addFilter('StripTags')
            ->addFilter('StringTrim');

        $observaciones = new Zend_Form_Element_Textarea('observaciones');
        $observaciones->setLabel('Observaciones')
            ->addFilter('StripTags')
            ->addFilter('StringTrim');
            

        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Crear orden de compra')
               ->setAttrib('class','orden-compra')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setDecorators(array('ViewHelper'));
        
        $this->addElements(
            array(
                $id, $proveedor, $fecha, $validez,
                $atencion_a, $emitida_por,
                $condiciones_pago, $referencia,
                $observaciones, $submit, $cancel,
                $back, $buscador, $proveedor_paga_flete,
                $descuento_global
            ));

        $this->addDisplayGroup(
            array(
                'buscador'
            ),
            'busquedaInputs'
        );

        $busquedaInputs = $this->getDisplayGroup('busquedaInputs');
        $busquedaInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-busqueda'))
            ));

        $this->addDisplayGroup(
            array(
                'proveedor', 'fecha', 'validez',
                'atencion_a', 'emitida_por',
                'condiciones_pago'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array(
                'descuento_global', 'proveedor_paga_flete', 'referencia', 'observaciones'
            ),
            'infoInputs2'
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left-ancho'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel','back', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'orden-compra',
                'action'    => $path . '/new'
            ));
    } 
} 
