<?php
class Default_Form_Reserva extends Zend_Form
{ 
    public function __construct($options = null, $path = null, $history = '/reserva')
    { 
        parent::__construct($options);

        $validadorRut = new App_Validate_ValidRut();

        $optionsVehiculo = array('table' => 'vehiculos', 'field' => 'patente');
        $validadorVehiculo = new Zend_Validate_Db_RecordExists($optionsVehiculo);

        $buscador = new Zend_Form_Element_Text('buscador');
        $buscador->setLabel('Buscar cliente')
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->setRequired(false)
                 ->setAttrib('onkeypress', 'ajaxSearchCliente($(this), "#cliente")');

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));

        $back = new Zend_Form_Element_Hidden('back');
        $back->setValue($history)
             ->setDecorators(array('ViewHelper'));

        $cliente = new Zend_Form_Element_Text('cliente');
        $cliente->setLabel('R.U.T. Cliente')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addValidator($validadorRut);

        $vehiculo = new Zend_Form_Element_Text('vehiculo');
        $vehiculo->setLabel('Patente Vehículo')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addValidator($validadorVehiculo)
                ->setAttrib('class', 'tooltip')
                ->setDescription('El vehículo y el cliente deben estar previamente registrados');

        $fecha = new Zend_Form_Element_Text('fecha');
        $fecha->setLabel('Fecha')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addValidator('Date')
               ->setAttrib('class', 'show-calendar');

        $hora = new Zend_Form_Element_Select('hora');
        $hora->setLabel('Hora')
            ->setRequired(true)
            ->addFilter('StripTags')
            ->addFilter('StringTrim')
            ->addMultiOption('','--Seleccionar')
            ->addMultiOptions(array(
                '08:00:00'  => '08:00',
                '09:00:00'  => '09:00',
                '10:00:00'  => '10:00',
                '11:00:00'  => '11:00',
                '12:00:00'  => '12:00',
                '15:00:00'  => '15:00',
                '16:00:00'  => '16:00',
                '17:00:00'  => '17:00',
                '18:00:00'  => '18:00'))
            ->setAttrib('class', 'tooltip')
            ->setDescription('Hora de llegada del cliente');

        $comentarios = new Zend_Form_Element_Textarea('comentarios');
        $comentarios->setLabel('Comentarios / Observaciones')
                    ->setRequired(true)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim')
                    ->setAttrib('class', 'tooltip')
                    ->setDescription('Ingrese una pequeña descripción de los servicios que solicita el cliente');

        $tipo = new Zend_Form_Element_Select('tipo');
        $tipo->setLabel('Tipo servicio')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addMultiOption('', '-- Seleccionar')
               ->addMultiOption('REV GENERAL', 'REVISION GENERAL')
               ->addMultiOption('MANT PROGRAMADO', 'MANTENIMIENTO PROGRAMADO')
               ->addMultiOption('REPARACIONES', 'REPARACIONES')
               ->addMultiOption('OTRO', 'OTRO MOTIVO');

        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Crear reserva')
               ->setAttrib('class','reserva')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setDecorators(array('ViewHelper'));
        
        $this->addElements(
            array(
                $cliente, $vehiculo, $fecha,
                $comentarios, $submit, $cancel, 
                $back, $id, $buscador, $hora, $tipo
            ));

        $this->addDisplayGroup(
            array(
                'buscador'
            ),
            'busquedaInputs'
        );

        $busquedaInputs = $this->getDisplayGroup('busquedaInputs');
        $busquedaInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-busqueda'))
            ));

        $this->addDisplayGroup(
            array(
                'cliente','vehiculo', 'tipo', 'comentarios'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            ));

        $this->addDisplayGroup(
            array(
                'fecha', 'hora'
            ),
            'fechaInputs'
        );

        $fechaInputs = $this->getDisplayGroup('fechaInputs');
        $fechaInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            ));

        $this->addDisplayGroup(
            array('submit', 'cancel','back','id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'reserva',
                'action'    => $path . '/new'
            ));

    } 
} 
