<?php
class Default_Form_SolicitudArticulo extends Zend_Form
{ 
    public function __construct($options = null, $path = null, $history = '/solicitud-articulo')
    { 
        parent::__construct($options);

        $opcionesArticulo = array('table' => 'articulos', 'field' => 'codigo');
        $validadorArticulo = new Zend_Validate_Db_RecordExists($opcionesArticulo);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));

        $buscador = new Zend_Form_Element_Text('buscador');
        $buscador->setLabel('Buscar artículo')
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->setRequired(false)
                 ->setAttrib('onkeypress', 'ajaxSearchArticulo($(this), "#articulo")');

        $back = new Zend_Form_Element_Hidden('back');
        $back->setValue($history)
             ->setDecorators(array('ViewHelper'));

        $articulo = new Zend_Form_Element_Text('articulo');
        $articulo->setLabel('Código')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addValidator($validadorArticulo);

        $cantidad = new Zend_Form_Element_Text('cantidad');
        $cantidad->setLabel('Cantidad')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addValidator('Int');

        $cargar_a = new Zend_Form_Element_Select('cargar_a');
        $cargar_a->setLabel('Cargar el retiro a')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addMultiOption('','-- Seleccionar')
                 ->addMultiOptions(Default_Model_TipoEgresoArticulo::getPairsToSelect());

        $numero_documento = new Zend_Form_Element_Text('numero_documento');
        $numero_documento->setLabel('')
                         ->setRequired(true)
                         ->setValue(0)
                         ->setAttrib('disabled', 'disabled');
            
        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Crear solicitud de artículo')
               ->setAttrib('class','solicitud-articulo')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setDecorators(array('ViewHelper'));
        
        $this->addElements(
            array(
                $id, $buscador, $articulo,
                $cantidad, $submit, $cancel,
                $back, $cargar_a, $numero_documento
            ));

        $this->addDisplayGroup(
            array(
                'buscador'
            ),
            'busquedaInputs'
        );

        $busquedaInputs = $this->getDisplayGroup('busquedaInputs');
        $busquedaInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-busqueda'))
            ));

        $this->addDisplayGroup(
            array(
                'articulo', 'cantidad','cargar_a', 'numero_documento'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel','back', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'solicitud-articulo',
                'action'    => $path . '/new'
            ));
    } 
} 
