<?php
class Default_Form_SolicitudCompra extends Zend_Form
{ 
    public function __construct($options = null, $path = null, $history = '/status/compras')
    { 
        parent::__construct($options);

        $descripcionCantidad = "Ingrese sólo números enteros. Ej. : 12";
        $descripcionDescripcion = "En caso de un artículo nuevo, poner la mayor "
                                . "cantidad de información posible, como fabricante, "
                                . "alternativas, etc.";

        $descripcionPrioridad = "Alta: Compra urgente para servicio en curso o máximo de 24 Hr." . "\n"
                              . "Media: Compra necesaria dentro de los próximos 3 días. "
                              . "Baja: Compra a realizar sin urgencia, generalmente para reponer stock";


        $validador_rut = new App_Validate_ValidRut();

        $buscador = new Zend_Form_Element_Text('buscador');
        $buscador->setLabel('Buscar proveedor')
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->setRequired(true)
                 ->setAttrib('onkeypress', 'ajaxSearchProveedor($(this), "#proveedor")');
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));

        $back = new Zend_Form_Element_Hidden('back');
        $back->setValue($history)
             ->setDecorators(array('ViewHelper'));

        $proveedor = new Zend_Form_Element_Text('proveedor');
        $proveedor->setLabel('R.U.T. Proveedor')
                  ->addFilter('StripTags')
                  ->addFilter('StringTrim')
                  ->addValidator($validador_rut);

        $prioridad = new Zend_Form_Element_Select('prioridad');
        $prioridad->setLabel('Prioridad')
            ->setRequired(true)
            ->addFilter('StripTags')
            ->addFilter('StringTrim')
            ->addMultiOption('', '-- Seleccionar --')
            ->addMultiOption('ALTA', 'ALTA')
            ->addMultiOption('MEDIA', 'MEDIA')
            ->addMultiOption('BAJA', 'BAJA')
            ->setAttrib('class', 'tooltip')
            ->setDescription(htmlspecialchars($descripcionPrioridad));
        
        $observaciones = new Zend_Form_Element_Textarea('observaciones');
        $observaciones->setLabel('Observaciones')
                      ->setRequired(false)
                      ->addFilter('StripTags')
                      ->addFilter('StringTrim')
                      ->setAttrib('style', 'height:125px');
            
        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Crear solicitud de compra')
               ->setAttrib('class','solicitud-compra')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setDecorators(array('ViewHelper'));
        
        $this->addElements(
            array(
                $id, $prioridad, $observaciones, $submit,
                $cancel, $back, $proveedor, $buscador
            ));

        $this->addDisplayGroup(
            array(
                'buscador'
            ),
            'busquedaInputs'
        );

        $busquedaInputs = $this->getDisplayGroup('busquedaInputs');
        $busquedaInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-busqueda'))
            ));

        $this->addDisplayGroup(
            array(
                'proveedor', 'prioridad', 'observaciones'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left-ancho'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel','back', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'solicitud-compra',
                'action'    => $path . '/new'
            ));
    } 
} 
