<?php
class Default_Form_TerminoOrdenServicio extends Zend_Form
{ 
    public function __construct($options = null, $path = null, $history = '/orden-servicio')
    { 
        parent::__construct($options);

        $options = array('table' => 'ordenes_servicios', 'field' => 'id');
        $validadorOrden = new Zend_Validate_Db_RecordExists($options);
        $validadorHorasReales = new App_Validate_Float();
        $descripcionHorasReales = 'Ingresar las horas reales que tomó el trabajo.' 
                                . ' Se aceptan decimales. Ej: 1.5 (equivale a 90 min)';

        $descripcionObservaciones = 'Comentarios adicionales relativos al trabajo realizado.';
        $descripcionRecomendaciones = 'Observaciones y recomendaciones generales sobre el estado del vehículo.';

        $id = new Zend_Form_Element_Text('id');
        $id->setLabel('Nº Orden de servicio')
                 ->addValidator('Int')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addValidator($validadorOrden);

        $prueba_ruta = new Zend_Form_Element_Radio('prueba_ruta');
        $prueba_ruta->setLabel('Prueba de ruta')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addMultiOption('HECHO', 'HECHO')
                 ->addMultiOption('NO APLICABLE', 'NO APLICABLE');

        $control_calidad = new Zend_Form_Element_Select('control_calidad');
        $control_calidad->setLabel('Control de calidad realizado por')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addMultiOption('', '-- Seleccionar --')
                 ->addMultiOptions(Default_Model_Empleado::getEmpleadosTaller());

        $horas_reales = new Zend_Form_Element_Text('horas_reales');
        $horas_reales->setLabel('Horas reales')
                     ->setRequired(true)
                     ->addFilter('StripTags')
                     ->addFilter('StringTrim')
                     ->addValidator($validadorHorasReales)
                     ->setDescription($descripcionHorasReales)
                     ->setAttrib("class", "tooltip");

        $back = new Zend_Form_Element_Hidden('back');
        $back->setValue($history)
             ->setDecorators(array('ViewHelper'));

        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Terminar')
               ->setAttrib('class','orden-servicio')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setDecorators(array('ViewHelper'));
        
        $this->addElements(
            array(
                $id, $submit, $cancel, $back, 
                $horas_reales, $prueba_ruta,
                $control_calidad
            ));

        $this->addDisplayGroup(
            array(
                'id', 'horas_reales', 'prueba_ruta', 'control_calidad'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel', 'back'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'termino-orden-servicio',
                'action'    => $path . '/terminar'
            ));
    } 
} 
