<?php
class Default_Form_UsuarioWeb extends Zend_Form
{ 
    public function __construct($options = null, $path = null, $history = '/status/ventas')
    {
        parent::__construct($options);

        $tiposUsuarios = array(
            'ADMINISTRADOR' => 'ADMINISTRADOR',
            'CONTABLE' => 'CONTABLE',
            'CONDUCTOR' => 'CONDUCTOR'
        );

        $optionsCliente = array('table' => 'clientes', 'field' => 'rut');
        $validadorCliente = new Zend_Validate_Db_RecordExists($optionsCliente);

        $mailDescripcion = 'La dirección de email será usada como usuario de acceso al módulo web. '
                         . 'Además, a esta dirección se enviarán todas las comunicaciones y notificaciones.';

        $back = new Zend_Form_Element_Hidden('back');
        $back->setValue($history)
             ->setDecorators(array('ViewHelper'));

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));

        $cliente = new Zend_Form_Element_Text('cliente');
        $cliente->setLabel('R.U.T. Cliente')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->addValidator($validadorCliente);
             
        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->setAttrib('class', 'tooltip')
              ->setDescription('Nombre completo de la persona');
             
        $mail = new Zend_Form_Element_Text('mail');
        $mail->setLabel('Email')
             ->setRequired(true)
             ->addFilter('StripTags') 
             ->addFilter('StringTrim')
             ->addValidator('EmailAddress')
             ->setAttrib('class', 'tooltip')
             ->setDescription($mailDescripcion);

        $telefono = new Zend_Form_Element_Text('telefono');
        $telefono->setLabel('Teléfonos')
              ->setRequired(false)
              ->addFilter('StripTags')
              ->addFilter('StringTrim');
        
        $tipo = new Zend_Form_Element_Select('tipo');
        $tipo->setLabel('Tipo de usuario')
             ->setRequired(true)
             ->addFilter('StripTags')
             ->addFilter('StringTrim')
             ->addMultiOptions($tiposUsuarios);

        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Crear usuario')
               ->setAttrib('class','cliente')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setDecorators(array('ViewHelper'));

        $this->addElements(
            array(
                $tipo, $cliente, $nombre,
                $mail, $telefono, $submit, 
                $cancel, $back, $id
            ));

        $this->addDisplayGroup(
            array(
                'tipo', 'cliente','nombre','mail', 'telefono'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel','back', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'usuario-web',
                'action'    => $path . '/new'
            ));

    } 
} 
