<?php
class Default_Form_Vehiculo extends Zend_Form 
{ 
    public function __construct($options = null, $path = null, $marca = null, $history = '/vehiculo')
    { 
        parent::__construct($options);

        $validador_patente = new Zend_Validate_StringLength();
        $validador_patente->setMin(6);
        $validador_patente->setMax(6);

        $validadorCilindrada = new App_Validate_Float();

        $descripcionCilindrada = 'Utilice un formato abreviado, por ejemplo : 1.6 o 2.5';

        $buscador = new Zend_Form_Element_Text('buscador');
        $buscador->setLabel('Buscar cliente')
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->setRequired(false)
                 ->setAttrib('onkeypress', 'ajaxSearchCliente($(this), "#cliente")')
                 ->setAttrib('class', 'tooltip')
                 ->setDescription('Busque el cliente a través de la razón social');

        $back = new Zend_Form_Element_Hidden('back');
        $back->setValue($history)
             ->setDecorators(array('ViewHelper'));

        $cliente = new Zend_Form_Element_Text('cliente');
        $cliente->setLabel('R.U.T. Cliente')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim');

        $marca_id = new Zend_Form_Element_Select('marca_id');
        $marca_id->setLabel('Marca vehículo')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addMultiOption('','-- Seleccionar --')
               ->addMultiOptions(Default_Model_MarcaVehiculo::getPairsToSelect());


        $modelo = new Zend_Form_Element_Text('modelo');
        $modelo->setLabel('Modelo Vehículo')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim');

        $version = new Zend_Form_Element_Text('version');
        $version->setLabel('Versión')
                ->setRequired(false)
                ->addFilter('StripTags')
                ->addFilter('StringTrim');

        $cilindrada = new Zend_Form_Element_Text('cilindrada');
        $cilindrada->setLabel('Cilindrada')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addValidator($validadorCilindrada)
                ->setAttrib('class', 'tooltip')
                ->setDescription($descripcionCilindrada);
        
        $tipo_combustible = new Zend_Form_Element_Select('tipo_combustible');
        $tipo_combustible->setLabel('Tipo combustible')
                         ->setRequired(true)
                         ->addFilter('StripTags')
                         ->addFilter('StringTrim')
                         ->addMultiOption('','-- Seleccionar --')
                         ->addMultiOption('GASOLINA','GASOLINA')
                         ->addMultiOption('DIESEL','DIESEL')
                         ->addMultiOption('ETANOL','ETANOL')
                         ->addMultiOption('ALCOHOL','ALCOHOL');

        $traccion = new Zend_Form_Element_Select('traccion');
        $traccion->setLabel('Tracción')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addMultiOption('','-- Seleccionar --')
                 ->addMultiOption('4x2','4x2')
                 ->addMultiOption('4x4','4x4');

        $transmision = new Zend_Form_Element_Select('transmision');
        $transmision->setLabel('Transmisión')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addMultiOption('','-- Seleccionar --')
                 ->addMultiOption('MANUAL','MANUAL')
                 ->addMultiOption('AUTOMATICA','AUTOMATICA');

        $patente = new Zend_Form_Element_Text('patente');
        $patente->setLabel('Placa patente')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->addValidator($validador_patente)
              ->setAttrib('class', 'tooltip')
              ->setDescription('Sin espacios ni signos adicionales.');

        $vin_chassis = new Zend_Form_Element_Text('vin_chassis');
        $vin_chassis->setLabel('VIN Chassis')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim');

        $numero_motor = new Zend_Form_Element_Text('numero_motor');
        $numero_motor->setLabel('Nº motor')
              ->setRequired(false)
              ->addFilter('StripTags')
              ->addFilter('StringTrim');
              
        $color = new Zend_Form_Element_Text('color');
        $color->setLabel('Color carrocería')
            ->setRequired(true)
            ->addFilter('StripTags') 
            ->addFilter('StringTrim');

        $km_anual = new Zend_Form_Element_Text('km_anual');
        $km_anual->setLabel('Kilometraje anual aproximado')
            ->setRequired(true)
            ->addFilter('StripTags')
            ->addFilter('StringTrim')
            ->addValidator('Int')
            ->setAttrib('class', 'tooltip')
            ->setDescription('Ingrese un número entero, sin puntos ni signos de ningún tipo.');
             
        $anio = new Zend_Form_Element_Text('anio');
        $anio->setLabel('Año')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->addValidator('Int')
              ->setAttrib('class', 'tooltip')
              ->setDescription('Ingrese el año con 4 digitos. Ej.: 2008');
            
        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Agregar vehiculo')
               ->setAttrib('class','vehiculo')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setDecorators(array('ViewHelper'));
        
        $this->addElements(
            array(
                $cliente, $patente, $marca_id,
                $modelo, $version, $cilindrada,
                $tipo_combustible, $traccion, 
                $anio, $color, $submit, $cancel,
                $back, $km_anual, $buscador, 
                $vin_chassis, $numero_motor,
                $transmision
                ));
        
        $this->addDisplayGroup(
            array(
                'buscador'
            ),
            'busquedaInputs'
        );

        $busquedaInputs = $this->getDisplayGroup('busquedaInputs');
        $busquedaInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-busqueda'))
            ));

        $this->addDisplayGroup(
            array(
                'cliente', 'patente', 'vin_chassis', 'numero_motor', 'anio', 'color', 'km_anual'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array(
               'marca_id', 'modelo', 'version', 'cilindrada', 'tipo_combustible', 'traccion', 'transmision'
            ),
            'infoInputs2'
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel','back'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'vehiculo',
                'action'    => $path . '/new'
            ));
    } 
} 
