<?php
class Default_Model_Articulo extends Zend_Db_Table_Abstract
{
    protected $_name = 'articulos';
    protected $_primary = 'codigo';

    private $_id;

    public function setId($_id)
    {
        $this->_id = $_id;
    }
        
    public function getAll()
    {
        $articulos = new VistaArticulos();
        return $articulos->fetchAll();
    }

    public function getRowsByCategoria($categoria_id)
    {
        $db = Zend_Registry::get('db');
        $db->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $db->select()
            ->from(array('ai' => 'articulos'),
                   array('id','codigo', 'nombre'))
            ->where('ai.categoria_id=?',$categoria_id)
            ->order('ai.nombre');
        $result = $db->fetchAll($select);
        if(count($result) > 0) {
            return $result;
        } else {
            return false;
        }
    }

    public function getRowsByCategoriaToOrdenCompra($categoria_id)
    {
        $db = Zend_Registry::get('db');
        $db->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $db->select()
            ->from(array('ai' => 'articulos'),
                   array('id','codigo', 'nombre'))
            ->where('ai.categoria_id=?',$categoria_id)
            ->order('ai.nombre');
        $result = $db->fetchAll($select);
        if(count($result) > 0) {
            return $result;
        } else {
            return false;
        }
    }

    public function getRowById()
    {
        $articulos = new VistaArticulos();
        return $articulos->fetchRow('id=' . $this->_id);
    }

    public static function getRowToItem($articulo_id)
    {
        $db = Zend_Registry::get('db');
        $db->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $db->select()
            ->from(array('ai' => 'articulos'), array('codigo','nombre','descripcion'))
            ->where('ai.id=?',$articulo_id);
        $result = $db->fetchRow($select);
        return $result;
    }

    public function getIdByCodigo($codigo)
    {
        $db = Zend_Registry::get('db');
        $db->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $db->select()
            ->from(array('ai' => 'articulos'),array('id'))
            ->where('ai.codigo = ? ', $codigo);
        $articulo_id = $db->fetchOne($select);
        if($articulo_id) {
            return $articulo_id;
        } else {
            return false;
        }
    }

    public static function getPairsToSelect()
    {
        $db = new Default_Model_Articulo();
        $result = $db->getAdapter()->fetchPairs("SELECT id, CONCAT(codigo," - ",nombre) FROM articulos");
        return $result;
    }


    public function getUltimoIngresoInventario($tipo_ingreso_id)
    {
        $ingreso = new IngresoArticulo();
        $ultimoIngreso = $ingreso->getLastByArticuloAndType($this->_id, $tipo_ingreso_id);
        return $ultimoIngreso;
    }

    public function getEquivalencias()
    {
        $codigo = self::getCodigoById($this->_id);
        $equivalencia = new EquivalenciaArticulo();
        $equivalencias = $equivalencia->getRowsByCodigo($codigo);
        return $equivalencias;
    }

    public static function getCodigoById($id)
    {
        $db = Zend_Registry::get('db');
        $db->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $db->select()
            ->from(array('ai' => 'articulos'), array('codigo'))
            ->where('ai.id = ? ', $id);
        $result = $db->fetchOne($select);
        return $result;
    }

    public function getStock()
    {
        $ingresos = IngresoArticulo::getIngresosByArticuloId($this->_id);
        $egresos = EgresoArticulo::getEgresosByArticuloId($this->_id);
        $stock = $ingresos - $egresos;
        return $stock;
    }

}